/* WARNING: This file is generated!
 * Do not edit this file, but edit /cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/src/doxygen-1.18.0/src/i18n/config_de.xml instead and run
 * python configgen.py -wiz /cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/src/doxygen-1.18.0/src/i18n/config_de.xml to regenerate this file!
 */
#include "configdoc.h"
#include "docintf.h"

void addConfigDocs_de(DocIntf *doc)
{
  doc->setHeader(
              "Diese Datei beschreibt die Einstellungen, die vom Dokumentationssystem Doxygen\n"
              "(www.doxygen.org) für ein Projekt verwendet werden.\n"
              "\n"
              "Der gesamte Text nach einer doppelten Raute (##) gilt als Kommentar und wird\n"
              "vor das Tag gesetzt, dem er vorangeht.\n"
              "\n"
              "Der gesamte Text nach einer einzelnen Raute (#) gilt als Kommentar und wird\n"
              "ignoriert. Das Format lautet:\n"
              "TAG = value [value, ...]\n"
              "Bei Listen können Einträge auch angehängt werden mit:\n"
              "TAG += value [value, ...]\n"
              "Werte, die Leerzeichen enthalten, sollten in Anführungszeichen gesetzt werden\n"
              "(\" \").\n"
              "\n"
              "Hinweis:\n"
              "\n"
              "Verwenden Sie Doxygen, um die verwendete Konfigurationsdatei mit der\n"
              "Vorlagen-Konfigurationsdatei zu vergleichen:\n"
              "doxygen -x [configFile]\n"
              "Verwenden Sie Doxygen, um die verwendete Konfigurationsdatei mit der\n"
              "Vorlagen-Konfigurationsdatei zu vergleichen, ohne die Umgebungsvariablen oder\n"
              "CMake-Ersetzungsvariablen zu ersetzen:\n"
              "doxygen -x_noenv [configFile]"
             );
  doc->add(
              "DOXYFILE_ENCODING",
              "Dieses Tag gibt die Codierung für alle Zeichen in der Konfigurationsdatei an,\n"
              "die folgen. Der Standardwert ist UTF-8, was auch die Codierung für den\n"
              "gesamten Text vor dem ersten Auftreten dieses Tags ist. Doxygen verwendet\n"
              "libiconv (oder das in libc eingebaute iconv) für die Transkodierung. Siehe\n"
              "https://www.gnu.org/software/libiconv/ für die Liste möglicher Codierungen.\n"
              "Der Standardwert ist: UTF-8."
          );
  doc->add(
              "PROJECT_NAME",
              "Das PROJECT_NAME-Tag ist ein einzelnes Wort (oder eine Folge von Wörtern, die\n"
              "von Anführungszeichen umgeben sind, es sei denn, Sie verwenden Doxywizard),\n"
              "das das Projekt identifizieren soll, für das die Dokumentation erstellt wird.\n"
              "Dieser Name wird im Titel der meisten generierten Seiten und an einigen\n"
              "anderen Stellen verwendet.\n"
              "Der Standardwert ist: My Project."
          );
  doc->add(
              "PROJECT_NUMBER",
              "Das PROJECT_NUMBER-Tag kann verwendet werden, um eine Projekt- oder\n"
              "Revisionsnummer einzugeben. Dies kann zum Archivieren der generierten\n"
              "Dokumentation oder bei Verwendung eines Versionskontrollsystems nützlich sein."
          );
  doc->add(
              "PROJECT_BRIEF",
              "Mit dem PROJECT_BRIEF-Tag kann man eine optionale einzeilige Beschreibung für\n"
              "ein Projekt angeben, die oben auf jeder Seite erscheint und den Betrachtern\n"
              "einen schnellen Überblick über den Zweck des Projekts geben sollte. Halten Sie\n"
              "die Beschreibung kurz."
          );
  doc->add(
              "PROJECT_LOGO",
              "Mit dem PROJECT_LOGO-Tag kann man ein Logo oder Symbol angeben, das in die\n"
              "Dokumentation aufgenommen wird. Die maximale Höhe des Logos sollte 55 Pixel\n"
              "nicht überschreiten und die maximale Breite sollte 200 Pixel nicht\n"
              "überschreiten. Doxygen kopiert das Logo in das Ausgabeverzeichnis."
          );
  doc->add(
              "PROJECT_ICON",
              "Mit dem PROJECT_ICON-Tag kann man ein Symbol angeben, das in den\n"
              "Registerkarten angezeigt wird, wenn das HTML-Dokument angezeigt wird. Doxygen\n"
              "kopiert das Logo in das Ausgabeverzeichnis."
          );
  doc->add(
              "OUTPUT_DIRECTORY",
              "Das OUTPUT_DIRECTORY-Tag wird verwendet, um den (relativen oder absoluten)\n"
              "Pfad anzugeben, in den die generierte Dokumentation geschrieben wird. Wenn ein\n"
              "relativer Pfad eingegeben wird, ist er relativ zu dem Ort, an dem Doxygen\n"
              "gestartet wurde. Wenn leer gelassen, wird das aktuelle Verzeichnis verwendet."
          );
  doc->add(
              "CREATE_SUBDIRS",
              "Wenn das CREATE_SUBDIRS-Tag auf YES gesetzt ist, erstellt Doxygen bis zu 4096\n"
              "Unterverzeichnisse (in 2 Ebenen) unter dem Ausgabeverzeichnis jedes\n"
              "Ausgabeformats und verteilt die generierten Dateien über diese Verzeichnisse.\n"
              "Das Aktivieren dieser Option kann nützlich sein, wenn Doxygen eine große Menge\n"
              "an Quelldateien zugeführt wird, wobei das Ablegen aller generierten Dateien im\n"
              "selben Verzeichnis sonst Leistungsprobleme für das Dateisystem verursachen\n"
              "würde. Passen Sie CREATE_SUBDIRS_LEVEL an, um die Anzahl der\n"
              "Unterverzeichnisse zu steuern.\n"
              "Der Standardwert ist: NO."
          );
  doc->add(
              "CREATE_SUBDIRS_LEVEL",
              "Steuert die Anzahl der Unterverzeichnisse, die erstellt werden, wenn das\n"
              "CREATE_SUBDIRS-Tag auf YES gesetzt ist. Ebene 0 repräsentiert 16\n"
              "Verzeichnisse, und jede Ebenenerhöhung verdoppelt die Anzahl der\n"
              "Verzeichnisse, was zu 4096 Verzeichnissen auf Ebene 8 führt, was der\n"
              "Standardwert und auch der Maximalwert ist. Die Unterverzeichnisse sind in 2\n"
              "Ebenen organisiert, wobei die erste Ebene immer eine feste Anzahl von 16\n"
              "Verzeichnissen hat.\n"
              "Mindestwert: 0, Höchstwert: 8, Standardwert: 8.\n"
              "Dieses Tag erfordert, dass das Tag CREATE_SUBDIRS auf YES gesetzt ist."
          );
  doc->add(
              "ALLOW_UNICODE_NAMES",
              "Wenn das ALLOW_UNICODE_NAMES-Tag auf YES gesetzt ist, erlaubt Doxygen Nicht-\n"
              "ASCII-Zeichen in den Namen der generierten Dateien. Wenn auf NO gesetzt,\n"
              "werden Nicht-ASCII-Zeichen maskiert, zum Beispiel wird _xE3_x81_x84 für\n"
              "Unicode U+3044 verwendet.\n"
              "Der Standardwert ist: NO."
          );
  doc->add(
              "OUTPUT_LANGUAGE",
              "Das OUTPUT_LANGUAGE-Tag wird verwendet, um die Sprache anzugeben, in der die\n"
              "gesamte von Doxygen generierte Dokumentation geschrieben wird. Doxygen\n"
              "verwendet diese Informationen, um die gesamte konstante Ausgabe in der\n"
              "richtigen Sprache zu generieren.\n"
              "Mögliche Werte sind: Afrikaans, Arabic, Armenian, Brazilian, Bulgarian,\n"
              "Catalan, Chinese, Chinese-Traditional, Croatian, Czech, Danish, Dutch, English\n"
              "(Vereinigte Staaten), Esperanto, Farsi (Persisch), Finnish, French, German,\n"
              "Greek, Hindi, Hungarian, Indonesian, Italian, Japanese, Japanese-en (Japanisch\n"
              "mit englischen Meldungen), Korean, Korean-en (Koreanisch mit englischen\n"
              "Meldungen), Latvian, Lithuanian, Macedonian, Norwegian, Persian (Farsi),\n"
              "Polish, Portuguese, Romanian, Russian, Serbian, Serbian-Cyrillic, Slovak,\n"
              "Slovene, Spanish, Swedish, Turkish, Ukrainian und Vietnamese.\n"
              "Der Standardwert ist: English."
          );
  doc->add(
              "BRIEF_MEMBER_DESC",
              "Wenn das BRIEF_MEMBER_DESC-Tag auf YES gesetzt ist, wird Doxygen kurze\n"
              "Mitgliederbeschreibungen nach den Mitgliedern einfügen, die in der Datei- und\n"
              "Klassendokumentation aufgeführt sind (ähnlich wie Javadoc). Auf NO setzen, um\n"
              "dies zu deaktivieren.\n"
              "Der Standardwert ist: YES."
          );
  doc->add(
              "REPEAT_BRIEF",
              "Wenn das REPEAT_BRIEF-Tag auf YES gesetzt ist, wird Doxygen die\n"
              "Kurzbeschreibung eines Mitglieds oder einer Funktion vor der detaillierten\n"
              "Beschreibung voranstellen.\n"
              "\n"
              "Hinweis: Wenn sowohl HIDE_UNDOC_MEMBERS als auch BRIEF_MEMBER_DESC auf NO\n"
              "gesetzt sind, werden die Kurzbeschreibungen vollständig unterdrückt.\n"
              "Der Standardwert ist: YES."
          );
  doc->add(
              "ABBREVIATE_BRIEF",
              "Dieses Tag implementiert einen quasi-intelligenten Kurzbeschreibungs-Abkürzer,\n"
              "der verwendet wird, um den Text in verschiedenen Auflistungen zu bilden. Jede\n"
              "Zeichenfolge in dieser Liste, wenn sie als führender Text der Kurzbeschreibung\n"
              "gefunden wird, wird vom Text entfernt, und das Ergebnis nach der Verarbeitung\n"
              "der gesamten Liste wird als kommentierter Text verwendet. Andernfalls wird die\n"
              "Kurzbeschreibung wie angegeben verwendet. Wenn leer gelassen, werden die\n"
              "folgenden Werte verwendet ($name wird automatisch durch den Namen der Entität\n"
              "ersetzt):The $name class, The $name widget, The $name file, is, provides,\n"
              "specifies, contains, represents, a, an und the."
          );
  doc->add(
              "ALWAYS_DETAILED_SEC",
              "Wenn sowohl die Tags ALWAYS_DETAILED_SEC als auch REPEAT_BRIEF auf YES gesetzt\n"
              "sind, generiert Doxygen einen detaillierten Abschnitt, auch wenn es nur eine\n"
              "Kurzbeschreibung gibt.\n"
              "Der Standardwert ist: NO."
          );
  doc->add(
              "INLINE_INHERITED_MEMB",
              "Wenn das INLINE_INHERITED_MEMB-Tag auf YES gesetzt ist, zeigt Doxygen alle\n"
              "geerbten Mitglieder einer Klasse in der Dokumentation dieser Klasse an, als ob\n"
              "diese Mitglieder gewöhnliche Klassenmitglieder wären. Konstruktoren,\n"
              "Destruktoren und Zuweisungsoperatoren der Basisklassen werden nicht angezeigt.\n"
              "Der Standardwert ist: NO."
          );
  doc->add(
              "FULL_PATH_NAMES",
              "Wenn das FULL_PATH_NAMES-Tag auf YES gesetzt ist, fügt Doxygen den\n"
              "vollständigen Pfad vor Dateinamen in der Dateiliste und in den Header-Dateien\n"
              "hinzu. Wenn auf NO gesetzt, wird der kürzeste Pfad verwendet, der die\n"
              "Dateinamen eindeutig macht.\n"
              "Der Standardwert ist: YES."
          );
  doc->add(
              "STRIP_FROM_PATH",
              "Das STRIP_FROM_PATH-Tag kann verwendet werden, um einen benutzerdefinierten\n"
              "Teil des Pfads zu entfernen. Das Entfernen erfolgt nur, wenn eine der\n"
              "angegebenen Zeichenfolgen mit dem linken Teil des Pfads übereinstimmt. Dieses\n"
              "Tag kann verwendet werden, um relative Pfade in der Dateiliste anzuzeigen.\n"
              "Wenn leer gelassen, wird das Verzeichnis, in dem Doxygen ausgeführt wird, als\n"
              "zu entfernender Pfad verwendet.\n"
              "\n"
              "Beachten Sie, dass Sie hier absolute Pfade angeben können, aber auch relative\n"
              "Pfade, die relativ zu dem Verzeichnis sind, in dem Doxygen gestartet wurde.\n"
              "Dieses Tag erfordert, dass das Tag FULL_PATH_NAMES auf YES gesetzt ist."
          );
  doc->add(
              "STRIP_FROM_INC_PATH",
              "Das STRIP_FROM_INC_PATH-Tag kann verwendet werden, um einen\n"
              "benutzerdefinierten Teil des Pfads zu entfernen, der in der Dokumentation\n"
              "einer Klasse erwähnt wird, der dem Leser sagt, welche Header-Datei er\n"
              "einbinden muss, um die Klasse zu verwenden. Wenn leer gelassen, wird nur der\n"
              "Name der Header-Datei verwendet, die die Klassendefinition enthält.\n"
              "Andernfalls sollten Sie eine Liste von Include-Pfaden angeben, die\n"
              "normalerweise mit dem -I-Flag an den Compiler übergeben werden."
          );
  doc->add(
              "SHORT_NAMES",
              "Wenn das SHORT_NAMES-Tag auf YES gesetzt ist, generiert Doxygen kurze (aber\n"
              "nicht eindeutige) Dateinamen. Dies kann nützlich sein, wenn Ihr Dateisystem\n"
              "keine langen Namen unterstützt, wie z.B. DOS, Mac oder CD-ROM.\n"
              "Der Standardwert ist: NO."
          );
  doc->add(
              "JAVADOC_AUTOBRIEF",
              "Wenn das JAVADOC_AUTOBRIEF-Tag auf YES gesetzt ist, interpretiert Doxygen die\n"
              "erste Zeile (bis zum ersten Punkt, Fragezeichen oder Ausrufezeichen) eines\n"
              "Javadoc-Stil-Kommentars als Kurzbeschreibung. Wenn auf NO gesetzt, verhält\n"
              "sich der Javadoc-Stil wie reguläre Qt-Stil-Kommentare (wodurch ein expliziter\n"
              "@brief-Befehl für eine Kurzbeschreibung erforderlich ist).\n"
              "Der Standardwert ist: NO."
          );
  doc->add(
              "JAVADOC_BANNER",
              "Wenn das JAVADOC_BANNER-Tag auf YES gesetzt ist, interpretiert Doxygen eine\n"
              "Zeile wie\n"
              "/***************\n"
              "als den Anfang eines Javadoc-Stil-Kommentar-Banners. Wenn auf NO gesetzt,\n"
              "verhält sich der Javadoc-Stil wie reguläre Kommentare und wird nicht von\n"
              "Doxygen interpretiert.\n"
              "Der Standardwert ist: NO."
          );
  doc->add(
              "QT_AUTOBRIEF",
              "Wenn das QT_AUTOBRIEF-Tag auf YES gesetzt ist, interpretiert Doxygen die erste\n"
              "Zeile (bis zum ersten Punkt, Fragezeichen oder Ausrufezeichen) eines Qt-Stil-\n"
              "Kommentars als Kurzbeschreibung. Wenn auf NO gesetzt, verhält sich der Qt-Stil\n"
              "wie normale Qt-Stil-Kommentare (wodurch ein expliziter \\brief-Befehl für eine\n"
              "Kurzbeschreibung erforderlich ist).\n"
              "Der Standardwert ist: NO."
          );
  doc->add(
              "MULTILINE_CPP_IS_BRIEF",
              "Das MULTILINE_CPP_IS_BRIEF-Tag kann auf YES gesetzt werden, damit Doxygen\n"
              "einen mehrzeiligen C++-Spezialkommentarblock (d.h. einen Block aus //! oder\n"
              "/// Kommentaren) als Kurzbeschreibung behandelt. Dies war früher das\n"
              "Standardverhalten. Der neue Standard ist, einen mehrzeiligen\n"
              "C++-Kommentarblock als detaillierte Beschreibung zu behandeln. Setzen Sie\n"
              "dieses Tag auf YES, wenn Sie das alte Verhalten bevorzugen.\n"
              "\n"
              "Beachten Sie, dass das Setzen dieses Tags auf YES auch bedeutet, dass Rational\n"
              "Rose-Kommentare nicht mehr erkannt werden.\n"
              "Der Standardwert ist: NO."
          );
  doc->add(
              "PYTHON_DOCSTRING",
              "Standardmäßig werden Python-Docstrings als vorformatierter Text angezeigt und\n"
              "können keine Doxygen-Spezialbefehle verwenden. Durch Setzen von\n"
              "PYTHON_DOCSTRING auf NO können Doxygen-Spezialbefehle verwendet werden, und\n"
              "der Inhalt der Docstring-Dokumentationsblöcke wird als Doxygen-Dokumentation\n"
              "angezeigt.\n"
              "Der Standardwert ist: YES."
          );
  doc->add(
              "INHERIT_DOCS",
              "Wenn das INHERIT_DOCS-Tag auf YES gesetzt ist, erbt ein undokumentiertes\n"
              "Mitglied die Dokumentation von jedem dokumentierten Mitglied, das es neu\n"
              "implementiert.\n"
              "Der Standardwert ist: YES."
          );
  doc->add(
              "SEPARATE_MEMBER_PAGES",
              "Wenn das SEPARATE_MEMBER_PAGES-Tag auf YES gesetzt ist, generiert Doxygen eine\n"
              "separate Seite für jedes Mitglied. Wenn auf NO gesetzt, wird die Dokumentation\n"
              "aller Mitglieder eines Verbunds (Klasse, Datei, Namensbereich) in einem\n"
              "einzigen Dokument zusammengefasst.\n"
              "Der Standardwert ist: NO."
          );
  doc->add(
              "TAB_SIZE",
              "Das TAB_SIZE-Tag kann verwendet werden, um die Anzahl der Leerzeichen in einem\n"
              "Tabulator festzulegen. Doxygen verwendet diesen Wert, um Tabulatoren in\n"
              "Codefragmenten durch Leerzeichen zu ersetzen.\n"
              "Mindestwert: 1, Höchstwert: 16, Standardwert: 4."
          );
  doc->add(
              "ALIASES",
              "Dieses Tag kann verwendet werden, um eine Reihe von Aliasnamen anzugeben, die\n"
              "als Befehle in der Dokumentation fungieren. Ein Alias hat die Form:\n"
              "name=wert\n"
              "Zum Beispiel wurde das Hinzufügen von\n"
              "\"sideeffect=@par Nebeneffekte:^^\"\n"
              "es Ihnen ermöglichen, den Befehl \\sideeffect (oder @sideeffect) in der\n"
              "Dokumentation zu platzieren, was einen benutzerdefinierten Absatz mit der\n"
              "Überschrift \"Nebeneffekte:\" erzeugt. Beachten Sie, dass Sie im Werteteil eines\n"
              "Alias kein \\n einfügen können, um einen Zeilenumbruch einzufügen (in der\n"
              "resultierenden Ausgabe). Sie können ^^ im Werteteil eines Alias einfügen, um\n"
              "einen Zeilenumbruch einzufügen, als ob ein physikalischer Zeilenumbruch in der\n"
              "Originaldatei vorhanden wäre.Wenn Sie in einem Alias im Wertteil ein Literal\n"
              "wie {, } oder , benötigen, müssen Sie diese mit einem Backslash (\\) maskieren.\n"
              "Dies kann zu Konflikten mit den Befehlen \\{ und \\} führen. Für diese empfiehlt\n"
              "es sich, die Versionen @{ und @} zu verwenden oder eine doppelte Maskierung\n"
              "(\\\\{ und \\\\}) zu verwenden."
          );
  doc->add(
              "OPTIMIZE_OUTPUT_FOR_C",
              "Setzen Sie das OPTIMIZE_OUTPUT_FOR_C-Tag auf YES, wenn Ihr Projekt nur aus\n"
              "C-Quellen besteht. Doxygen wird dann eine Ausgabe generieren, die mehr auf C\n"
              "zugeschnitten ist. Zum Beispiel werden einige der verwendeten Namen anders\n"
              "sein. Die Liste aller Mitglieder wird weggelassen usw.\n"
              "Der Standardwert ist: NO."
          );
  doc->add(
              "OPTIMIZE_OUTPUT_JAVA",
              "Setzen Sie das OPTIMIZE_OUTPUT_JAVA-Tag auf YES, wenn Ihr Projekt nur aus\n"
              "Java- oder Python-Quellen besteht. Doxygen wird dann eine Ausgabe generieren,\n"
              "die mehr auf diese Sprache zugeschnitten ist. Zum Beispiel werden\n"
              "Namensbereiche als Pakete präsentiert, qualifizierte Bereiche werden anders\n"
              "aussehen usw.\n"
              "Der Standardwert ist: NO."
          );
  doc->add(
              "OPTIMIZE_FOR_FORTRAN",
              "Setzen Sie das OPTIMIZE_FOR_FORTRAN-Tag auf YES, wenn Ihr Projekt aus Fortran-\n"
              "Quellen besteht. Doxygen wird dann eine Ausgabe generieren, die auf Fortran\n"
              "zugeschnitten ist.\n"
              "Der Standardwert ist: NO."
          );
  doc->add(
              "OPTIMIZE_OUTPUT_VHDL",
              "Setzen Sie das OPTIMIZE_OUTPUT_VHDL-Tag auf YES, wenn Ihr Projekt aus VHDL-\n"
              "Quellen besteht. Doxygen wird dann eine Ausgabe generieren, die auf VHDL\n"
              "zugeschnitten ist.\n"
              "Der Standardwert ist: NO."
          );
  doc->add(
              "OPTIMIZE_OUTPUT_SLICE",
              "Setzen Sie das OPTIMIZE_OUTPUT_SLICE-Tag auf YES, wenn Ihr Projekt nur aus\n"
              "Slice-Quellen besteht. Doxygen wird dann eine Ausgabe generieren, die mehr auf\n"
              "diese Sprache zugeschnitten ist. Zum Beispiel werden Namensbereiche als Module\n"
              "präsentiert, Typen werden in mehr Gruppen unterteilt usw.\n"
              "Der Standardwert ist: NO."
          );
  doc->add(
              "EXTENSION_MAPPING",
              "Doxygen wählt den zu verwendenden Parser basierend auf der Erweiterung der zu\n"
              "parsenden Datei aus. Mit diesem Tag können Sie einen Parser zuweisen, der für\n"
              "eine bestimmte Erweiterung verwendet werden soll. Doxygen hat eine eingebaute\n"
              "Zuordnung, aber Sie können diese mit diesem Tag überschreiben oder erweitern.\n"
              "Das Format ist ext=language, wobei ext eine Dateierweiterung ist und language\n"
              "einer der von Doxygen unterstützten Parser: IDL, Java, JavaScript, Csharp\n"
              "(C#), C, C++, Lex, D, PHP, md (Markdown), Objective-C, Python, Slice, VHDL,\n"
              "Fortran (festes Format Fortran: FortranFixed, freies Format Fortran:\n"
              "FortranFree, unbekanntes Format Fortran: Fortran. Im letzteren Fall versucht\n"
              "der Parser zu erraten, ob der Code festes oder freies Format ist, was die\n"
              "Standardeinstellung für Fortran-Typ-Dateien ist). Um beispielsweise Doxygen\n"
              "dazu zu bringen, .inc-Dateien als Fortran-Dateien zu behandeln (Standard ist\n"
              "PHP) und .f-Dateien als C (Standard ist Fortran), verwenden Sie: inc=Fortran\n"
              "f=C.\n"
              "\n"
              "Hinweis: Für Dateien ohne Erweiterung können Sie no_extension als Platzhalter\n"
              "verwenden.\n"
              "\n"
              "Hinweis: Für benutzerdefinierte Erweiterungen müssen Sie auch FILE_PATTERNS\n"
              "setzen, sonst werden die Dateien von Doxygen nicht gelesen.\n"
              "\n"
              "Hinweis: Siehe auch die Liste der Standard-Dateierweiterungszuordnungen."
          );
  doc->add(
              "MARKDOWN_SUPPORT",
              "Wenn das MARKDOWN_SUPPORT-Tag aktiviert ist, verarbeitet Doxygen alle\n"
              "Kommentare vorab gemäß dem Markdown-Format, was eine besser lesbare\n"
              "Dokumentation ermöglicht. Siehe https://daringfireball.net/projects/markdown/\n"
              "für Details. Die Ausgabe der Markdown-Verarbeitung wird von Doxygen\n"
              "weiterverarbeitet, sodass Sie Doxygen-, HTML- und XML-Befehle mit Markdown-\n"
              "Formatierung mischen können. Deaktivieren Sie dies nur bei Problemen mit der\n"
              "Abwärtskompatibilität.\n"
              "Der Standardwert ist: YES."
          );
  doc->add(
              "MARKDOWN_STRICT",
              "Wenn das MARKDOWN_STRICT-Tag aktiviert ist, behandelt Doxygen den Text in\n"
              "Kommentaren auch dann als Markdown-Format, wenn das native Markup-Format von\n"
              "Doxygen mit Markdown in Konflikt steht. Dies ist nur relevant, wenn Backticks\n"
              "verwendet werden. Der native Markup-Stil von Doxygen erlaubt es einem\n"
              "einfachen Anführungszeichen, ein mit einem Backtick begonnenes Textfragment zu\n"
              "beenden und es dann als zitierten Text zu behandeln, während in Markdown ein\n"
              "solches Textfragment als wörtlicher Text behandelt wird und nur endet, wenn\n"
              "ein zweiter übereinstimmender Backtick gefunden wird. Zudem erfordert das\n"
              "native Markup-Format von Doxygen, dass doppelte Anführungszeichen in einem\n"
              "Backtick-Abschnitt maskiert werden, während dies für Markdown nicht nötig ist.\n"
              "Der Standardwert ist: YES.\n"
              "Dieses Tag erfordert, dass das Tag MARKDOWN_SUPPORT auf YES gesetzt ist."
          );
  doc->add(
              "TOC_INCLUDE_HEADINGS",
              "Wenn das TOC_INCLUDE_HEADINGS-Tag auf einen Wert ungleich null gesetzt ist,\n"
              "werden alle Überschriften bis zu dieser Ebene automatisch in das\n"
              "Inhaltsverzeichnis aufgenommen, auch wenn sie kein id-Attribut haben.\n"
              "Hinweis: Diese Funktion gilt derzeit nur für Markdown-Überschriften.\n"
              "Mindestwert: 0, Höchstwert: 99, Standardwert: 6.\n"
              "Dieses Tag erfordert, dass das Tag MARKDOWN_SUPPORT auf YES gesetzt ist."
          );
  doc->add(
              "MARKDOWN_ID_STYLE",
              "Das MARKDOWN_ID_STYLE-Tag kann verwendet werden, um den Algorithmus anzugeben,\n"
              "der zum Generieren von Bezeichnern für Markdown-Überschriften verwendet wird.\n"
              "Hinweis: Jeder Bezeichner ist eindeutig.\n"
              "Mögliche Werte sind: DOXYGEN verwendet eine feste 'autotoc_md'-Zeichenkette\n"
              "gefolgt von einer Sequenznummer beginnend bei 0 und GITHUB verwendet die\n"
              "Kleinbuchstabenversion des Titels, wobei alle Leerzeichen durch '-' ersetzt\n"
              "und Satzzeichen entfernt werden.\n"
              "Der Standardwert ist: DOXYGEN.\n"
              "Dieses Tag erfordert, dass das Tag MARKDOWN_SUPPORT auf YES gesetzt ist."
          );
  doc->add(
              "AUTOLINK_SUPPORT",
              "Wenn aktiviert, versucht Doxygen, Wörter, die einer dokumentierten Klasse oder\n"
              "einem Namespace entsprechen, mit der entsprechenden Dokumentation zu\n"
              "verknüpfen. Dies kann in Einzelfallen verhindert werden, indem ein %-Symbol\n"
              "vor das Wort gesetzt wird, oder global, indem AUTOLINK_SUPPORT auf NO gesetzt\n"
              "wird. Wörter, die im AUTOLINK_IGNORE_WORDS-Tag aufgelistet sind, werden von\n"
              "der automatischen Verknüpfung ausgeschlossen.\n"
              "Der Standardwert ist: YES."
          );
  doc->add(
              "AUTOLINK_IGNORE_WORDS",
              "Dieses Tag gibt eine Liste von Wörtern an, die, wenn sie mit dem Anfang eines\n"
              "Wortes in der Dokumentation übereinstimmen, die automatische\n"
              "Verknüpfungsgenerierung unterdrücken, wenn diese durch AUTOLINK_SUPPORT\n"
              "aktiviert ist. Diese Liste beeinflusst keine explizit mit # oder den Befehlen\n"
              "\\link oder \\ref erstellten Links.\n"
              "Dieses Tag erfordert, dass das Tag AUTOLINK_SUPPORT auf YES gesetzt ist."
          );
  doc->add(
              "BUILTIN_STL_SUPPORT",
              "Wenn Sie STL-Klassen verwenden (d.h. std::string, std::vector usw.), aber\n"
              "nicht den (Tag-Datei-)Quellcode der STL als Eingabe einbinden möchten, sollten\n"
              "Sie dieses Tag auf YES setzen, damit Doxygen Funktionsdeklarationen und\n"
              "-definitionen mit Argumenten, die STL-Klassen enthalten, abgleichen kann (z.B.\n"
              "func(std::string); gegenüber func(std::string) {}). Dies macht auch die\n"
              "Vererbungs- und Kollaborationsdiagramme, die STL-Klassen beinhalten,\n"
              "vollständiger und genauer.\n"
              "Der Standardwert ist: NO."
          );
  doc->add(
              "CPP_CLI_SUPPORT",
              "Wenn Sie die C++/CLI-Sprache von Microsoft verwenden, sollten Sie diese Option\n"
              "auf YES setzen, um Parsing-Unterstützung zu aktivieren.\n"
              "Der Standardwert ist: NO."
          );
  doc->add(
              "SIP_SUPPORT",
              "Wenn Sie SIP (siehe https://www.riverbankcomputing.com/software/sip/)\n"
              "verwenden, um Python-Bindungen zu erstellen, setzen Sie diese Option auf YES,\n"
              "damit Doxygen die speziellen Kommentare für SIP-Unterstützung erkennen kann.\n"
              "Der Standardwert ist: NO."
          );
  doc->add(
              "IDL_PROPERTY_SUPPORT",
              "Für Microsofts IDL gibt es die Attribute propget und propput, um Getter- und\n"
              "Setter-Methoden für eine Eigenschaft anzuzeigen. Das Setzen dieser Option auf\n"
              "YES führt dazu, dass Doxygen die get- und set-Methoden in der Dokumentation\n"
              "durch die Eigenschaft ersetzt. Dies funktioniert nur, wenn die Methoden\n"
              "tatsächlich einen einfachen Typ abrufen oder setzen. Wenn dies nicht der Fall\n"
              "ist oder Sie die Methoden trotzdem anzeigen möchten, sollten Sie diese Option\n"
              "auf NO setzen.\n"
              "Der Standardwert ist: YES."
          );
  doc->add(
              "DISTRIBUTE_GROUP_DOC",
              "Wenn in der Dokumentation eine Mitgliedergruppierung verwendet wird und das\n"
              "DISTRIBUTE_GROUP_DOC-Tag auf YES gesetzt ist, wird Doxygen die Dokumentation\n"
              "des ersten Mitglieds der Gruppe für die anderen Mitglieder der Gruppe\n"
              "wiederverwenden (falls vorhanden). Standardmäßig müssen alle Mitglieder einer\n"
              "Gruppe explizit dokumentiert werden.\n"
              "Der Standardwert ist: NO."
          );
  doc->add(
              "GROUP_NESTED_COMPOUNDS",
              "Wenn eine Struktur oder Klasse zu einer Gruppe hinzugefügt wird und diese\n"
              "Option aktiviert ist, werden alle verschachtelten Klassen oder Strukturen\n"
              "ebenfalls derselben Gruppe hinzugefügt. Standardmäßig ist diese Option\n"
              "deaktiviert und man muss verschachtelte Verbindungen explizit über \\ingroup\n"
              "hinzufügen.\n"
              "Der Standardwert ist: NO."
          );
  doc->add(
              "SUBGROUPING",
              "Setzen Sie das SUBGROUPING-Tag auf YES, um Gruppen von Klassenmitgliedern\n"
              "desselben Typs (z.B. eine Gruppe öffentlicher Funktionen) als Untergruppe\n"
              "dieses Typs zu platzieren (z.B. unter dem Abschnitt Öffentliche Funktionen).\n"
              "Setzen Sie es auf NO, um Untergruppierung zu verhindern. Alternativ kann dies\n"
              "pro Klasse mit dem Befehl \\nosubgrouping erfolgen.\n"
              "Der Standardwert ist: YES."
          );
  doc->add(
              "INLINE_GROUPED_CLASSES",
              "Wenn das INLINE_GROUPED_CLASSES-Tag auf YES gesetzt ist, werden Klassen,\n"
              "Strukturen und Unions innerhalb der Gruppe angezeigt, in der sie enthalten\n"
              "sind (z.B. mit \\ingroup) anstatt auf einer separaten Seite (für HTML und Man-\n"
              "Pages) oder in einem Abschnitt (für LaTeX und RTF).\n"
              "\n"
              "Beachten Sie, dass diese Funktion nicht in Kombination mit\n"
              "SEPARATE_MEMBER_PAGES funktioniert.\n"
              "Der Standardwert ist: NO."
          );
  doc->add(
              "INLINE_SIMPLE_STRUCTS",
              "Wenn das INLINE_SIMPLE_STRUCTS-Tag auf YES gesetzt ist, werden Strukturen,\n"
              "Klassen und Unions mit nur öffentlichen Datenfeldern oder einfachen Typedef-\n"
              "Feldern inline in der Dokumentation des Bereichs angezeigt, in dem sie\n"
              "definiert sind (d.h. Datei-, Namensbereich- oder Gruppendokumentation),\n"
              "vorausgesetzt dieser Bereich ist dokumentiert. Wenn auf NO gesetzt, werden\n"
              "Strukturen, Klassen und Unions auf einer separaten Seite (für HTML und Man-\n"
              "Pages) oder in einem Abschnitt (für LaTeX und RTF) angezeigt.\n"
              "Der Standardwert ist: NO."
          );
  doc->add(
              "TYPEDEF_HIDES_STRUCT",
              "Wenn das TYPEDEF_HIDES_STRUCT-Tag aktiviert ist, wird eine Typedef einer\n"
              "Struktur, Union oder Aufzählung als Struktur, Union oder Aufzählung mit dem\n"
              "Namen der Typedef dokumentiert. So wird typedef struct TypeS {} TypeT in der\n"
              "Dokumentation als Struktur mit dem Namen TypeT erscheinen. Wenn deaktiviert,\n"
              "erscheint die Typedef als Mitglied einer Datei, eines Namensbereichs oder\n"
              "einer Klasse. Und die Struktur wird TypeS genannt. Dies kann typischerweise\n"
              "für C-Code nützlich sein, falls die Codierungskonvention vorschreibt, dass\n"
              "alle Verbundtypen typedefiniert sind und nur auf die Typedef verwiesen wird,\n"
              "niemals auf den Tag-Namen.\n"
              "Der Standardwert ist: NO."
          );
  doc->add(
              "LOOKUP_CACHE_SIZE",
              "Die Größe des Symbol-Lookup-Caches kann mit LOOKUP_CACHE_SIZE festgelegt\n"
              "werden. Dieser Cache wird verwendet, um Symbole anhand ihres Namens und\n"
              "Bereichs aufzulösen. Da dies ein aufwendiger Prozess sein kann und dasselbe\n"
              "Symbol oft mehrmals im Code erscheint, halt Doxygen einen Cache mit vorab\n"
              "aufgelösten Symbolen. Wenn der Cache zu klein ist, wird Doxygen langsamer.\n"
              "Wenn der Cache zu groß ist, wird Speicher verschwendet. Die Cache-Größe wird\n"
              "durch diese Formel gegeben: 2^(16+LOOKUP_CACHE_SIZE). Der gültige Bereich ist\n"
              "0..9, der Standard ist 0, was einer Cache-Größe von 2^16=65536 Symbolen\n"
              "entspricht. Am Ende eines Laufs meldet Doxygen die Cache-Nutzung und schlagt\n"
              "die optimale Cache-Größe aus Geschwindigkeitssicht vor.\n"
              "Mindestwert: 0, Höchstwert: 9, Standardwert: 0."
          );
  doc->add(
              "NUM_PROC_THREADS",
              "Das NUM_PROC_THREADS gibt die Anzahl der Threads an, die Doxygen während der\n"
              "Verarbeitung verwenden darf. Wenn auf 0 gesetzt, wird Doxygen dies auf der\n"
              "Anzahl der im System verfügbaren Kerne basieren. Sie können es explizit auf\n"
              "einen Wert größer als 0 setzen, um mehr Kontrolle über das Gleichgewicht\n"
              "zwischen CPU-Last und Verarbeitungsgeschwindigkeit zu erhalten. Im Moment kann\n"
              "nur die Eingabeverarbeitung mit mehreren Threads durchgeführt werden. Da dies\n"
              "noch eine experimentelle Funktion ist, ist der Standard auf 1 gesetzt, was die\n"
              "parallele Verarbeitung effektiv deaktiviert. Bitte melden Sie alle Probleme,\n"
              "die Sie feststellen. Das parallele Generieren von dot-Graphen wird durch die\n"
              "Einstellung DOT_NUM_THREADS gesteuert.\n"
              "Mindestwert: 0, Höchstwert: 512, Standardwert: 1."
          );
  doc->add(
              "TIMESTAMP",
              "Wenn das TIMESTAMP-Tag auf einen anderen Wert als NO gesetzt ist, enthält jede\n"
              "generierte Seite das Datum oder Datum und Uhrzeit, wann die Seite generiert\n"
              "wurde. Das Setzen auf NO kann beim Vergleichen der Ausgabe mehrerer Laufe\n"
              "helfen.\n"
              "Mögliche Werte sind: YES, NO, DATETIME und DATE.\n"
              "Der Standardwert ist: NO."
          );
  doc->add(
              "EXTRACT_ALL",
              "Wenn das EXTRACT_ALL-Tag auf YES gesetzt ist, geht Doxygen davon aus, dass\n"
              "alle Entitäten in der Dokumentation dokumentiert sind, auch wenn keine\n"
              "Dokumentation verfügbar war. Private Klassenmitglieder und statische\n"
              "Dateimitglieder werden ausgeblendet, es sei denn, die Tags EXTRACT_PRIVATE\n"
              "bzw. EXTRACT_STATIC sind auf YES gesetzt.\n"
              "Hinweis: Dies deaktiviert auch die Warnungen über undokumentierte Mitglieder,\n"
              "die normalerweise erzeugt werden, wenn WARNINGS auf YES gesetzt ist.\n"
              "Der Standardwert ist: NO."
          );
  doc->add(
              "EXTRACT_PRIVATE",
              "Wenn das EXTRACT_PRIVATE-Tag auf YES gesetzt ist, werden alle privaten\n"
              "Mitglieder einer Klasse in die Dokumentation aufgenommen.\n"
              "Der Standardwert ist: NO."
          );
  doc->add(
              "EXTRACT_PRIV_VIRTUAL",
              "Wenn das EXTRACT_PRIV_VIRTUAL-Tag auf YES gesetzt ist, werden dokumentierte\n"
              "private virtuelle Methoden einer Klasse in die Dokumentation aufgenommen.\n"
              "Der Standardwert ist: NO."
          );
  doc->add(
              "EXTRACT_PACKAGE",
              "Wenn das EXTRACT_PACKAGE-Tag auf YES gesetzt ist, werden alle Mitglieder mit\n"
              "package- oder internem Sichtbarkeitsbereich in die Dokumentation aufgenommen.\n"
              "Der Standardwert ist: NO."
          );
  doc->add(
              "EXTRACT_STATIC",
              "Wenn das EXTRACT_STATIC-Tag auf YES gesetzt ist, werden alle statischen\n"
              "Mitglieder einer Datei in die Dokumentation aufgenommen.\n"
              "Der Standardwert ist: NO."
          );
  doc->add(
              "EXTRACT_LOCAL_CLASSES",
              "Wenn das EXTRACT_LOCAL_CLASSES-Tag auf YES gesetzt ist, werden lokal in\n"
              "Quelldateien definierte Klassen (und Strukturen) in die Dokumentation\n"
              "aufgenommen. Wenn auf NO gesetzt, werden nur in Header-Dateien definierte\n"
              "Klassen aufgenommen. Hat keine Auswirkung auf Java-Quellen.\n"
              "Der Standardwert ist: YES."
          );
  doc->add(
              "EXTRACT_LOCAL_METHODS",
              "Dieses Tag ist nur für Objective-C-Code nützlich. Wenn auf YES gesetzt, werden\n"
              "lokale Methoden, die im Implementierungsabschnitt definiert sind, aber nicht\n"
              "im Interface, in die Dokumentation aufgenommen. Wenn auf NO gesetzt, werden\n"
              "nur Methoden im Interface aufgenommen.\n"
              "Der Standardwert ist: NO."
          );
  doc->add(
              "EXTRACT_ANON_NSPACES",
              "Wenn dieses Tag auf YES gesetzt ist, werden die Mitglieder anonymer\n"
              "Namensbereiche extrahiert und erscheinen in der Dokumentation als\n"
              "Namensbereich namens 'anonymous_namespace{file}', wobei file durch den\n"
              "Basisnamen der Datei ersetzt wird, die den anonymen Namensbereich enthält.\n"
              "Standardmäßig sind anonyme Namensbereiche ausgeblendet.\n"
              "Der Standardwert ist: NO."
          );
  doc->add(
              "RESOLVE_UNNAMED_PARAMS",
              "Wenn dieses Tag auf YES gesetzt ist, wird der Name eines unbenannten\n"
              "Parameters in einer Deklaration durch die entsprechende Definition bestimmt.\n"
              "Standardmäßig bleiben unbenannte Parameter in der Ausgabe unbenannt.\n"
              "Der Standardwert ist: YES."
          );
  doc->add(
              "HIDE_UNDOC_MEMBERS",
              "Wenn das HIDE_UNDOC_MEMBERS-Tag auf YES gesetzt ist, blendet Doxygen alle\n"
              "undokumentierten Mitglieder innerhalb dokumentierter Klassen oder Dateien aus.\n"
              "Wenn auf NO gesetzt, werden diese Mitglieder in die verschiedenen Übersichten\n"
              "aufgenommen, aber es wird kein Dokumentationsabschnitt generiert. Diese Option\n"
              "hat keine Auswirkung, wenn EXTRACT_ALL aktiviert ist.\n"
              "Der Standardwert ist: NO."
          );
  doc->add(
              "HIDE_UNDOC_CLASSES",
              "Wenn das HIDE_UNDOC_CLASSES-Tag auf YES gesetzt ist, blendet Doxygen alle\n"
              "undokumentierten Klassen aus, die normalerweise in der Klassenhierarchie\n"
              "sichtbar sind. Wenn auf NO gesetzt, werden diese Klassen in den verschiedenen\n"
              "Übersichten aufgenommen. Diese Option blendet auch undokumentierte\n"
              "C++-Konzepte aus, falls aktiviert. Diese Option hat keine Auswirkung, wenn\n"
              "EXTRACT_ALL aktiviert ist.\n"
              "Der Standardwert ist: NO."
          );
  doc->add(
              "HIDE_UNDOC_NAMESPACES",
              "Wenn das HIDE_UNDOC_NAMESPACES-Tag auf YES gesetzt ist, blendet Doxygen alle\n"
              "undokumentierten Namensbereiche aus, die normalerweise in der Namensbereich-\n"
              "Hierarchie sichtbar sind. Wenn auf NO gesetzt, werden diese Namensbereiche in\n"
              "die verschiedenen Übersichten aufgenommen. Diese Option hat keine Auswirkung,\n"
              "wenn EXTRACT_ALL aktiviert ist.\n"
              "Der Standardwert ist: YES."
          );
  doc->add(
              "HIDE_FRIEND_COMPOUNDS",
              "Wenn das HIDE_FRIEND_COMPOUNDS-Tag auf YES gesetzt ist, werden alle Friend-\n"
              "Deklarationen ausgeblendet. Wenn auf NO gesetzt, werden diese Deklarationen in\n"
              "die Dokumentation aufgenommen.\n"
              "Der Standardwert ist: NO."
          );
  doc->add(
              "HIDE_IN_BODY_DOCS",
              "Wenn das HIDE_IN_BODY_DOCS-Tag auf YES gesetzt ist, wird Doxygen alle\n"
              "Dokumentationsblöcke ausblenden, die im Körper einer Funktion gefunden werden.\n"
              "Wenn auf NO gesetzt, werden diese Blöcke an den detaillierten\n"
              "Dokumentationsblock der Funktion angehängt.\n"
              "Der Standardwert ist: NO."
          );
  doc->add(
              "INTERNAL_DOCS",
              "Das INTERNAL_DOCS-Tag bestimmt, ob Dokumentation, die nach einem \\internal-\n"
              "Befehl geschrieben wird, einbezogen wird. Wenn das Tag auf NO gesetzt ist,\n"
              "wird die Dokumentation ausgeschlossen. Setzen Sie es auf YES, um die interne\n"
              "Dokumentation einzubeziehen.\n"
              "Der Standardwert ist: NO."
          );
  doc->add(
              "CASE_SENSE_NAMES",
              "Mit der korrekten Einstellung der Option CASE_SENSE_NAMES wird Doxygen die\n"
              "Fähigkeiten des zugrunde liegenden Dateisystems besser nutzen können. Im Fall\n"
              "eines Dateisystems, das zwischen Groß- und Kleinschreibung unterscheidet (d.h.\n"
              "es unterstützt Dateien im selben Verzeichnis, deren Namen sich nur in der\n"
              "Groß-/Kleinschreibung unterscheiden), muss die Option auf YES gesetzt werden,\n"
              "um solche Dateien ordnungsgemäß zu behandeln, falls sie in der Eingabe\n"
              "erscheinen. Für Dateisysteme, die nicht zwischen Groß- und Kleinschreibung\n"
              "unterscheiden, sollte die Option auf NO gesetzt werden, um Ausgabedateien für\n"
              "Symbole zu behandeln, die sich nur in der Groß-/Kleinschreibung unterscheiden.\n"
              "Auf Windows (einschließlich Cygwin) und macOS sollten Benutzer diese Option\n"
              "typischerweise auf NO setzen, während auf Linux oder anderen Unix-Varianten\n"
              "sie typischerweise auf YES gesetzt werden sollte.\n"
              "Mögliche Werte sind: SYSTEM, NO und YES.\n"
              "Der Standardwert ist: SYSTEM."
          );
  doc->add(
              "HIDE_SCOPE_NAMES",
              "Wenn das HIDE_SCOPE_NAMES-Tag auf NO gesetzt ist, zeigt Doxygen Mitglieder mit\n"
              "ihren vollständigen Klassen- und Namensbereichen in der Dokumentation an. Wenn\n"
              "auf YES gesetzt, wird der Bereich ausgeblendet.\n"
              "Der Standardwert ist: NO."
          );
  doc->add(
              "HIDE_COMPOUND_REFERENCE",
              "Wenn das HIDE_COMPOUND_REFERENCE-Tag auf NO (Standard) gesetzt ist, wird\n"
              "Doxygen zusätzlichen Text an den Titel einer Seite anhängen, wie z.B.\n"
              "Klassenreferenz. Wenn auf YES gesetzt, wird die Verbundreferenz ausgeblendet.\n"
              "Der Standardwert ist: NO."
          );
  doc->add(
              "SHOW_HEADERFILE",
              "Wenn das SHOW_HEADERFILE-Tag auf YES gesetzt ist, zeigt die Dokumentation für\n"
              "eine Klasse an, welche Datei eingebunden werden muss, um die Klasse zu\n"
              "verwenden.\n"
              "Der Standardwert ist: YES."
          );
  doc->add(
              "SHOW_INCLUDE_FILES",
              "Wenn das SHOW_INCLUDE_FILES-Tag auf YES gesetzt ist, wird Doxygen eine Liste\n"
              "der Dateien anzeigen, die von einer Datei eingebunden werden, in der\n"
              "Dokumentation dieser Datei.\n"
              "Der Standardwert ist: YES."
          );
  doc->add(
              "SHOW_GROUPED_MEMB_INC",
              "Wenn das SHOW_GROUPED_MEMB_INC-Tag auf YES gesetzt ist, werden Include-\n"
              "Abhängigkeiten für Gruppenmitglieder in der Dokumentation angezeigt.\n"
              "Der Standardwert ist: NO."
          );
  doc->add(
              "FORCE_LOCAL_INCLUDES",
              "Wenn das FORCE_LOCAL_INCLUDES-Tag auf YES gesetzt ist, wird Doxygen Include-\n"
              "Dateien mit doppelten Anführungszeichen in der Dokumentation auflisten,\n"
              "anstatt mit spitzen Klammern.\n"
              "Der Standardwert ist: NO."
          );
  doc->add(
              "INLINE_INFO",
              "Wenn das INLINE_INFO-Tag auf YES gesetzt ist, wird ein Tag [inline] in die\n"
              "Dokumentation für Inline-Mitglieder eingefügt.\n"
              "Der Standardwert ist: YES."
          );
  doc->add(
              "SORT_MEMBER_DOCS",
              "Wenn das SORT_MEMBER_DOCS-Tag auf YES gesetzt ist, wird Doxygen die\n"
              "(detaillierte) Dokumentation von Datei- und Klassenmitgliedern alphabetisch\n"
              "nach Mitgliedsnamen sortieren. Wenn auf NO gesetzt, erscheinen die Mitglieder\n"
              "in Deklarationsreihenfolge.\n"
              "Der Standardwert ist: YES."
          );
  doc->add(
              "SORT_BRIEF_DOCS",
              "Wenn das SORT_BRIEF_DOCS-Tag auf YES gesetzt ist, wird Doxygen die\n"
              "Kurzbeschreibungen von Datei-, Namensbereich- und Klassenmitgliedern\n"
              "alphabetisch nach Mitgliedsnamen sortieren. Wenn auf NO gesetzt, erscheinen\n"
              "die Mitglieder in Deklarationsreihenfolge. Beachten Sie, dass dies auch die\n"
              "Reihenfolge der Klassen in der Klassenliste beeinflusst.\n"
              "Der Standardwert ist: NO."
          );
  doc->add(
              "SORT_MEMBERS_CTORS_1ST",
              "Wenn das SORT_MEMBERS_CTORS_1ST-Tag auf YES gesetzt ist, wird Doxygen die\n"
              "(Kurz- und detaillierte) Dokumentation von Klassenmitgliedern so sortieren,\n"
              "dass Konstruktoren und Destruktoren zuerst aufgeführt werden. Wenn auf NO\n"
              "gesetzt, erscheinen die Konstruktoren in den jeweiligen Reihenfolgen, die\n"
              "durch SORT_BRIEF_DOCS und SORT_MEMBER_DOCS definiert sind.\n"
              "Hinweis: Wenn SORT_BRIEF_DOCS auf NO gesetzt ist, wird diese Option beim\n"
              "Sortieren der kurzen Mitgliedsdokumentation ignoriert.\n"
              "Hinweis: Wenn SORT_MEMBER_DOCS auf NO gesetzt ist, wird diese Option beim\n"
              "Sortieren der detaillierten Mitgliedsdokumentation ignoriert.\n"
              "Der Standardwert ist: NO."
          );
  doc->add(
              "SORT_GROUP_NAMES",
              "Wenn das SORT_GROUP_NAMES-Tag auf YES gesetzt ist, wird Doxygen die Hierarchie\n"
              "der Gruppennamen in alphabetische Reihenfolge sortieren. Wenn auf NO gesetzt,\n"
              "erscheinen die Gruppennamen in ihrer definierten Reihenfolge.\n"
              "Der Standardwert ist: NO."
          );
  doc->add(
              "SORT_BY_SCOPE_NAME",
              "Wenn das SORT_BY_SCOPE_NAME-Tag auf YES gesetzt ist, wird die Klassenliste\n"
              "nach vollqualifizierten Namen sortiert, einschließlich Namensbereiche. Wenn\n"
              "auf NO gesetzt, wird die Klassenliste nur nach Klassennamen sortiert, ohne den\n"
              "Namensbereichteil.\n"
              "Hinweis: Diese Option ist nicht sehr nützlich, wenn HIDE_SCOPE_NAMES auf YES\n"
              "gesetzt ist.\n"
              "Hinweis: Diese Option gilt nur für die Klassenliste, nicht für die\n"
              "alphabetische Liste.\n"
              "Der Standardwert ist: NO."
          );
  doc->add(
              "STRICT_PROTO_MATCHING",
              "Wenn die STRICT_PROTO_MATCHING-Option aktiviert ist und Doxygen keine korrekte\n"
              "Typauflösung aller Parameter einer Funktion durchführen kann, wird eine\n"
              "Übereinstimmung zwischen dem Prototyp und der Implementierung einer\n"
              "Mitgliedsfunktion abgelehnt, selbst wenn es nur einen Kandidaten gibt oder es\n"
              "offensichtlich ist, welcher Kandidat durch einen einfachen\n"
              "Zeichenfolgenabgleich zu wählen ist. Durch Deaktivieren von\n"
              "STRICT_PROTO_MATCHING akzeptiert Doxygen in solchen Fallen weiterhin eine\n"
              "Übereinstimmung zwischen Prototyp und Implementierung.\n"
              "Der Standardwert ist: NO."
          );
  doc->add(
              "GENERATE_TODOLIST",
              "Das GENERATE_TODOLIST-Tag kann verwendet werden, um die Todo-Liste zu\n"
              "aktivieren (YES) oder zu deaktivieren (NO). Diese Liste wird erstellt, indem\n"
              "\\todo-Befehle in der Dokumentation platziert werden.\n"
              "Der Standardwert ist: YES."
          );
  doc->add(
              "GENERATE_TESTLIST",
              "Das GENERATE_TESTLIST-Tag kann verwendet werden, um die Testliste zu\n"
              "aktivieren (YES) oder zu deaktivieren (NO). Diese Liste wird erstellt, indem\n"
              "\\test-Befehle in der Dokumentation platziert werden.\n"
              "Der Standardwert ist: YES."
          );
  doc->add(
              "GENERATE_BUGLIST",
              "Das GENERATE_BUGLIST-Tag kann verwendet werden, um die Bug-Liste zu aktivieren\n"
              "(YES) oder zu deaktivieren (NO). Diese Liste wird erstellt, indem \\bug-Befehle\n"
              "in der Dokumentation platziert werden.\n"
              "Der Standardwert ist: YES."
          );
  doc->add(
              "GENERATE_DEPRECATEDLIST",
              "Das GENERATE_DEPRECATEDLIST-Tag kann verwendet werden, um die Veraltet-Liste\n"
              "zu aktivieren (YES) oder zu deaktivieren (NO). Diese Liste wird erstellt,\n"
              "indem \\deprecated-Befehle in der Dokumentation platziert werden.\n"
              "Der Standardwert ist: YES."
          );
  doc->add(
              "GENERATE_REQUIREMENTS",
              "Das GENERATE_REQUIREMENTS-Tag kann verwendet werden, um die Anforderungen-\n"
              "Seite zu aktivieren (YES) oder zu deaktivieren (NO). Wenn aktiviert, wird\n"
              "diese Seite automatisch erstellt, wenn mindestens ein Kommentarblock mit einem\n"
              "\\requirement-Befehl in der Eingabe erscheint.\n"
              "Der Standardwert ist: YES."
          );
  doc->add(
              "REQ_TRACEABILITY_INFO",
              "Das REQ_TRACEABILITY_INFO-Tag steuert, ob Rückverfolgbarkeitsinformationen auf\n"
              "der Anforderungen-Seite angezeigt werden (nur relevant bei Verwendung von\n"
              "\\requirement-Kommentarblöcken). Die Einstellung NO deaktiviert die\n"
              "Rückverfolgbarkeitsinformationen vollständig. Die Einstellung UNSATISFIED_ONLY\n"
              "zeigt eine Liste von Anforderungen an, denen eine satisfies-Beziehung fehlt\n"
              "(über den Befehl: \\satisfies). Ähnlich zeigt die Einstellung UNVERIFIED_ONLY\n"
              "eine Liste von Anforderungen an, denen eine verifies-Beziehung fehlt (über den\n"
              "Befehl: \\verifies). Das Setzen des Tags auf YES (der Standard) zeigt beide\n"
              "Listen an, falls zutreffend.\n"
              "Mögliche Werte sind: YES, NO, UNSATISFIED_ONLY und UNVERIFIED_ONLY.\n"
              "Der Standardwert ist: YES.\n"
              "Dieses Tag erfordert, dass das Tag GENERATE_REQUIREMENTS auf YES gesetzt ist."
          );
  doc->add(
              "ENABLED_SECTIONS",
              "Das ENABLED_SECTIONS-Tag kann verwendet werden, um bedingte\n"
              "Dokumentationsabschnitte zu aktivieren, die mit \\if <section_label> ... \\endif\n"
              "und \\cond <section_label> ... \\endcond Blöcken markiert sind."
          );
  doc->add(
              "MAX_INITIALIZER_LINES",
              "Das MAX_INITIALIZER_LINES-Tag bestimmt die maximale Anzahl von Zeilen, die der\n"
              "Anfangswert einer Variable oder eines Makros / Defines haben darf, um in der\n"
              "Dokumentation zu erscheinen. Wenn der Initialisierer aus mehr Zeilen besteht\n"
              "als hier angegeben, wird er ausgeblendet. Verwenden Sie den Wert 0, um\n"
              "Initialisierer vollständig auszublenden. Das Erscheinen des Werts einzelner\n"
              "Variablen und Makros / Defines kann mit dem Befehl \\showinitializer oder\n"
              "\\hideinitializer in der Dokumentation gesteuert werden, unabhängig von dieser\n"
              "Einstellung.\n"
              "Mindestwert: 0, Höchstwert: 10000, Standardwert: 30."
          );
  doc->add(
              "SHOW_USED_FILES",
              "Setzen Sie das SHOW_USED_FILES-Tag auf NO, um die Liste der Dateien, die am\n"
              "Ende der Dokumentation einer Klasse angezeigt werden, zu deaktivieren.\n"
              "Der Standardwert ist: YES."
          );
  doc->add(
              "SHOW_FILES",
              "Wenn das SHOW_FILES-Tag auf NO gesetzt ist, wird die Dateiliste nicht\n"
              "generiert. Dies spart Zeit, wenn Sie eine sehr große Anzahl von Dateien haben\n"
              "und die Dateiliste nicht benötigen.\n"
              "Der Standardwert ist: YES."
          );
  doc->add(
              "SHOW_NAMESPACES",
              "Wenn das SHOW_NAMESPACES-Tag auf NO gesetzt ist, wird die Namensbereich-Liste\n"
              "nicht generiert. Dies spart Zeit, wenn Sie eine sehr große Anzahl von\n"
              "Namensbereichen haben und die Namensbereich-Liste nicht benötigen.\n"
              "Der Standardwert ist: YES."
          );
  doc->add(
              "FILE_VERSION_FILTER",
              "Das FILE_VERSION_FILTER-Tag kann verwendet werden, um ein Programm oder Skript\n"
              "anzugeben, das Doxygen aufrufen soll, um die aktuelle Version für jede Datei\n"
              "zu erhalten (typischerweise vom Versionskontrollsystem). Doxygen ruft das\n"
              "Programm auf, indem es (über popen()) den Befehl command input_file ausführt,\n"
              "wobei command der Wert des FILE_VERSION_FILTER-Tags ist und input_file der\n"
              "Name einer von Doxygen bereitgestellten Eingabedatei ist. Was auch immer das\n"
              "Programm auf die Standardausgabe schreibt, wird als Dateiversion verwendet.\n"
              "Für ein Beispiel siehe die Dokumentation."
          );
  doc->add(
              "LAYOUT_FILE",
              "Das LAYOUT_FILE-Tag kann verwendet werden, um eine Layout-Datei anzugeben, die\n"
              "von Doxygen geparst wird. Die Layout-Datei steuert die globale Struktur der\n"
              "generierten Ausgabedateien in einer ausgabeformatunabhängigen Weise. Um die\n"
              "Layout-Datei zu erstellen, die Doxygens Standards repräsentiert, führen Sie\n"
              "Doxygen mit der Option -l aus. Sie können optional einen Dateinamen nach der\n"
              "Option angeben, wenn weggelassen wird DoxygenLayout.xml als Name der Layout-\n"
              "Datei verwendet. Siehe auch Abschnitt \"Changing the layout of pages\" für\n"
              "Informationen.\n"
              "\n"
              "Beachten Sie, dass Doxygen automatisch eine Datei namens DoxygenLayout.xml\n"
              "analysiert, wenn Sie Doxygen aus einem Verzeichnis ausführen, das diese Datei\n"
              "enthält, auch wenn das LAYOUT_FILE-Tag leer gelassen wird."
          );
  doc->add(
              "CITE_BIB_FILES",
              "Das CITE_BIB_FILES-Tag kann verwendet werden, um eine oder mehrere bib-Dateien\n"
              "anzugeben, die die Referenzdefinitionen enthalten. Dies muss eine Liste von\n"
              ".bib-Dateien sein. Die .bib-Erweiterung wird automatisch angehängt, wenn\n"
              "weggelassen. Dies erfordert, dass das bibtex-Tool installiert ist. Siehe auch\n"
              "https://en.wikipedia.org/wiki/BibTeX für weitere Informationen. Für LaTeX kann\n"
              "der Stil der Bibliographie mit LATEX_BIB_STYLE gesteuert werden. Um diese\n"
              "Funktion zu nutzen, benötigen Sie bibtex und perl im Suchpfad. Siehe auch\n"
              "\\cite für Informationen zum Erstellen von Referenzen."
          );
  doc->add(
              "EXTERNAL_TOOL_PATH",
              "Das EXTERNAL_TOOL_PATH-Tag kann verwendet werden, um den Suchpfad (PATH-\n"
              "Umgebungsvariable) zu erweitern, damit externe Tools wie latex und gs gefunden\n"
              "werden können.\n"
              "Hinweis: Mit EXTERNAL_TOOL_PATH angegebene Verzeichnisse werden vor den\n"
              "bereits durch die PATH-Variable angegebenen Pfad hinzugefügt und in der\n"
              "angegebenen Reihenfolge hinzugefügt.\n"
              "Hinweis: Diese Option ist besonders nützlich für macOS Version 14 (Sonoma) und\n"
              "höher, wenn Doxygen von Doxywizard ausgeführt wird, da in diesem Fall alle\n"
              "benutzerdefinierten Änderungen an PATH ignoriert werden. Ein typisches\n"
              "Beispiel auf macOS ist die Einstellung\n"
              "EXTERNAL_TOOL_PATH = /Library/TeX/texbin /usr/local/bin\n"
              "Zusammen mit dem Standardpfad wird der vollständige Suchpfad, den Doxygen\n"
              "beim Starten externer Tools verwendet, zu\n"
              "PATH=/Library/TeX/texbin:/usr/local/bin:/usr/bin:/bin:/usr/sbin:/sbin"
          );
  doc->add(
              "QUIET",
              "Das QUIET-Tag kann verwendet werden, um die Nachrichten ein- oder\n"
              "auszuschalten, die von Doxygen auf die Standardausgabe generiert werden. Wenn\n"
              "QUIET auf YES gesetzt ist, bedeutet dies, dass die Nachrichten ausgeschaltet\n"
              "sind.\n"
              "Der Standardwert ist: NO."
          );
  doc->add(
              "WARNINGS",
              "Das WARNINGS-Tag kann verwendet werden, um die Warnmeldungen ein- oder\n"
              "auszuschalten, die von Doxygen auf die Standardfehlerausgabe (stderr)\n"
              "generiert werden. Wenn WARNINGS auf YES gesetzt ist, bedeutet dies, dass die\n"
              "Warnungen eingeschaltet sind.\n"
              "\n"
              "Tipp: Schalten Sie Warnungen ein, während Sie die Dokumentation schreiben.\n"
              "Der Standardwert ist: YES."
          );
  doc->add(
              "WARN_IF_UNDOCUMENTED",
              "Wenn das WARN_IF_UNDOCUMENTED-Tag auf YES gesetzt ist, generiert Doxygen\n"
              "Warnungen für undokumentierte Mitglieder. Wenn EXTRACT_ALL auf YES gesetzt\n"
              "ist, wird dieses Tag automatisch deaktiviert.\n"
              "Der Standardwert ist: YES."
          );
  doc->add(
              "WARN_IF_DOC_ERROR",
              "Wenn das WARN_IF_DOC_ERROR-Tag auf YES gesetzt ist, generiert Doxygen\n"
              "Warnungen für potenzielle Fehler in der Dokumentation, wie z.B. das zweimalige\n"
              "Dokumentieren einiger Parameter in einer dokumentierten Funktion, das\n"
              "Dokumentieren nicht vorhandener Parameter oder das falsche Verwenden von\n"
              "Markup-Befehlen.\n"
              "Der Standardwert ist: YES."
          );
  doc->add(
              "WARN_IF_INCOMPLETE_DOC",
              "Wenn WARN_IF_INCOMPLETE_DOC auf YES gesetzt ist, warnt Doxygen vor\n"
              "unvollständiger Funktionsparameter-Dokumentation. Wenn auf NO gesetzt,\n"
              "akzeptiert Doxygen, dass einige Parameter keine Dokumentation haben, ohne zu\n"
              "warnen.\n"
              "Der Standardwert ist: YES."
          );
  doc->add(
              "WARN_NO_PARAMDOC",
              "Diese WARN_NO_PARAMDOC-Option kann aktiviert werden, um Warnungen für\n"
              "Funktionen zu erhalten, die dokumentiert sind, aber keine Dokumentation für\n"
              "ihre Parameter oder Rückgabewerte haben. Wenn auf NO gesetzt, warnt Doxygen\n"
              "nur über falsche Parameterdokumentation, aber nicht über das Fehlen von\n"
              "Dokumentation. Wenn EXTRACT_ALL auf YES gesetzt ist, wird dieses Tag\n"
              "automatisch deaktiviert. Siehe auch WARN_IF_INCOMPLETE_DOC\n"
              "Der Standardwert ist: NO."
          );
  doc->add(
              "WARN_IF_UNDOC_ENUM_VAL",
              "Wenn die WARN_IF_UNDOC_ENUM_VAL-Option auf YES gesetzt ist, warnt Doxygen vor\n"
              "undokumentierten Aufzählungswerten. Wenn auf NO gesetzt, akzeptiert Doxygen\n"
              "undokumentierte Aufzählungswerte. Wenn EXTRACT_ALL auf YES gesetzt ist, wird\n"
              "dieses Tag automatisch deaktiviert.\n"
              "Der Standardwert ist: NO."
          );
  doc->add(
              "WARN_LAYOUT_FILE",
              "Wenn die WARN_LAYOUT_FILE-Option auf YES gesetzt ist, warnt Doxygen vor\n"
              "Problemen, die beim Parsen der benutzerdefinierten Layout-Datei gefunden\n"
              "wurden, wie fehlende oder falsche Elemente. Siehe auch LAYOUT_FILE für\n"
              "Details. Wenn auf NO gesetzt, werden Probleme mit der Layout-Datei\n"
              "unterdrückt.\n"
              "Der Standardwert ist: YES."
          );
  doc->add(
              "WARN_AS_ERROR",
              "Wenn das WARN_AS_ERROR-Tag auf YES gesetzt ist, stoppt Doxygen sofort, wenn\n"
              "eine Warnung auftritt. Wenn das WARN_AS_ERROR-Tag auf FAIL_ON_WARNINGS gesetzt\n"
              "ist, fährt Doxygen fort, als ob das WARN_AS_ERROR-Tag auf NO gesetzt wurde,\n"
              "aber am Ende des Doxygen-Prozesses kehrt Doxygen mit einem Status ungleich\n"
              "Null zurück. Wenn das WARN_AS_ERROR-Tag auf FAIL_ON_WARNINGS_PRINT gesetzt\n"
              "ist, verhält sich Doxygen wie FAIL_ON_WARNINGS, aber falls keine WARN_LOGFILE\n"
              "definiert ist, schreibt Doxygen die Warnmeldungen nicht zwischen andere\n"
              "Nachrichten, sondern schreibt sie am Ende eines Laufs. Falls eine WARN_LOGFILE\n"
              "definiert ist, werden die Warnmeldungen zusätzlich zur definierten Datei auch\n"
              "am Ende eines Laufs angezeigt, es sei denn, die WARN_LOGFILE ist als -\n"
              "definiert, d.h. Standardausgabe (stdout), in diesem Fall bleibt das Verhalten\n"
              "wie bei der Einstellung FAIL_ON_WARNINGS.\n"
              "Mögliche Werte sind: NO, YES, FAIL_ON_WARNINGS und FAIL_ON_WARNINGS_PRINT.\n"
              "Der Standardwert ist: NO."
          );
  doc->add(
              "WARN_FORMAT",
              "Das WARN_FORMAT-Tag bestimmt das Format der Warnmeldungen, die Doxygen\n"
              "erzeugen kann. Die Zeichenfolge sollte die Tags $file, $line und $text\n"
              "enthalten, die durch die Datei und Zeilennummer, von der die Warnung stammt,\n"
              "und die Warnmeldung ersetzt werden. Optional kann das Format $version\n"
              "enthalten, das durch die Version der Datei ersetzt wird (falls sie über\n"
              "FILE_VERSION_FILTER ermittelt werden konnte).\n"
              "Siehe auch: WARN_LINE_FORMAT\n"
              "Der Standardwert ist: $file:$line: $text."
          );
  doc->add(
              "WARN_LINE_FORMAT",
              "Im $text-Teil des WARN_FORMAT-Befehls ist es möglich, dass ein Verweis auf\n"
              "einen spezifischeren Ort angegeben wird. Um das Springen zu diesem Ort\n"
              "(außerhalb von Doxygen) zu erleichtern, kann der Benutzer eine\n"
              "benutzerdefinierte \"Ausschneiden\"/\"Einfügen\"-Zeichenfolge definieren.\n"
              "Beispiel:\n"
              "WARN_LINE_FORMAT = \"'vi $file +$line'\"\n"
              "Siehe auch: WARN_FORMAT\n"
              "Der Standardwert ist: at line $line of file $file."
          );
  doc->add(
              "WARN_LOGFILE",
              "Das WARN_LOGFILE-Tag kann verwendet werden, um eine Datei anzugeben, in die\n"
              "Warn- und Fehlermeldungen geschrieben werden sollen. Wenn leer gelassen, wird\n"
              "die Ausgabe auf die Standardfehlerausgabe (stderr) geschrieben. Falls die\n"
              "angegebene Datei nicht zum Schreiben geöffnet werden kann, werden die Warn-\n"
              "und Fehlermeldungen auf die Standardfehlerausgabe geschrieben. Wenn die Datei\n"
              "- angegeben wird, werden die Warn- und Fehlermeldungen auf die Standardausgabe\n"
              "(stdout) geschrieben."
          );
  doc->add(
              "INPUT",
              "Das INPUT-Tag wird verwendet, um die Dateien und/oder Verzeichnisse anzugeben,\n"
              "die die Quellcode- und anderen Dokumentationsdateien enthalten. Sie können\n"
              "Dateinamen wie myfile.cpp oder Verzeichnisse wie /usr/src/myproject eingeben.\n"
              "Trennen Sie die Dateien oder Verzeichnisse durch Leerzeichen. Siehe auch\n"
              "FILE_PATTERNS und EXTENSION_MAPPING.\n"
              "Hinweis: Wenn dieses Tag leer ist, wird das aktuelle Verzeichnis durchsucht."
          );
  doc->add(
              "INPUT_ENCODING",
              "Dieses Tag kann verwendet werden, um die Zeichencodierung der Quelldateien\n"
              "anzugeben, die Doxygen analysiert. Intern verwendet Doxygen die\n"
              "UTF-8-Codierung. Doxygen verwendet libiconv (oder das in libc eingebaute\n"
              "iconv) für die Transkodierung. Siehe die libiconv-Dokumentation (see:\n"
              "https://www.gnu.org/software/libiconv/) für die Liste der möglichen\n"
              "Codierungen.\n"
              "Siehe auch: INPUT_FILE_ENCODING\n"
              "Der Standardwert ist: UTF-8."
          );
  doc->add(
              "INPUT_FILE_ENCODING",
              "Dieses Tag kann verwendet werden, um die Zeichencodierung der Quelldateien\n"
              "anzugeben, die Doxygen analysiert. Das INPUT_FILE_ENCODING-Tag kann verwendet\n"
              "werden, um die Zeichencodierung pro Dateimuster anzugeben. Doxygen vergleicht\n"
              "den Dateinamen mit jedem Muster und wendet die Codierung anstelle der\n"
              "Standard-INPUT_ENCODING an, wenn eine Übereinstimmung vorliegt. Die\n"
              "Zeichencodierungen sind eine Liste der Form: Muster=Codierung (wie\n"
              "*.php=ISO-8859-1).\n"
              "Siehe auch: INPUT_ENCODING für weitere Informationen zu unterstützten\n"
              "Codierungen."
          );
  doc->add(
              "FILE_PATTERNS",
              "Wenn der Wert des INPUT-Tags Verzeichnisse enthält, können Sie das\n"
              "FILE_PATTERNS-Tag verwenden, um ein oder mehrere Wildcard-Muster (wie *.cpp\n"
              "und *.h) anzugeben, um die Quelldateien in den Verzeichnissen zu filtern.\n"
              "\n"
              "Beachten Sie, dass Sie für benutzerdefinierte Erweiterungen oder nicht direkt\n"
              "unterstützte Erweiterungen auch EXTENSION_MAPPING für die Erweiterung setzen\n"
              "müssen, sonst werden die Dateien von Doxygen nicht gelesen.\n"
              "\n"
              "Beachten Sie, dass die Liste der standardmäßig geprüften Dateimuster von der\n"
              "Liste der Standard-Dateierweiterungszuordnungen abweichen kann.\n"
              "\n"
              "Wenn leer gelassen, werden die folgenden Muster geprüft:*.c, *.cc, *.cxx,\n"
              "*.cxxm, *.cpp, *.cppm, *.ccm, *.c++, *.c++m, *.java, *.ii, *.ixx, *.ipp,\n"
              "*.i++, *.inl, *.idl, *.ddl, *.odl, *.h, *.hh, *.hxx, *.hpp, *.h++, *.l, *.cs,\n"
              "*.d, *.php, *.php4, *.php5, *.phtml, *.inc, *.m, *.markdown, *.md, *.mm, *.dox\n"
              "(to be provided as Doxygen C comment), *.py, *.pyw, *.f90, *.f95, *.f03,\n"
              "*.f08, *.f18, *.f, *.for, *.vhd, *.vhdl, *.ucf, *.qsf und *.ice."
          );
  doc->add(
              "RECURSIVE",
              "Das RECURSIVE-Tag kann verwendet werden, um anzugeben, ob Unterverzeichnisse\n"
              "ebenfalls nach Eingabedateien durchsucht werden sollen.\n"
              "Der Standardwert ist: NO."
          );
  doc->add(
              "EXCLUDE",
              "Das EXCLUDE-Tag kann verwendet werden, um Dateien und/oder Verzeichnisse\n"
              "anzugeben, die von den INPUT-Quelldateien ausgeschlossen werden sollen. Auf\n"
              "diese Weise können Sie einfach ein Unterverzeichnis aus einem Verzeichnisbaum\n"
              "ausschließen, dessen Wurzel mit dem INPUT-Tag angegeben ist.\n"
              "\n"
              "Beachten Sie, dass relative Pfade relativ zu dem Verzeichnis sind, aus dem\n"
              "Doxygen ausgeführt wird."
          );
  doc->add(
              "EXCLUDE_SYMLINKS",
              "Das EXCLUDE_SYMLINKS-Tag kann verwendet werden, um auszuwählen, ob Dateien\n"
              "oder Verzeichnisse, die symbolische Links sind, von der Eingabe ausgeschlossen\n"
              "werden.\n"
              "Der Standardwert ist: NO."
          );
  doc->add(
              "EXCLUDE_PATTERNS",
              "Wenn der Wert des INPUT-Tags Verzeichnisse enthält, können Sie das\n"
              "EXCLUDE_PATTERNS-Tag verwenden, um ein oder mehrere Wildcard-Muster anzugeben,\n"
              "um bestimmte Dateien aus diesen Verzeichnissen auszuschließen."
          );
  doc->add(
              "EXCLUDE_SYMBOLS",
              "Das EXCLUDE_SYMBOLS-Tag kann verwendet werden, um einen oder mehrere\n"
              "Symbolnamen anzugeben, die von der Ausgabe ausgeschlossen werden sollen. Das\n"
              "Symbol kann ein Name einer Funktion, einer Variable, einer Struktur, eines\n"
              "Typedefs usw. sein."
          );
  doc->add(
              "EXAMPLE_PATH",
              "Das EXAMPLE_PATH-Tag kann verwendet werden, um eine oder mehrere Dateien oder\n"
              "Verzeichnisse anzugeben, die Beispielcode-Fragmente enthalten."
          );
  doc->add(
              "EXAMPLE_PATTERNS",
              "Wenn der Wert des EXAMPLE_PATH-Tags Verzeichnisse enthält, können Sie das\n"
              "EXAMPLE_PATTERNS-Tag verwenden, um ein oder mehrere Wildcard-Muster anzugeben,\n"
              "um die Quelldateien in den Verzeichnissen zu filtern."
          );
  doc->add(
              "EXAMPLE_RECURSIVE",
              "Wenn das EXAMPLE_RECURSIVE-Tag auf YES gesetzt ist, werden Unterverzeichnisse\n"
              "nach Eingabedateien durchsucht. Wenn auf NO gesetzt, werden nur die im\n"
              "EXAMPLE_PATH-Tag angegebenen Verzeichnisse durchsucht.\n"
              "Der Standardwert ist: NO."
          );
  doc->add(
              "IMAGE_PATH",
              "Das IMAGE_PATH-Tag kann verwendet werden, um ein oder mehrere Verzeichnisse\n"
              "anzugeben, die Bilder enthalten, die in die Dokumentation eingebunden werden\n"
              "(siehe den Befehl \\image)."
          );
  doc->add(
              "INPUT_FILTER",
              "Das INPUT_FILTER-Tag kann verwendet werden, um ein Programm anzugeben, das\n"
              "Doxygen für jede Eingabedatei aufrufen soll. Doxygen ruft das Filterprogramm\n"
              "auf, indem es (über popen()) den Befehl ausführt:\n"
              "\n"
              "<filter> <input-file>\n"
              "\n"
              "wobei <filter> der Wert des INPUT_FILTER-Tags ist und <input-file> der Name\n"
              "einer Eingabedatei ist. Doxygen verwendet dann die Ausgabe, die das\n"
              "Filterprogramm auf die Standardausgabe schreibt. Wenn FILTER_PATTERNS\n"
              "angegeben ist, wird dieses Tag ignoriert.\n"
              "\n"
              "Beachten Sie, dass der Filter keine Zeilen hinzufügen oder entfernen darf; er\n"
              "wird angewendet, bevor der Code gescannt wird, aber nicht wenn der Ausgabecode\n"
              "generiert wird. Wenn Zeilen hinzugefügt oder entfernt werden, werden die Anker\n"
              "nicht korrekt platziert.\n"
              "\n"
              "Beachten Sie, dass Doxygen die verarbeiteten und auf die Standardausgabe\n"
              "geschriebenen Daten für die weitere Verarbeitung verwendet, daher sollte\n"
              "nichts anderes, wie Debug-Anweisungen oder verwendete Befehle (also im Fall\n"
              "einer Windows-Batch-Datei immer @echo OFF verwenden), auf die Standardausgabe\n"
              "geschrieben werden.\n"
              "\n"
              "Beachten Sie, dass für benutzerdefinierte Erweiterungen oder nicht direkt\n"
              "unterstützte Erweiterungen Sie auch EXTENSION_MAPPING für die Erweiterung\n"
              "setzen müssen, sonst werden die Dateien von Doxygen nicht korrekt verarbeitet.\n"
              ""
          );
  doc->add(
              "FILTER_PATTERNS",
              "Das FILTER_PATTERNS-Tag kann verwendet werden, um Filter auf Dateimusterbasis\n"
              "anzugeben. Doxygen vergleicht den Dateinamen mit jedem Muster und wendet den\n"
              "Filter an, wenn es eine Übereinstimmung gibt. Die Filter sind eine Liste der\n"
              "Form: muster=filter (wie *.cpp=my_cpp_filter). Siehe INPUT_FILTER für weitere\n"
              "Informationen zur Verwendung von Filtern. Wenn das FILTER_PATTERNS-Tag leer\n"
              "ist oder keines der Muster mit dem Dateinamen übereinstimmt, wird INPUT_FILTER\n"
              "angewendet.\n"
              "\n"
              "Beachten Sie, dass Sie für benutzerdefinierte Erweiterungen oder nicht direkt\n"
              "unterstützte Erweiterungen auch EXTENSION_MAPPING für die Erweiterung setzen\n"
              "müssen, sonst werden die Dateien von Doxygen nicht ordnungsgemäß verarbeitet.\n"
              ""
          );
  doc->add(
              "FILTER_SOURCE_FILES",
              "Wenn das FILTER_SOURCE_FILES-Tag auf YES gesetzt ist, wird der Eingabefilter\n"
              "(falls mit INPUT_FILTER gesetzt) auch verwendet, um die Eingabedateien zu\n"
              "filtern, die zum Erstellen der Quelldateien zum Durchsuchen verwendet werden\n"
              "(d.h. wenn SOURCE_BROWSER auf YES gesetzt ist).\n"
              "Der Standardwert ist: NO."
          );
  doc->add(
              "FILTER_SOURCE_PATTERNS",
              "Das FILTER_SOURCE_PATTERNS-Tag kann verwendet werden, um Quellfilter pro\n"
              "Dateimuster anzugeben. Ein Muster überschreibt die Einstellung für\n"
              "FILTER_PATTERN (falls vorhanden) und es ist auch möglich, die Quellfilterung\n"
              "für ein bestimmtes Muster mit *.ext= zu deaktivieren (also ohne einen Filter\n"
              "zu nennen).\n"
              "Dieses Tag erfordert, dass das Tag FILTER_SOURCE_FILES auf YES gesetzt ist."
          );
  doc->add(
              "USE_MDFILE_AS_MAINPAGE",
              "Wenn das USE_MDFILE_AS_MAINPAGE-Tag auf den Namen einer Markdown-Datei\n"
              "verweist, die Teil der Eingabe ist, wird ihr Inhalt auf der Hauptseite\n"
              "(index.html) platziert. Dies kann nützlich sein, wenn Sie ein Projekt\n"
              "beispielsweise auf GitHub haben und die README.md-Datei als Hauptseite\n"
              "wiederverwenden möchten."
          );
  doc->add(
              "IMPLICIT_DIR_DOCS",
              "Wenn das IMPLICIT_DIR_DOCS-Tag auf YES gesetzt ist, wird jede README.md-Datei,\n"
              "die in Unterverzeichnissen des Projektstamms gefunden wird, als Dokumentation\n"
              "für dieses Unterverzeichnis verwendet, außer wenn die README.md mit einem\n"
              "\\dir, \\page oder \\mainpage-Befehl beginnt. Wenn auf NO gesetzt, muss die\n"
              "README.md-Datei mit einem expliziten \\dir-Befehl beginnen, um als\n"
              "Verzeichnisdokumentation verwendet zu werden.\n"
              "Der Standardwert ist: YES."
          );
  doc->add(
              "FORTRAN_COMMENT_AFTER",
              "Der Fortran-Standard gibt an, dass für fest formatierten Fortran-Code alle\n"
              "Zeichen ab Position 72 als Kommentar betrachtet werden. Eine häufige\n"
              "Erweiterung ist es, längere Zeilen zu erlauben, bevor der automatische\n"
              "Kommentar beginnt. Die Einstellung FORTRAN_COMMENT_AFTER macht es auch\n"
              "möglich, dass längere Zeilen verarbeitet werden können, bevor der automatische\n"
              "Kommentar beginnt.\n"
              "Mindestwert: 7, Höchstwert: 10000, Standardwert: 72."
          );
  doc->add(
              "SOURCE_BROWSER",
              "Wenn das SOURCE_BROWSER-Tag auf YES gesetzt ist, wird eine Liste der\n"
              "Quelldateien generiert. Dokumentierte Entitäten werden mit diesen Quellen\n"
              "querverwiesen.\n"
              "\n"
              "Hinweis: Um den gesamten Quellcode in der generierten Ausgabe zu entfernen,\n"
              "stellen Sie sicher, dass auch VERBATIM_HEADERS auf NO gesetzt ist.\n"
              "Der Standardwert ist: NO."
          );
  doc->add(
              "INLINE_SOURCES",
              "Wenn das INLINE_SOURCES-Tag auf YES gesetzt ist, wird der Körper der\n"
              "Funktionen, Klassen und Namensbereiche direkt in die Dokumentation eingefügt.\n"
              "Der Standardwert ist: NO."
          );
  doc->add(
              "STRIP_CODE_COMMENTS",
              "Das Setzen des STRIP_CODE_COMMENTS-Tags auf YES weist Doxygen an, alle\n"
              "speziellen Kommentarblöcke aus generierten Quellcode-Fragmenten auszublenden.\n"
              "Normale C-, C++- und Fortran-Kommentare bleiben immer sichtbar.\n"
              "Der Standardwert ist: YES."
          );
  doc->add(
              "REFERENCED_BY_RELATION",
              "Wenn das REFERENCED_BY_RELATION-Tag auf YES gesetzt ist, wird für jede\n"
              "dokumentierte Entität alle dokumentierten Funktionen aufgelistet, die sie\n"
              "referenzieren.\n"
              "Der Standardwert ist: NO."
          );
  doc->add(
              "REFERENCES_RELATION",
              "Wenn das REFERENCES_RELATION-Tag auf YES gesetzt ist, wird für jede\n"
              "dokumentierte Funktion alle dokumentierten Entitäten aufgelistet, die von\n"
              "dieser Funktion aufgerufen/verwendet werden.\n"
              "Der Standardwert ist: NO."
          );
  doc->add(
              "REFERENCES_LINK_SOURCE",
              "Wenn das REFERENCES_LINK_SOURCE-Tag auf YES gesetzt ist und das\n"
              "SOURCE_BROWSER-Tag auf YES gesetzt ist, dann verweisen die Hyperlinks von\n"
              "Funktionen in den REFERENCES_RELATION- und REFERENCED_BY_RELATION-Listen auf\n"
              "den Quellcode. Andernfalls verweisen sie auf die Dokumentation.\n"
              "Der Standardwert ist: YES."
          );
  doc->add(
              "SOURCE_TOOLTIPS",
              "Wenn SOURCE_TOOLTIPS aktiviert ist (Standard), zeigt das Schweben über einem\n"
              "Hyperlink im Quellcode einen Tooltip mit zusätzlichen Informationen wie\n"
              "Prototyp, Kurzbeschreibung und Links zur Definition und Dokumentation an. Da\n"
              "dies die HTML-Datei großer macht und das Laden großer Dateien etwas langsamer,\n"
              "können Sie diese Funktion deaktivieren.\n"
              "Der Standardwert ist: YES.\n"
              "Dieses Tag erfordert, dass das Tag SOURCE_BROWSER auf YES gesetzt ist."
          );
  doc->add(
              "USE_HTAGS",
              "Wenn das USE_HTAGS-Tag auf YES gesetzt ist, verweisen die Referenzen auf den\n"
              "Quellcode auf das vom htags(1)-Tool generierte HTML anstelle des integrierten\n"
              "Quellcode-Browsers von Doxygen. Das htags-Tool ist Teil des globalen\n"
              "Quellcode-Tagging-Systems von GNU (siehe\n"
              "https://www.gnu.org/software/global/global.html). Sie benötigen Version 4.8.6\n"
              "oder höher.\n"
              "\n"
              "Um es zu verwenden, tun Sie Folgendes:\n"
              "- Installieren Sie die neueste Version von global\n"
              "- Aktivieren Sie SOURCE_BROWSER und USE_HTAGS in der Konfigurationsdatei\n"
              "- Stellen Sie sicher, dass INPUT auf die Wurzel des Quellbaums zeigt\n"
              "- Führen Sie doxygen wie gewohnt aus\n"
              "\n"
              "Doxygen ruft htags auf (und das wiederum ruft gtags auf), daher müssen diese\n"
              "Tools über die Befehlszeile verfügbar sein (d.h. im Suchpfad).\n"
              "\n"
              "Das Ergebnis: Anstelle des von Doxygen generierten Quellcode-Browsers zeigen\n"
              "die Links zum Quellcode jetzt auf die Ausgabe von htags.\n"
              "Der Standardwert ist: NO.\n"
              "Dieses Tag erfordert, dass das Tag SOURCE_BROWSER auf YES gesetzt ist."
          );
  doc->add(
              "VERBATIM_HEADERS",
              "Wenn das VERBATIM_HEADERS-Tag auf YES gesetzt ist, generiert Doxygen eine\n"
              "wörtliche Kopie der Header-Datei für jede Klasse, für die ein Include\n"
              "angegeben ist. Setzen Sie auf NO, um dies zu deaktivieren.\n"
              "Siehe auch: Abschnitt \\class.\n"
              "Der Standardwert ist: YES."
          );
  doc->add(
              "CLANG_ASSISTED_PARSING",
              "Wenn das CLANG_ASSISTED_PARSING-Tag auf YES gesetzt ist, verwendet Doxygen den\n"
              "clang-Parser für genaueres Parsing auf Kosten reduzierter Leistung.\n"
              "Der Standardwert ist: NO."
          );
  doc->add(
              "CLANG_ADD_INC_PATHS",
              "Wenn das CLANG_ASSISTED_PARSING-Tag auf YES gesetzt ist und das\n"
              "CLANG_ADD_INC_PATHS-Tag auf YES gesetzt ist, fügt Doxygen das Verzeichnis\n"
              "jeder Eingabe zum Include-Pfad hinzu.\n"
              "Der Standardwert ist: YES.\n"
              "Dieses Tag erfordert, dass das Tag CLANG_ASSISTED_PARSING auf YES gesetzt ist."
          );
  doc->add(
              "CLANG_OPTIONS",
              "Wenn clang-gestütztes Parsing aktiviert ist, können Sie dem Compiler\n"
              "Befehlszeilenoptionen bereitstellen, die Sie normalerweise beim Aufruf des\n"
              "Compilers verwenden würden. Beachten Sie, dass die Include-Pfade bereits von\n"
              "Doxygen für die mit INPUT und INCLUDE_PATH angegebenen Dateien und\n"
              "Verzeichnisse gesetzt werden.\n"
              "Dieses Tag erfordert, dass das Tag CLANG_ASSISTED_PARSING auf YES gesetzt ist."
          );
  doc->add(
              "CLANG_DATABASE_PATH",
              "Wenn clang-gestütztes Parsing aktiviert ist, können Sie dem clang-Parser den\n"
              "Pfad zum Verzeichnis mit einer Datei namens compile_commands.json\n"
              "bereitstellen. Diese Datei kann von CMake mit der Option\n"
              "CMAKE_EXPORT_COMPILE_COMMANDS generiert werden."
          );
  doc->add(
              "ALPHABETICAL_INDEX",
              "Wenn das ALPHABETICAL_INDEX-Tag auf YES gesetzt ist, wird ein alphabetischer\n"
              "Index aller Verbindungen generiert. Wenn Sie die EXTRACT_ALL und\n"
              "EXTRACT_PRIVATE Tags auf YES setzen, wird auch der Index aller internen\n"
              "Elemente generiert. Wenn Sie dies nicht möchten, können Sie IGNORE_PREFIX auf\n"
              "einen nicht-leeren Wert setzen.\n"
              "Der Standardwert ist: YES."
          );
  doc->add(
              "IGNORE_PREFIX",
              "Das IGNORE_PREFIX-Tag kann verwendet werden, um ein Präfix (oder eine Liste\n"
              "von Präfixen) anzugeben, das beim Generieren der Index-Header ignoriert werden\n"
              "soll. Das IGNORE_PREFIX-Tag funktioniert für Klassen-, Funktions- und\n"
              "Mitgliedsnamen. Die Entität wird in der alphabetischen Liste unter dem ersten\n"
              "Buchstaben des Entitätsnamens platziert, der nach dem Entfernen des Präfixes\n"
              "übrig bleibt.\n"
              "Dieses Tag erfordert, dass das Tag ALPHABETICAL_INDEX auf YES gesetzt ist."
          );
  doc->add(
              "GENERATE_HTML",
              "Wenn das GENERATE_HTML-Tag auf YES gesetzt ist, generiert Doxygen HTML-\n"
              "Ausgabe.\n"
              "Der Standardwert ist: YES."
          );
  doc->add(
              "HTML_OUTPUT",
              "Das HTML_OUTPUT-Tag wird verwendet, um anzugeben, wo die HTML-Dokumente\n"
              "platziert werden. Wenn ein relativer Pfad eingegeben wird, wird der Wert von\n"
              "OUTPUT_DIRECTORY davor gesetzt.\n"
              "Das Standardverzeichnis ist: html.\n"
              "Dieses Tag erfordert, dass das Tag GENERATE_HTML auf YES gesetzt ist."
          );
  doc->add(
              "HTML_FILE_EXTENSION",
              "Das HTML_FILE_EXTENSION-Tag kann verwendet werden, um die Dateierweiterung für\n"
              "jede generierte HTML-Seite anzugeben (zum Beispiel: .htm, .php, .asp).\n"
              "Der Standardwert ist: .html.\n"
              "Dieses Tag erfordert, dass das Tag GENERATE_HTML auf YES gesetzt ist."
          );
  doc->add(
              "HTML_HEADER",
              "Das HTML_HEADER-Tag kann verwendet werden, um eine benutzerdefinierte HTML-\n"
              "Header-Datei für jede generierte HTML-Seite anzugeben. Wenn das Tag leer\n"
              "gelassen wird, generiert Doxygen einen Standard-Header.\n"
              "\n"
              "Um gültiges HTML zu erhalten, muss die Header-Datei alle Skripte und\n"
              "Stylesheets enthalten, die Doxygen benötigt, was von den verwendeten\n"
              "Konfigurationsoptionen abhängt (z.B. die Einstellung GENERATE_TREEVIEW). Es\n"
              "wird dringend empfohlen, mit einem Standard-Header zu beginnen, indem Sie\n"
              "doxygen -w html new_header.html new_footer.html new_stylesheet.css\n"
              "YourConfigFile\n"
              "verwenden und dann die Datei new_header.html ändern. Siehe auch Abschnitt\n"
              "\"Doxygen usage\" für Informationen zum Generieren des Standard-Headers, den\n"
              "Doxygen normalerweise verwendet.\n"
              "Hinweis: Der Header kann sich ändern, daher müssen Sie normalerweise den\n"
              "Standard-Header regenerieren, wenn Sie auf eine neuere Version von Doxygen\n"
              "aktualisieren. Für eine Beschreibung der möglichen Marker und Blocknamen siehe\n"
              "die Dokumentation.\n"
              "Dieses Tag erfordert, dass das Tag GENERATE_HTML auf YES gesetzt ist."
          );
  doc->add(
              "HTML_FOOTER",
              "Das HTML_FOOTER-Tag kann verwendet werden, um eine benutzerdefinierte HTML-\n"
              "Fußzeile für jede generierte HTML-Seite anzugeben. Wenn das Tag leer gelassen\n"
              "wird, generiert Doxygen eine Standard-Fußzeile. Siehe HTML_HEADER für weitere\n"
              "Informationen zum Generieren einer Standard-Fußzeile und welche speziellen\n"
              "Befehle innerhalb der Fußzeile verwendet werden können. Siehe auch Abschnitt\n"
              "\"Doxygen usage\" für Informationen zum Generieren der Standard-Fußzeile, die\n"
              "Doxygen normalerweise verwendet.\n"
              "Dieses Tag erfordert, dass das Tag GENERATE_HTML auf YES gesetzt ist."
          );
  doc->add(
              "HTML_STYLESHEET",
              "Das HTML_STYLESHEET-Tag kann verwendet werden, um ein benutzerdefiniertes\n"
              "Cascading Stylesheet anzugeben, das von jeder HTML-Seite verwendet wird. Es\n"
              "kann verwendet werden, um das Aussehen der HTML-Ausgabe zu optimieren. Wenn\n"
              "leer gelassen, generiert Doxygen ein Standard-Stylesheet. Siehe auch Abschnitt\n"
              "\"Doxygen usage\" für Informationen zum Generieren des Stylesheets, das Doxygen\n"
              "normalerweise verwendet.\n"
              "Hinweis: Es wird empfohlen, HTML_EXTRA_STYLESHEET anstelle dieses Tags zu\n"
              "verwenden, da es robuster ist und dieses Tag (HTML_STYLESHEET) wird in Zukunft\n"
              "veraltet sein.\n"
              "Dieses Tag erfordert, dass das Tag GENERATE_HTML auf YES gesetzt ist."
          );
  doc->add(
              "HTML_EXTRA_STYLESHEET",
              "Das HTML_EXTRA_STYLESHEET-Tag kann verwendet werden, um zusätzliche\n"
              "benutzerdefinierte Cascading Stylesheets anzugeben, die nach den von Doxygen\n"
              "erstellten Standard-Stylesheets eingebunden werden. Mit dieser Option können\n"
              "bestimmte Stilaspekte überschrieben werden. Dies ist der Verwendung von\n"
              "HTML_STYLESHEET vorzuziehen, da es das Standard-Stylesheet nicht ersetzt und\n"
              "daher robuster gegen zukünftige Updates ist. Doxygen kopiert die Stylesheet-\n"
              "Dateien in das Ausgabeverzeichnis.\n"
              "Hinweis: Die Reihenfolge der zusätzlichen Stylesheet-Dateien ist wichtig (z.B.\n"
              "überschreibt das letzte Stylesheet in der Liste die Einstellungen der\n"
              "vorherigen in der Liste).\n"
              "Hinweis: Da die Gestaltung von Scrollleisten in Webkit/Chromium derzeit nicht\n"
              "überschrieben werden kann, wird die Gestaltung aus der Standard-datei\n"
              "doxygen.css weggelassen, wenn ein oder mehrere zusätzliche Stylesheets\n"
              "angegeben wurden. Wenn also eine Anpassung der Scrollleisten gewünscht wird,\n"
              "muss diese explizit hinzugefügt werden. Für ein Beispiel siehe die\n"
              "Dokumentation.\n"
              "Dieses Tag erfordert, dass das Tag GENERATE_HTML auf YES gesetzt ist."
          );
  doc->add(
              "HTML_EXTRA_FILES",
              "Das HTML_EXTRA_FILES-Tag kann verwendet werden, um eine oder mehrere\n"
              "zusätzliche Bilder oder andere Quelldateien anzugeben, die in das HTML-\n"
              "Ausgabeverzeichnis kopiert werden sollen. Beachten Sie, dass diese Dateien in\n"
              "das Basis-HTML-Ausgabeverzeichnis kopiert werden. Verwenden Sie den Marker\n"
              "$relpath^ in den Dateien HTML_HEADER und/oder HTML_FOOTER, um diese Dateien zu\n"
              "laden. In der Datei HTML_STYLESHEET verwenden Sie nur den Dateinamen. Beachten\n"
              "Sie auch, dass die Dateien wie besehen kopiert werden; es sind keine Befehle\n"
              "oder Marker verfügbar.\n"
              "Dieses Tag erfordert, dass das Tag GENERATE_HTML auf YES gesetzt ist."
          );
  doc->add(
              "HTML_COLORSTYLE",
              "Das HTML_COLORSTYLE-Tag kann verwendet werden, um anzugeben, ob die generierte\n"
              "HTML-Ausgabe mit einem dunklen oder hellen Thema gerendert werden soll.\n"
              "Mögliche Werte sind: LIGHT generiert immer Light-Mode-Ausgabe, DARK generiert\n"
              "immer Dark-Mode-Ausgabe, AUTO_LIGHT setzt den Modus automatisch entsprechend\n"
              "der Benutzereinstellung, verwendet Light-Mode, wenn keine Einstellung\n"
              "festgelegt ist (Standard), AUTO_DARK setzt den Modus automatisch entsprechend\n"
              "der Benutzereinstellung, verwendet Dark-Mode, wenn keine Einstellung\n"
              "festgelegt ist und TOGGLE ermöglicht dem Benutzer, über eine Schaltfläche\n"
              "zwischen Light- und Dark-Mode zu wechseln.\n"
              "Der Standardwert ist: AUTO_LIGHT.\n"
              "Dieses Tag erfordert, dass das Tag GENERATE_HTML auf YES gesetzt ist."
          );
  doc->add(
              "HTML_COLORSTYLE_HUE",
              "Das HTML_COLORSTYLE_HUE-Tag steuert die Farbe der HTML-Ausgabe. Doxygen passt\n"
              "die Farben im Stylesheet und in den Hintergrundbildern entsprechend dieser\n"
              "Farbe an. Farbton wird als Winkel auf einem Farbkreis angegeben, siehe\n"
              "https://en.wikipedia.org/wiki/Hue für weitere Informationen. Zum Beispiel\n"
              "repräsentiert der Wert 0 Rot, 60 ist Gelb, 120 ist Grün, 180 ist Cyan, 240 ist\n"
              "Blau, 300 ist Lila und 360 ist wieder Rot.\n"
              "Mindestwert: 0, Höchstwert: 359, Standardwert: 220.\n"
              "Dieses Tag erfordert, dass das Tag GENERATE_HTML auf YES gesetzt ist."
          );
  doc->add(
              "HTML_COLORSTYLE_SAT",
              "Das HTML_COLORSTYLE_SAT-Tag steuert die Reinheit (oder Sättigung) der Farben\n"
              "in der HTML-Ausgabe. Für einen Wert von 0 verwendet die Ausgabe nur\n"
              "Graustufen. Ein Wert von 255 erzeugt die lebhaftesten Farben.\n"
              "Mindestwert: 0, Höchstwert: 255, Standardwert: 100.\n"
              "Dieses Tag erfordert, dass das Tag GENERATE_HTML auf YES gesetzt ist."
          );
  doc->add(
              "HTML_COLORSTYLE_GAMMA",
              "Das HTML_COLORSTYLE_GAMMA-Tag steuert die Gammakorrektur, die auf die\n"
              "Luminanzkomponente der Farben in der HTML-Ausgabe angewendet wird. Werte unter\n"
              "100 machen die Ausgabe allmählich heller, während Werte über 100 die Ausgabe\n"
              "dunkler machen. Der Wert geteilt durch 100 ist das tatsächlich angewendete\n"
              "Gamma, also repräsentiert 80 ein Gamma von 0.8, der Wert 220 repräsentiert ein\n"
              "Gamma von 2.2, und 100 ändert das Gamma nicht.\n"
              "Mindestwert: 40, Höchstwert: 240, Standardwert: 80.\n"
              "Dieses Tag erfordert, dass das Tag GENERATE_HTML auf YES gesetzt ist."
          );
  doc->add(
              "HTML_DYNAMIC_MENUS",
              "Wenn das HTML_DYNAMIC_MENUS-Tag auf YES gesetzt ist, enthält die generierte\n"
              "HTML-Dokumentation einen Hauptindex mit vertikalen Navigationsmenus, die\n"
              "dynamisch über JavaScript erstellt werden. Wenn deaktiviert, besteht der\n"
              "Navigationsindex aus mehreren Ebenen von Tabs, die statisch in jede HTML-Seite\n"
              "eingebettet sind. Deaktivieren Sie diese Option, um Browser zu unterstützen,\n"
              "die kein JavaScript haben, wie den Qt-Hilfe-Browser.\n"
              "Der Standardwert ist: YES.\n"
              "Dieses Tag erfordert, dass das Tag GENERATE_HTML auf YES gesetzt ist."
          );
  doc->add(
              "HTML_DYNAMIC_SECTIONS",
              "Wenn das HTML_DYNAMIC_SECTIONS-Tag auf YES gesetzt ist, enthält die generierte\n"
              "HTML-Dokumentation Abschnitte, die nach dem Laden der Seite ein- und\n"
              "ausgeblendet werden können.\n"
              "Der Standardwert ist: NO.\n"
              "Dieses Tag erfordert, dass das Tag GENERATE_HTML auf YES gesetzt ist."
          );
  doc->add(
              "HTML_CODE_FOLDING",
              "Wenn das HTML_CODE_FOLDING-Tag auf YES gesetzt ist, können Klassen und\n"
              "Funktionen im generierten HTML-Quellcode dynamisch gefaltet und erweitert\n"
              "werden.\n"
              "Der Standardwert ist: YES.\n"
              "Dieses Tag erfordert, dass das Tag GENERATE_HTML auf YES gesetzt ist."
          );
  doc->add(
              "HTML_COPY_CLIPBOARD",
              "Wenn das HTML_COPY_CLIPBOARD-Tag auf YES gesetzt ist, zeigt Doxygen ein Symbol\n"
              "in der oberen rechten Ecke von Code- und Textfragmenten an, das es dem\n"
              "Benutzer ermöglicht, den Inhalt in die Zwischenablage zu kopieren. Beachten\n"
              "Sie, dass dies nur funktioniert, wenn es vom Browser unterstützt wird und die\n"
              "Webseite über einen sicheren Kontext (see:\n"
              "https://www.w3.org/TR/secure-contexts/) bereitgestellt wird, d.h. über das\n"
              "https: oder file: Protokoll.\n"
              "Der Standardwert ist: YES.\n"
              "Dieses Tag erfordert, dass das Tag GENERATE_HTML auf YES gesetzt ist."
          );
  doc->add(
              "HTML_PROJECT_COOKIE",
              "Doxygen speichert einige Einstellungen dauerhaft im Browser (z.B. über\n"
              "Cookies). Standardmäßig gelten diese Einstellungen für alle von Doxygen\n"
              "generierten HTML-Seiten über alle Projekte hinweg. Das HTML_PROJECT_COOKIE-Tag\n"
              "kann verwendet werden, um die Einstellungen unter einem projektspezifischen\n"
              "Schlüssel zu speichern, sodass die Benutzereinstellungen separat gespeichert\n"
              "werden.\n"
              "Dieses Tag erfordert, dass das Tag GENERATE_HTML auf YES gesetzt ist."
          );
  doc->add(
              "HTML_INDEX_NUM_ENTRIES",
              "Mit HTML_INDEX_NUM_ENTRIES kann die bevorzugte Anzahl von Eintragen gesteuert\n"
              "werden, die anfänglich in den verschiedenen baumstrukturierten Indizes\n"
              "angezeigt werden; der Benutzer kann Eintrage später dynamisch erweitern und\n"
              "reduzieren. Doxygen erweitert den Baum auf eine solche Ebene, dass höchstens\n"
              "die angegebene Anzahl von Eintragen sichtbar ist (es sei denn, ein vollständig\n"
              "reduzierter Baum überschreitet diesen Betrag bereits). Das Setzen der Anzahl\n"
              "der Eintrage auf 1 erzeugt standardmäßig einen vollständig reduzierten Baum. 0\n"
              "ist ein spezieller Wert, der eine unendliche Anzahl von Eintragen\n"
              "repräsentiert und standardmäßig zu einem vollständig erweiterten Baum führt.\n"
              "Mindestwert: 0, Höchstwert: 9999, Standardwert: 100.\n"
              "Dieses Tag erfordert, dass das Tag GENERATE_HTML auf YES gesetzt ist."
          );
  doc->add(
              "GENERATE_DOCSET",
              "Wenn das GENERATE_DOCSET-Tag auf YES gesetzt ist, werden zusätzliche\n"
              "Indexdateien generiert, die als Eingabe für Apples Xcode 3 integrierte\n"
              "Entwicklungsumgebung (see:\n"
              "https://developer.apple.com/xcode/) verwendet werden können, die mit OSX 10.5\n"
              "(Leopard) eingeführt wurde. Um einen Dokumentensatz zu erstellen, generiert\n"
              "Doxygen eine Makefile im HTML-Ausgabeverzeichnis. Das Ausführen von make\n"
              "erzeugt den Dokumentensatz in diesem Verzeichnis und das Ausführen von make\n"
              "install installiert den Dokumentensatz in\n"
              "~/Library/Developer/Shared/Documentation/DocSets, sodass Xcode ihn beim Start\n"
              "findet. Siehe https://developer.apple.com/library/archive/featuredarticles/Dox\n"
              "ygenXcode/_index.html für weitere Informationen.\n"
              "Der Standardwert ist: NO.\n"
              "Dieses Tag erfordert, dass das Tag GENERATE_HTML auf YES gesetzt ist."
          );
  doc->add(
              "DOCSET_FEEDNAME",
              "Dieses Tag bestimmt den Namen des Docset-Feeds. Ein Dokumentations-Feed bietet\n"
              "einen Dach, unter dem mehrere Dokumentensatze eines einzelnen Anbieters (z.B.\n"
              "eines Unternehmens oder einer Produktsuite) gruppiert werden können.\n"
              "Der Standardwert ist: Doxygen generated docs.\n"
              "Dieses Tag erfordert, dass das Tag GENERATE_DOCSET auf YES gesetzt ist."
          );
  doc->add(
              "DOCSET_FEEDURL",
              "Dieses Tag bestimmt die URL des Docset-Feeds. Ein Dokumentations-Feed bietet\n"
              "einen Dach, unter dem mehrere Dokumentensatze eines einzelnen Anbieters (z.B.\n"
              "eines Unternehmens oder einer Produktsuite) gruppiert werden können.\n"
              "Dieses Tag erfordert, dass das Tag GENERATE_DOCSET auf YES gesetzt ist."
          );
  doc->add(
              "DOCSET_BUNDLE_ID",
              "Dieses Tag gibt eine Zeichenfolge an, die das Dokumentensatz-Bundle eindeutig\n"
              "identifizieren sollte. Dies sollte eine Zeichenfolge im umgekehrten\n"
              "Domainnamen-Stil sein, z.B. com.mycompany.MyDocSet. Doxygen wird .docset an\n"
              "den Namen anhängen.\n"
              "Der Standardwert ist: org.doxygen.Project.\n"
              "Dieses Tag erfordert, dass das Tag GENERATE_DOCSET auf YES gesetzt ist."
          );
  doc->add(
              "DOCSET_PUBLISHER_ID",
              "Das DOCSET_PUBLISHER_ID-Tag gibt eine Zeichenfolge an, die den\n"
              "Dokumentationsherausgeber eindeutig identifizieren sollte. Dies sollte eine\n"
              "Zeichenfolge im umgekehrten Domainnamen-Stil sein, z.B.\n"
              "com.mycompany.MyDocSet.documentation.\n"
              "Der Standardwert ist: org.doxygen.Publisher.\n"
              "Dieses Tag erfordert, dass das Tag GENERATE_DOCSET auf YES gesetzt ist."
          );
  doc->add(
              "DOCSET_PUBLISHER_NAME",
              "Das DOCSET_PUBLISHER_NAME-Tag identifiziert den Dokumentationsherausgeber.\n"
              "Der Standardwert ist: Publisher.\n"
              "Dieses Tag erfordert, dass das Tag GENERATE_DOCSET auf YES gesetzt ist."
          );
  doc->add(
              "GENERATE_HTMLHELP",
              "Wenn das GENERATE_HTMLHELP-Tag auf YES gesetzt ist, generiert Doxygen drei\n"
              "zusätzliche HTML-Indexdateien: index.hhp, index.hhc und index.hhk. Die\n"
              "index.hhp ist eine Projektdatei, die von Microsofts HTML Help Workshop unter\n"
              "Windows gelesen werden kann. Anfang 2021 hat Microsoft die ursprüngliche Seite\n"
              "mit den Download-Links offline genommen (der HTML Help Workshop war bereits\n"
              "viele Jahre im Wartungsmodus). Sie können den HTML Help Workshop aus den Web-\n"
              "Archiven unter Installation executable (see:\n"
              "http://web.archive.org/web/20160201063255/https://download.microsoft.com/downl\n"
              "oad/0/A/9/0A939EF6-E31C-430F-A3DF-DFAE7960D564/htmlhelp.exe) herunterladen.\n"
              "\n"
              "Der HTML Help Workshop enthält einen Compiler, der alle von Doxygen\n"
              "generierten HTML-Ausgaben in eine einzelne kompilierte HTML-Datei (.chm)\n"
              "umwandeln kann. Kompilierte HTML-Dateien werden jetzt als Windows\n"
              "98-Hilfeformat verwendet und werden in Zukunft das alte Windows-Hilfeformat\n"
              "(.hlp) auf allen Windows-Plattformen ersetzen. Komprimierte HTML-Dateien\n"
              "enthalten auch einen Index, ein Inhaltsverzeichnis und Sie können nach Wörtern\n"
              "in der Dokumentation suchen. Der HTML-Workshop enthält auch einen Viewer für\n"
              "komprimierte HTML-Dateien.\n"
              "Der Standardwert ist: NO.\n"
              "Dieses Tag erfordert, dass das Tag GENERATE_HTML auf YES gesetzt ist."
          );
  doc->add(
              "CHM_FILE",
              "Das CHM_FILE-Tag kann verwendet werden, um den Dateinamen der resultierenden\n"
              ".chm-Datei anzugeben. Ein relativer Pfad wird relativ zum HTML_OUTPUT-\n"
              "Verzeichnis interpretiert. Wenn leer gelassen, wird der Standardwert index.chm\n"
              "verwendet.\n"
              "Dieses Tag erfordert, dass das Tag GENERATE_HTMLHELP auf YES gesetzt ist."
          );
  doc->add(
              "HHC_LOCATION",
              "Das HHC_LOCATION-Tag kann verwendet werden, um den Speicherort (absoluter Pfad\n"
              "einschließlich Dateiname) des HTML-Help-Compilers (hhc.exe) anzugeben. Wenn\n"
              "nicht leer, wird Doxygen versuchen, den HTML-Help-Compiler auf der generierten\n"
              "index.hhp-Datei auszuführen.\n"
              "Die Datei muss mit vollem Pfad angegeben werden.\n"
              "Dieses Tag erfordert, dass das Tag GENERATE_HTMLHELP auf YES gesetzt ist."
          );
  doc->add(
              "GENERATE_CHI",
              "Das GENERATE_CHI-Tag steuert, ob eine separate .chi-Indexdatei generiert wird\n"
              "(YES) oder dass sie in die Haupt-.chm-Datei aufgenommen werden soll (NO).\n"
              "Der Standardwert ist: NO.\n"
              "Dieses Tag erfordert, dass das Tag GENERATE_HTMLHELP auf YES gesetzt ist."
          );
  doc->add(
              "CHM_INDEX_ENCODING",
              "Das CHM_INDEX_ENCODING wird verwendet, um HtmlHelp-Index, Inhalt und\n"
              "Projektdatei-Inhalt zu kodieren. Standardmäßig wird die Codierung des HTML-\n"
              "Outputs verwendet.\n"
              "Dieses Tag erfordert, dass das Tag GENERATE_HTMLHELP auf YES gesetzt ist."
          );
  doc->add(
              "BINARY_TOC",
              "Das BINARY_TOC-Tag steuert, ob ein binäres Inhaltsverzeichnis generiert wird.\n"
              "Wenn es auf YES gesetzt ist, wird ein binäres Inhaltsverzeichnis erstellt, was\n"
              "zu schnellerer Suche und kleineren Dateien führt. Das Standard-\n"
              "Inhaltsverzeichnis wird in einer Textdatei gespeichert.\n"
              "Der Standardwert ist: NO.\n"
              "Dieses Tag erfordert, dass das Tag GENERATE_HTMLHELP auf YES gesetzt ist."
          );
  doc->add(
              "TOC_EXPAND",
              "Das TOC_EXPAND-Tag kann auf YES gesetzt werden, um zusätzliche Elemente für\n"
              "Gruppenmitglieder zum Inhaltsverzeichnis der HTML-Hilfe-Dokumentation und zur\n"
              "Baumansicht hinzuzufügen.\n"
              "Der Standardwert ist: NO.\n"
              "Dieses Tag erfordert, dass das Tag GENERATE_HTMLHELP auf YES gesetzt ist."
          );
  doc->add(
              "SITEMAP_URL",
              "Das SITEMAP_URL-Tag wird verwendet, um die vollständige URL des Ortes\n"
              "anzugeben, an dem die generierte Dokumentation vom Benutzer während der\n"
              "Bereitstellung der Dokumentation auf dem Server platziert wird. Die generierte\n"
              "Sitemap heißt sitemap.xml und wird im durch HTML_OUTPUT angegebenen\n"
              "Verzeichnis platziert. Falls keine SITEMAP_URL angegeben ist, wird keine\n"
              "Sitemap generiert. Für Informationen zum Sitemap-Protokoll siehe\n"
              "https://www.sitemaps.org\n"
              "Dieses Tag erfordert, dass das Tag GENERATE_HTML auf YES gesetzt ist."
          );
  doc->add(
              "GENERATE_QHP",
              "Wenn das GENERATE_QHP-Tag auf YES gesetzt ist und sowohl QHP_NAMESPACE als\n"
              "auch QHP_VIRTUAL_FOLDER gesetzt sind, wird eine zusätzliche Indexdatei\n"
              "generiert, die als Eingabe für Qt's qhelpgenerator verwendet werden kann, um\n"
              "eine Qt Compressed Help (.qch) der generierten HTML-Dokumentation zu\n"
              "erstellen.\n"
              "Der Standardwert ist: NO.\n"
              "Dieses Tag erfordert, dass das Tag GENERATE_HTML auf YES gesetzt ist."
          );
  doc->add(
              "QCH_FILE",
              "Wenn das QHG_LOCATION-Tag angegeben ist, kann das QCH_FILE-Tag verwendet\n"
              "werden, um den Dateinamen der resultierenden .qch-Datei anzugeben. Der\n"
              "angegebene Pfad ist relativ zum HTML-Ausgabeordner.\n"
              "Dieses Tag erfordert, dass das Tag GENERATE_QHP auf YES gesetzt ist."
          );
  doc->add(
              "QHP_NAMESPACE",
              "Das QHP_NAMESPACE-Tag gibt den Namespace an, der beim Generieren der Qt Help\n"
              "Project-Ausgabe verwendet werden soll. Für weitere Informationen siehe Qt Help\n"
              "Project / Namespace (see:\n"
              "https://doc.qt.io/archives/qt-4.8/qthelpproject.html#namespace).\n"
              "Der Standardwert ist: org.doxygen.Project.\n"
              "Dieses Tag erfordert, dass das Tag GENERATE_QHP auf YES gesetzt ist."
          );
  doc->add(
              "QHP_VIRTUAL_FOLDER",
              "Das QHP_VIRTUAL_FOLDER-Tag gibt den virtuellen Ordner an, der beim Generieren\n"
              "der Qt Help Project-Ausgabe verwendet werden soll. Für weitere Informationen\n"
              "siehe Qt Help Project / Virtual Folders (see:\n"
              "https://doc.qt.io/archives/qt-4.8/qthelpproject.html#virtual-folders).\n"
              "Der Standardwert ist: doc.\n"
              "Dieses Tag erfordert, dass das Tag GENERATE_QHP auf YES gesetzt ist."
          );
  doc->add(
              "QHP_CUST_FILTER_NAME",
              "Wenn das QHP_CUST_FILTER_NAME-Tag gesetzt ist, gibt es den Namen eines\n"
              "benutzerdefinierten Filters an, der hinzugefügt werden soll. Für weitere\n"
              "Informationen siehe Qt Help Project / Custom Filters (see:\n"
              "https://doc.qt.io/archives/qt-4.8/qthelpproject.html#custom-filters).\n"
              "Dieses Tag erfordert, dass das Tag GENERATE_QHP auf YES gesetzt ist."
          );
  doc->add(
              "QHP_CUST_FILTER_ATTRS",
              "Das QHP_CUST_FILTER_ATTRS-Tag gibt die Liste der Attribute des\n"
              "benutzerdefinierten Filters an, der hinzugefügt werden soll. Für weitere\n"
              "Informationen siehe Qt Help Project / Custom Filters (see:\n"
              "https://doc.qt.io/archives/qt-4.8/qthelpproject.html#custom-filters).\n"
              "Dieses Tag erfordert, dass das Tag GENERATE_QHP auf YES gesetzt ist."
          );
  doc->add(
              "QHP_SECT_FILTER_ATTRS",
              "Das QHP_SECT_FILTER_ATTRS-Tag gibt die Liste der Attribute an, mit denen der\n"
              "Filterabschnitt dieses Projekts übereinstimmt. Qt Help Project / Filter\n"
              "Attributes (see:\n"
              "https://doc.qt.io/archives/qt-4.8/qthelpproject.html#filter-attributes).\n"
              "Dieses Tag erfordert, dass das Tag GENERATE_QHP auf YES gesetzt ist."
          );
  doc->add(
              "QHG_LOCATION",
              "Das QHG_LOCATION-Tag kann verwendet werden, um den Speicherort (absoluter Pfad\n"
              "einschließlich Dateiname) von Qt's qhelpgenerator anzugeben. Wenn nicht leer,\n"
              "wird Doxygen versuchen, qhelpgenerator auf der generierten .qhp-Datei\n"
              "auszuführen.\n"
              "Dieses Tag erfordert, dass das Tag GENERATE_QHP auf YES gesetzt ist."
          );
  doc->add(
              "GENERATE_ECLIPSEHELP",
              "Wenn das GENERATE_ECLIPSEHELP-Tag auf YES gesetzt ist, werden zusätzliche\n"
              "Indexdateien generiert, die zusammen mit den HTML-Dateien ein Eclipse-Hilfe-\n"
              "Plugin bilden. Um das Plugin zu installieren, platzieren Sie das Verzeichnis,\n"
              "das die HTML- und Indexdateien enthält, in Ihrem Eclipse-\n"
              "Installationsverzeichnis unter plugins.\n"
              "Der Standardwert ist: NO.\n"
              "Dieses Tag erfordert, dass das Tag GENERATE_HTML auf YES gesetzt ist."
          );
  doc->add(
              "ECLIPSE_DOC_ID",
              "Eine eindeutige Kennung für das Eclipse-Hilfe-Plugin. Dies sollte eine\n"
              "Zeichenfolge im umgekehrten Domainnamen-Stil sein, z.B. org.doxygen.Project.\n"
              "Der Standardwert ist: org.doxygen.Project.\n"
              "Dieses Tag erfordert, dass das Tag GENERATE_ECLIPSEHELP auf YES gesetzt ist."
          );
  doc->add(
              "DISABLE_INDEX",
              "Wenn Sie volle Kontrolle über das Layout der generierten HTML-Seiten möchten,\n"
              "kann es notwendig sein, den Index zu deaktivieren und ihn durch Ihren eigenen\n"
              "zu ersetzen. Das DISABLE_INDEX-Tag kann verwendet werden, um den kondensierten\n"
              "Index (Tabs) oben auf jeder HTML-Seite ein- oder auszuschalten. Ein Wert von\n"
              "NO aktiviert den Index und der Wert YES deaktiviert ihn. Da die Tabs im Index\n"
              "dieselben Informationen wie der Navigationsbaum enthalten, können Sie diese\n"
              "Option auf YES setzen, wenn Sie auch GENERATE_TREEVIEW auf YES setzen.\n"
              "Der Standardwert ist: NO.\n"
              "Dieses Tag erfordert, dass das Tag GENERATE_HTML auf YES gesetzt ist."
          );
  doc->add(
              "GENERATE_TREEVIEW",
              "Das GENERATE_TREEVIEW-Tag wird verwendet, um anzugeben, ob eine baumartige\n"
              "Indexstruktur generiert werden soll, um hierarchische Informationen\n"
              "anzuzeigen. Wenn der Tag-Wert auf YES gesetzt ist, wird ein Seitenpanel\n"
              "generiert, das eine baumartige Indexstruktur enthält (genau wie die, die für\n"
              "HTML-Hilfe generiert wird). Dafür ist ein Browser erforderlich, der\n"
              "JavaScript, DHTML, CSS und Frames unterstützt (d.h. jeder moderne Browser).\n"
              "Windows-Benutzer sind wahrscheinlich besser mit der HTML-Hilfe-Funktion\n"
              "bedient. Über benutzerdefinierte Stylesheets (siehe HTML_EXTRA_STYLESHEET)\n"
              "kann man das Aussehen des Index weiter verfeinern (siehe \"Fine-tuning the\n"
              "output\"). Als Beispiel hat das von Doxygen generierte Standard-Stylesheet ein\n"
              "Beispiel, das zeigt, wie man ein Bild an der Wurzel des Baums statt des\n"
              "PROJECT_NAME platziert.\n"
              "Der Standardwert ist: YES.\n"
              "Dieses Tag erfordert, dass das Tag GENERATE_HTML auf YES gesetzt ist."
          );
  doc->add(
              "PAGE_OUTLINE_PANEL",
              "Wenn GENERATE_TREEVIEW auf YES gesetzt ist, bestimmt die PAGE_OUTLINE_PANEL-\n"
              "Option, ob ein zusätzliches Navigationspanel auf der rechten Seite des\n"
              "Bildschirms angezeigt wird, das eine Gliederung des Inhalts der Hauptseite\n"
              "anzeigt, ähnlich wie z.B. https://developer.android.com/reference. Wenn\n"
              "GENERATE_TREEVIEW auf NO gesetzt ist, hat diese Option keine Auswirkung.\n"
              "Der Standardwert ist: YES.\n"
              "Dieses Tag erfordert, dass das Tag GENERATE_HTML auf YES gesetzt ist."
          );
  doc->add(
              "FULL_SIDEBAR",
              "Wenn GENERATE_TREEVIEW auf YES gesetzt ist, bestimmt die FULL_SIDEBAR-Option,\n"
              "ob die Seitenleiste auf den Treeview-Bereich beschränkt ist (Wert NO) oder ob\n"
              "sie sich über die volle Höhe des Fensters erstrecken soll (Wert YES). Wenn\n"
              "dies auf YES gesetzt wird, ergibt sich ein Layout ähnlich wie z.B.\n"
              "https://docs.readthedocs.io mit mehr Platz für Inhalte, aber weniger Platz für\n"
              "Projektlogo, Titel und Beschreibung. Wenn GENERATE_TREEVIEW auf NO gesetzt\n"
              "ist, hat diese Option keine Auswirkung.\n"
              "Der Standardwert ist: NO.\n"
              "Dieses Tag erfordert, dass das Tag GENERATE_HTML auf YES gesetzt ist."
          );
  doc->add(
              "ENUM_VALUES_PER_LINE",
              "Das ENUM_VALUES_PER_LINE-Tag kann verwendet werden, um die Anzahl von Enum-\n"
              "Werten festzulegen, die Doxygen in einer Zeile gruppiert.\n"
              "Mindestwert: 0, Höchstwert: 20, Standardwert: 4.\n"
              "Dieses Tag erfordert, dass das Tag GENERATE_HTML auf YES gesetzt ist."
          );
  doc->add(
              "SHOW_ENUM_VALUES",
              "Wenn das SHOW_ENUM_VALUES-Tag gesetzt ist, zeigt Doxygen die angegebenen\n"
              "Aufzählungswerte neben den Aufzählungsmnemoniken an.\n"
              "Der Standardwert ist: NO."
          );
  doc->add(
              "TREEVIEW_WIDTH",
              "Wenn der Treeview aktiviert ist (siehe GENERATE_TREEVIEW), kann dieses Tag\n"
              "verwendet werden, um die anfängliche Breite (in Pixeln) des Frames\n"
              "festzulegen, in dem der Baum angezeigt wird.\n"
              "Mindestwert: 0, Höchstwert: 1500, Standardwert: 250.\n"
              "Dieses Tag erfordert, dass das Tag GENERATE_HTML auf YES gesetzt ist."
          );
  doc->add(
              "EXT_LINKS_IN_WINDOW",
              "Wenn die EXT_LINKS_IN_WINDOW-Option auf YES gesetzt ist, öffnet Doxygen Links\n"
              "zu externen Symbolen, die über Tag-Dateien importiert wurden, in einem\n"
              "separaten Fenster.\n"
              "Der Standardwert ist: NO.\n"
              "Dieses Tag erfordert, dass das Tag GENERATE_HTML auf YES gesetzt ist."
          );
  doc->add(
              "OBFUSCATE_EMAILS",
              "Wenn das OBFUSCATE_EMAILS-Tag auf YES gesetzt ist, werden E-Mail-Adressen in\n"
              "der generierten HTML-Ausgabe verschleiert, um Spam-Bots zu verhindern.\n"
              "Der Standardwert ist: YES.\n"
              "Dieses Tag erfordert, dass das Tag GENERATE_HTML auf YES gesetzt ist."
          );
  doc->add(
              "HTML_FORMULA_FORMAT",
              "Wenn die HTML_FORMULA_FORMAT-Option auf svg gesetzt ist, verwendet Doxygen das\n"
              "Tool pdf2svg (siehe https://github.com/dawbarton/pdf2svg) oder Inkscape (siehe\n"
              "https://inkscape.org), um Formeln als SVG-Bilder anstelle von PNGs für die\n"
              "HTML-Ausgabe zu generieren. Diese Bilder sehen bei skalierten Auflösungen im\n"
              "Allgemeinen besser aus.\n"
              "Mögliche Werte sind: png (Standard) und svg (sieht schöner aus, erfordert aber\n"
              "das pdf2svg- oder inkscape-Tool).\n"
              "Der Standardwert ist: png.\n"
              "Dieses Tag erfordert, dass das Tag GENERATE_HTML auf YES gesetzt ist."
          );
  doc->add(
              "FORMULA_FONTSIZE",
              "Verwenden Sie dieses Tag, um die Schriftgröße von LaTeX-Formeln zu ändern, die\n"
              "als Bilder in die HTML-Dokumentation eingebunden werden. Wenn Sie die\n"
              "Schriftgröße nach einem erfolgreichen Doxygen-Lauf ändern, müssen Sie manuell\n"
              "alle form_*.png-Bilder aus dem HTML-Ausgabeverzeichnis entfernen, um deren\n"
              "Neugenerierung zu erzwingen.\n"
              "Mindestwert: 8, Höchstwert: 50, Standardwert: 10.\n"
              "Dieses Tag erfordert, dass das Tag GENERATE_HTML auf YES gesetzt ist."
          );
  doc->add(
              "FORMULA_MACROFILE",
              "Die FORMULA_MACROFILE kann LaTeX-Befehle \\newcommand und \\renewcommand\n"
              "enthalten, um neue LaTeX-Befehle zu erstellen, die als Bausteine in Formeln\n"
              "verwendet werden. Siehe den Abschnitt \"Including formulas\" für Details."
          );
  doc->add(
              "USE_MATHJAX",
              "Aktivieren Sie die USE_MATHJAX-Option, um LaTeX-Formeln mit MathJax zu rendern\n"
              "(siehe https://www.mathjax.org), das clientseitiges JavaScript für das\n"
              "Rendering verwendet, anstatt vorgerenderte Bitmaps zu verwenden. Verwenden Sie\n"
              "dies, wenn Sie LaTeX nicht installiert haben oder wenn Sie möchten, dass die\n"
              "Formeln in der HTML-Ausgabe schöner aussehen. Wenn aktiviert, müssen Sie\n"
              "möglicherweise auch MathJax separat installieren und den Pfad dazu mit der\n"
              "Option MATHJAX_RELPATH konfigurieren.\n"
              "Der Standardwert ist: NO.\n"
              "Dieses Tag erfordert, dass das Tag GENERATE_HTML auf YES gesetzt ist."
          );
  doc->add(
              "MATHJAX_VERSION",
              "Mit MATHJAX_VERSION ist es möglich, die zu verwendende MathJax-Version\n"
              "anzugeben. Beachten Sie, dass die verschiedenen Versionen von MathJax\n"
              "unterschiedliche Anforderungen an die verschiedenen Einstellungen haben,\n"
              "sodass es möglich ist, dass auch andere MathJax-Einstellungen geändert werden\n"
              "müssen, wenn zwischen den verschiedenen MathJax-Versionen gewechselt wird.\n"
              "Mögliche Werte sind: MathJax_2, MathJax_3 und MathJax_4.\n"
              "Der Standardwert ist: MathJax_2.\n"
              "Dieses Tag erfordert, dass das Tag USE_MATHJAX auf YES gesetzt ist."
          );
  doc->add(
              "MATHJAX_FORMAT",
              "Wenn MathJax aktiviert ist, können Sie das Standardausgabeformat festlegen,\n"
              "das für die MathJax-Ausgabe verwendet wird. Für weitere Details zum\n"
              "Ausgabeformat siehe MathJax version 2 (see:\n"
              "https://docs.mathjax.org/en/v2.7/output.html), MathJax version 3 (see:\n"
              "https://docs.mathjax.org/en/v3.2/output/index.html) und MathJax version 4\n"
              "(see:\n"
              "https://docs.mathjax.org/en/v4.0/output/index.htm).\n"
              "Mögliche Werte sind: HTML-CSS (langsamer, aber mit bester Kompatibilität. Dies\n"
              "ist der Name für MathJax Version 2, für MathJax Version 3 wird dies in chtml\n"
              "übersetzt), NativeMML (d.h. MathML. Nur für MathJax 2 unterstützt. Für MathJax\n"
              "Version 3 wird stattdessen chtml verwendet.), chtml (Dies ist der Name für\n"
              "MathJax Version 3, für MathJax Version 2 wird dies in HTML-CSS übersetzt) und\n"
              "SVG.\n"
              "Der Standardwert ist: HTML-CSS.\n"
              "Dieses Tag erfordert, dass das Tag USE_MATHJAX auf YES gesetzt ist."
          );
  doc->add(
              "MATHJAX_RELPATH",
              "Wenn MathJax aktiviert ist, müssen Sie den Speicherort relativ zum HTML-\n"
              "Ausgabeverzeichnis mit der Option MATHJAX_RELPATH angeben. Für MathJax Version\n"
              "2 sollte das Zielverzeichnis das MathJax.js-Skript enthalten. Wenn sich\n"
              "beispielsweise das mathjax-Verzeichnis auf derselben Ebene wie das HTML-\n"
              "Ausgabeverzeichnis befindet, sollte MATHJAX_RELPATH ../mathjax sein. Für\n"
              "MathJax Versionen 3 und 4 sollte das Zielverzeichnis das tex-<format>.js-\n"
              "Skript enthalten (wobei <format> entweder chtml oder svg ist). Der\n"
              "Standardwert verweist auf das MathJax Content Delivery Network, sodass Sie das\n"
              "Ergebnis schnell sehen können, ohne MathJax zu installieren. Es wird jedoch\n"
              "dringend empfohlen, eine lokale Kopie von MathJax von https://www.mathjax.org\n"
              "vor der Bereitstellung zu installieren. Der Standardwert ist:\n"
              "- im Fall von MathJax Version 2: https://cdn.jsdelivr.net/npm/mathjax@2\n"
              "- im Fall von MathJax Version 3: https://cdn.jsdelivr.net/npm/mathjax@3\n"
              "- im Fall von MathJax Version 4: https://cdn.jsdelivr.net/npm/mathjax@4\n"
              "Dieses Tag erfordert, dass das Tag USE_MATHJAX auf YES gesetzt ist."
          );
  doc->add(
              "MATHJAX_EXTENSIONS",
              "Das MATHJAX_EXTENSIONS-Tag kann verwendet werden, um einen oder mehrere\n"
              "MathJax-Erweiterungsnamen anzugeben, die während des MathJax-Renderings\n"
              "aktiviert werden sollen. Zum Beispiel für MathJax Version 2 (siehe\n"
              "https://docs.mathjax.org/en/v2.7/tex.html):\n"
              "MATHJAX_EXTENSIONS = TeX/AMSmath TeX/AMSsymbols\n"
              "Zum Beispiel für MathJax Version 3 (siehe\n"
              "https://docs.mathjax.org/en/v3.2/input/tex/extensions/):\n"
              "MATHJAX_EXTENSIONS = ams\n"
              "Zum Beispiel für MathJax Version 4 (siehe\n"
              "https://docs.mathjax.org/en/v4.0/input/tex/extensions/):\n"
              "MATHJAX_EXTENSIONS = units\n"
              "Beachten Sie, dass für MathJax Version 4 bereits einige Erweiterungen\n"
              "automatisch geladen werden. Um ein Paket in MathJax Version 4 zu deaktivieren,\n"
              "können Sie den Paketnamen mit einem vorangestellten Minuszeichen verwenden (-\n"
              "wie MATHJAX_EXTENSIONS += -textmacros)\n"
              "Dieses Tag erfordert, dass das Tag USE_MATHJAX auf YES gesetzt ist."
          );
  doc->add(
              "MATHJAX_CODEFILE",
              "Das MATHJAX_CODEFILE-Tag kann verwendet werden, um eine Datei mit JavaScript-\n"
              "Code-Stucken anzugeben, die beim Start des MathJax-Codes verwendet werden.\n"
              "Siehe die MathJax-Website für weitere Details:\n"
              "- MathJax version 2 (see:\n"
              "https://docs.mathjax.org/en/v2.7/)\n"
              "- MathJax version 3 (see:\n"
              "https://docs.mathjax.org/en/v3.2/)\n"
              "- MathJax version 4 (see:\n"
              "https://docs.mathjax.org/en/v4.0/) Für ein Beispiel siehe die Dokumentation.\n"
              "Dieses Tag erfordert, dass das Tag USE_MATHJAX auf YES gesetzt ist."
          );
  doc->add(
              "SEARCHENGINE",
              "Wenn das SEARCHENGINE-Tag aktiviert ist, generiert Doxygen ein Suchfeld für\n"
              "die HTML-Ausgabe. Die zugrunde liegende Suchmaschine verwendet JavaScript und\n"
              "DHTML und sollte in jedem modernen Browser funktionieren. Beachten Sie, dass\n"
              "bei Verwendung von HTML-Hilfe (GENERATE_HTMLHELP), Qt-Hilfe (GENERATE_QHP)\n"
              "oder Docsets (GENERATE_DOCSET) bereits eine Suchfunktion vorhanden ist, sodass\n"
              "diese normalerweise deaktiviert werden sollte. Für große Projekte kann die\n"
              "JavaScript-basierte Suchmaschine langsam sein, dann kann das Aktivieren von\n"
              "SERVER_BASED_SEARCH eine bessere Lösung bieten. Es ist möglich, mit der\n"
              "Tastatur zu suchen; um zum Suchfeld zu springen, verwenden Sie\n"
              "<Zugriffsschlüssel> + S (was der <Zugriffsschlüssel> ist, hängt vom System\n"
              "ab).\n"
              "Der Standardwert ist: YES.\n"
              "Dieses Tag erfordert, dass das Tag GENERATE_HTML auf YES gesetzt ist."
          );
  doc->add(
              "SERVER_BASED_SEARCH",
              "Wenn das SERVER_BASED_SEARCH-Tag auf YES gesetzt ist, wird die Suchmaschine\n"
              "mit einem Webserver anstelle eines Webclients implementiert. Es gibt zwei\n"
              "Möglichkeiten, dies einzurichten: mit einem PHP-Skript oder mit einem externen\n"
              "Indexer. Siehe Abschnitt \"External Indexing and Searching\" für Details.\n"
              "Der Standardwert ist: NO.\n"
              "Dieses Tag erfordert, dass das Tag SEARCHENGINE auf YES gesetzt ist."
          );
  doc->add(
              "EXTERNAL_SEARCH",
              "Wenn das EXTERNAL_SEARCH-Tag aktiviert ist, generiert Doxygen das PHP-Skript\n"
              "zum Suchen nicht mehr. Stattdessen werden die Suchergebnisse in eine XML-Datei\n"
              "geschrieben, die von einem externen Indexer verarbeitet werden muss. Doxygen\n"
              "ruft eine externe Suchmaschine auf, die durch die Option SEARCHENGINE_URL\n"
              "angegeben wird, um die Suchergebnisse zu erhalten.\n"
              "\n"
              "Doxygen liefert einen Beispiel-Indexer (doxyindexer) und eine Suchmaschine\n"
              "(doxysearch.cgi), die auf der Open-Source-Suchmaschinen-Bibliothek Xapian\n"
              "(see:\n"
              "https://xapian.org/) basieren.\n"
              "\n"
              "Siehe den Abschnitt \"External Indexing and Searching\" für Details.\n"
              "Der Standardwert ist: NO.\n"
              "Dieses Tag erfordert, dass das Tag SEARCHENGINE auf YES gesetzt ist."
          );
  doc->add(
              "SEARCHENGINE_URL",
              "Wenn SERVER_BASED_SEARCH und EXTERNAL_SEARCH beide aktiviert sind, kann das\n"
              "SEARCHENGINE_URL-Tag verwendet werden, um eine URL anzugeben, an die eine\n"
              "Suchanfrage gesendet wird, um die Suchergebnisse zu erhalten. Die Suchanfrage\n"
              "wird an die URL angehängt. Für die externe Suchmaschine wird die Suchanfrage\n"
              "als JSON-Objekt gesendet.\n"
              "Dieses Tag erfordert, dass das Tag SEARCHENGINE auf YES gesetzt ist."
          );
  doc->add(
              "SEARCHDATA_FILE",
              "Wenn SERVER_BASED_SEARCH und EXTERNAL_SEARCH beide aktiviert sind, kann das\n"
              "SEARCHDATA_FILE-Tag verwendet werden, um eine Datei anzugeben, in der\n"
              "Suchdaten geschrieben werden. Wenn leer gelassen, wird searchdata.xml\n"
              "verwendet.\n"
              "Die Standarddatei ist: searchdata.xml.\n"
              "Dieses Tag erfordert, dass das Tag SEARCHENGINE auf YES gesetzt ist."
          );
  doc->add(
              "EXTERNAL_SEARCH_ID",
              "Wenn SERVER_BASED_SEARCH und EXTERNAL_SEARCH beide aktiviert sind, kann das\n"
              "EXTERNAL_SEARCH_ID-Tag als Kennung für das Projekt verwendet werden. Dies ist\n"
              "in Kombination mit EXTRA_SEARCH_MAPPINGS nützlich, um mehrere Projekte zu\n"
              "durchsuchen und die Ergebnisse zurück zum richtigen Projekt zu leiten.\n"
              "Dieses Tag erfordert, dass das Tag SEARCHENGINE auf YES gesetzt ist."
          );
  doc->add(
              "EXTRA_SEARCH_MAPPINGS",
              "Das EXTRA_SEARCH_MAPPINGS-Tag kann verwendet werden, um das Durchsuchen von\n"
              "Doxygen-Projekten zu ermöglichen, die nicht durch diese Konfigurationsdatei\n"
              "definiert sind, aber alle demselben externen Suchindex hinzugefügt werden.\n"
              "Jedes Projekt muss eine eindeutige ID haben, die über EXTERNAL_SEARCH_ID\n"
              "gesetzt wird. Die Suchzuordnung ordnet dann die ID einer relativen Position\n"
              "zu, an der die Dokumentation gefunden werden kann. Das Format ist:\n"
              "EXTRA_SEARCH_MAPPINGS = tagname1=loc1 tagname2=loc2 ...\n"
              "Dieses Tag erfordert, dass das Tag SEARCHENGINE auf YES gesetzt ist."
          );
  doc->add(
              "GENERATE_LATEX",
              "Wenn das GENERATE_LATEX-Tag auf YES gesetzt ist, generiert Doxygen LaTeX-\n"
              "Ausgabe.\n"
              "Der Standardwert ist: YES."
          );
  doc->add(
              "LATEX_OUTPUT",
              "Das LATEX_OUTPUT-Tag wird verwendet, um anzugeben, wo die LaTeX-Dokumente\n"
              "platziert werden. Wenn ein relativer Pfad eingegeben wird, wird der Wert von\n"
              "OUTPUT_DIRECTORY davor gesetzt.\n"
              "Das Standardverzeichnis ist: latex.\n"
              "Dieses Tag erfordert, dass das Tag GENERATE_LATEX auf YES gesetzt ist."
          );
  doc->add(
              "LATEX_CMD_NAME",
              "Das LATEX_CMD_NAME-Tag kann verwendet werden, um den aufzurufenden LaTeX-\n"
              "Befehlsnamen anzugeben.\n"
              "\n"
              "Beachten Sie, dass bei Nicht-Aktivierung von USE_PDFLATEX der Standard latex\n"
              "ist, bei Aktivierung von USE_PDFLATEX der Standard pdflatex ist und wenn im\n"
              "letzteren Fall latex gewählt wird, wird dies durch pdflatex überschrieben. Für\n"
              "bestimmte Ausgabesprachen kann der Standard unterschiedlich festgelegt sein,\n"
              "dies hängt von der Implementierung der Ausgabesprache ab.\n"
              "Dieses Tag erfordert, dass das Tag GENERATE_LATEX auf YES gesetzt ist."
          );
  doc->add(
              "MAKEINDEX_CMD_NAME",
              "Das MAKEINDEX_CMD_NAME-Tag kann verwendet werden, um den Befehlsnamen zum\n"
              "Generieren des Index für LaTeX anzugeben.\n"
              "Hinweis: Dieses Tag wird in der Makefile / make.bat verwendet.\n"
              "Siehe auch: LATEX_MAKEINDEX_CMD für den Teil in der generierten Ausgabedatei\n"
              "(.tex).\n"
              "Die Standarddatei ist: makeindex.\n"
              "Dieses Tag erfordert, dass das Tag GENERATE_LATEX auf YES gesetzt ist."
          );
  doc->add(
              "LATEX_MAKEINDEX_CMD",
              "Das LATEX_MAKEINDEX_CMD-Tag kann verwendet werden, um den Befehlsnamen zum\n"
              "Generieren des Index für LaTeX anzugeben. Falls kein Backslash (\\) als erstes\n"
              "Zeichen vorhanden ist, wird er automatisch im LaTeX-Code hinzugefügt.\n"
              "Hinweis: Dieses Tag wird in der generierten Ausgabedatei (.tex) verwendet.\n"
              "Siehe auch: MAKEINDEX_CMD_NAME für den Teil in der Makefile / make.bat.\n"
              "Der Standardwert ist: makeindex.\n"
              "Dieses Tag erfordert, dass das Tag GENERATE_LATEX auf YES gesetzt ist."
          );
  doc->add(
              "COMPACT_LATEX",
              "Wenn das COMPACT_LATEX-Tag auf YES gesetzt ist, generiert Doxygen kompaktere\n"
              "LaTeX-Dokumente. Dies kann für kleine Projekte nützlich sein und kann dazu\n"
              "beitragen, im Allgemeinen einige Bäume zu sparen.\n"
              "Der Standardwert ist: NO.\n"
              "Dieses Tag erfordert, dass das Tag GENERATE_LATEX auf YES gesetzt ist."
          );
  doc->add(
              "PAPER_TYPE",
              "Das PAPER_TYPE-Tag kann verwendet werden, um das Papierformat festzulegen, das\n"
              "vom Drucker verwendet wird. Mögliche Werte sind: a4, letter, legal und\n"
              "executive.\n"
              "Mögliche Werte sind: a4 (210 x 297 mm), letter (8,5 x 11 Zoll), legal (8,5 x\n"
              "14 Zoll) und executive (7,25 x 10,5 Zoll).\n"
              "Der Standardwert ist: a4.\n"
              "Dieses Tag erfordert, dass das Tag GENERATE_LATEX auf YES gesetzt ist."
          );
  doc->add(
              "EXTRA_PACKAGES",
              "Das EXTRA_PACKAGES-Tag kann verwendet werden, um einen oder mehrere LaTeX-\n"
              "Paketnamen anzugeben, die in die LaTeX-Ausgabe aufgenommen werden sollen. Das\n"
              "Paket kann nur durch seinen Namen oder mit der korrekten Syntax für die\n"
              "Verwendung mit dem LaTeX-Befehl \\usepackage angegeben werden. Um\n"
              "beispielsweise die times-Schrift zu erhalten, können Sie angeben:\n"
              "EXTRA_PACKAGES=times oder EXTRA_PACKAGES={times}\n"
              "Um die Option intlimits mit dem amsmath-Paket zu verwenden, können Sie\n"
              "angeben:\n"
              "EXTRA_PACKAGES=[intlimits]{amsmath}\n"
              "Wenn leer gelassen, werden keine zusätzlichen Pakete aufgenommen.\n"
              "Dieses Tag erfordert, dass das Tag GENERATE_LATEX auf YES gesetzt ist."
          );
  doc->add(
              "LATEX_HEADER",
              "Das LATEX_HEADER-Tag kann verwendet werden, um einen benutzerdefinierten\n"
              "LaTeX-Header für das generierte LaTeX-Dokument anzugeben. Der Header sollte\n"
              "alles bis zum ersten Kapitel enthalten. Wenn er leer gelassen wird, generiert\n"
              "Doxygen einen Standard-Header. Es wird dringend empfohlen, mit einem Standard-\n"
              "Header zu beginnen, indem Sie\n"
              "doxygen -w latex new_header.tex new_footer.tex new_stylesheet.sty\n"
              "verwenden und dann die Datei new_header.tex ändern. Siehe auch Abschnitt\n"
              "\"Doxygen usage\" für Informationen zum Generieren des Standard-Headers, den\n"
              "Doxygen normalerweise verwendet.\n"
              "\n"
              "Hinweis: Verwenden Sie nur einen benutzerdefinierten Header, wenn Sie wissen,\n"
              "was Sie tun!\n"
              "Hinweis: Der Header kann sich ändern, daher müssen Sie normalerweise den\n"
              "Standard-Header regenerieren, wenn Sie auf eine neuere Version von Doxygen\n"
              "aktualisieren. Für eine Beschreibung der möglichen Marker und Blocknamen siehe\n"
              "die Dokumentation.\n"
              "Dieses Tag erfordert, dass das Tag GENERATE_LATEX auf YES gesetzt ist."
          );
  doc->add(
              "LATEX_FOOTER",
              "Das LATEX_FOOTER-Tag kann verwendet werden, um einen benutzerdefinierten\n"
              "LaTeX-Footer für das generierte LaTeX-Dokument anzugeben. Der Footer sollte\n"
              "alles nach dem letzten Kapitel enthalten. Wenn er leer gelassen wird,\n"
              "generiert Doxygen einen Standard-Footer. Siehe LATEX_HEADER für weitere\n"
              "Informationen zum Generieren eines Standard-Footers und welche speziellen\n"
              "Befehle im Footer verwendet werden können. Siehe auch Abschnitt \"Doxygen\n"
              "usage\" für Informationen zum Generieren des Standard-Footers, den Doxygen\n"
              "normalerweise verwendet. Hinweis: Verwenden Sie nur einen benutzerdefinierten\n"
              "Footer, wenn Sie wissen, was Sie tun!\n"
              "Dieses Tag erfordert, dass das Tag GENERATE_LATEX auf YES gesetzt ist."
          );
  doc->add(
              "LATEX_EXTRA_STYLESHEET",
              "Das LATEX_EXTRA_STYLESHEET-Tag kann verwendet werden, um zusätzliche\n"
              "benutzerdefinierte LaTeX-Stylesheets anzugeben, die nach den von Doxygen\n"
              "erstellten Standard-Stylesheets eingebunden werden. Mit dieser Option können\n"
              "bestimmte Stilaspekte überschrieben werden. Doxygen kopiert die Stylesheet-\n"
              "Dateien in das Ausgabeverzeichnis.\n"
              "Hinweis: Die Reihenfolge der zusätzlichen Stylesheet-Dateien ist wichtig (z.B.\n"
              "das letzte Stylesheet in der Liste überschreibt die Einstellungen der\n"
              "vorherigen in der Liste).\n"
              "Dieses Tag erfordert, dass das Tag GENERATE_LATEX auf YES gesetzt ist."
          );
  doc->add(
              "LATEX_EXTRA_FILES",
              "Das LATEX_EXTRA_FILES-Tag kann verwendet werden, um ein oder mehrere\n"
              "zusätzliche Bilder oder andere Quelldateien anzugeben, die in das\n"
              "LATEX_OUTPUT-Ausgabeverzeichnis kopiert werden sollen. Beachten Sie, dass die\n"
              "Dateien wie sie sind kopiert werden; es sind keine Befehle oder Marker\n"
              "verfügbar.\n"
              "Dieses Tag erfordert, dass das Tag GENERATE_LATEX auf YES gesetzt ist."
          );
  doc->add(
              "PDF_HYPERLINKS",
              "Wenn das PDF_HYPERLINKS-Tag auf YES gesetzt ist, ist das generierte LaTeX für\n"
              "die Konvertierung zu PDF vorbereitet (mit ps2pdf oder pdflatex). Die PDF-Datei\n"
              "wird Links (genau wie die HTML-Ausgabe) anstelle von Seitenreferenzen\n"
              "enthalten. Dies macht die Ausgabe für die Online-Anzeige mit einem PDF-Viewer\n"
              "geeignet.\n"
              "Der Standardwert ist: YES.\n"
              "Dieses Tag erfordert, dass das Tag GENERATE_LATEX auf YES gesetzt ist."
          );
  doc->add(
              "USE_PDFLATEX",
              "Wenn das USE_PDFLATEX-Tag auf YES gesetzt ist, verwendet Doxygen die mit\n"
              "LATEX_CMD_NAME angegebene Engine, um die PDF-Datei direkt aus den LaTeX-\n"
              "Dateien zu generieren. Setzen Sie diese Option auf YES, um eine PDF-\n"
              "Dokumentation höherer Qualität zu erhalten.\n"
              "\n"
              "Siehe auch Abschnitt LATEX_CMD_NAME für die Auswahl der Engine.\n"
              "Der Standardwert ist: YES.\n"
              "Dieses Tag erfordert, dass das Tag GENERATE_LATEX auf YES gesetzt ist."
          );
  doc->add(
              "LATEX_BATCHMODE",
              "Wenn das LATEX_BATCHMODE-Tag auf YES gesetzt ist, führt Doxygen den LaTeX-\n"
              "Compiler im Batch-Modus aus, was bedeutet, dass er nicht bei Fehlern anhält.\n"
              "Mögliche Werte sind: NO gleich wie ERROR_STOP, YES gleich wie BATCH, BATCH Im\n"
              "Batch-Modus wird nichts auf dem Terminal ausgegeben, Fehler werden so\n"
              "gescrollt, als ob bei jedem Fehler <Return> gedrückt würde; fehlende Dateien,\n"
              "die TeX versucht einzulesen oder über Tastatureingabe anzufordern (\\read auf\n"
              "einem nicht geöffneten Eingabestream), führen zum Abbruch des Auftrags,\n"
              "NON_STOP Im Nonstop-Modus erscheint die Diagnosemeldung auf dem Terminal, aber\n"
              "es gibt keine Möglichkeit der Benutzerinteraktion, genau wie im Batch-Modus,\n"
              "SCROLL Im Scroll-Modus hält TeX nur an, um fehlende Dateien einzulesen oder\n"
              "wenn Tastatureingabe erforderlich ist und ERROR_STOP Im Errorstop-Modus hält\n"
              "TeX bei jedem Fehler an und fordert Benutzerintervention.\n"
              "Der Standardwert ist: NO.\n"
              "Dieses Tag erfordert, dass das Tag GENERATE_LATEX auf YES gesetzt ist."
          );
  doc->add(
              "LATEX_HIDE_INDICES",
              "Wenn das LATEX_HIDE_INDICES-Tag auf YES gesetzt ist, wird Doxygen die\n"
              "Indexkapitel (wie Datei-Index, Verbund-Index usw.) nicht in die Ausgabe\n"
              "aufnehmen.\n"
              "Der Standardwert ist: NO.\n"
              "Dieses Tag erfordert, dass das Tag GENERATE_LATEX auf YES gesetzt ist."
          );
  doc->add(
              "LATEX_BIB_STYLE",
              "Das LATEX_BIB_STYLE-Tag kann verwendet werden, um den Stil der Bibliographie\n"
              "anzugeben, der vom bibtex-Tool verwendet wird. Standardmäßig ist dies auf\n"
              "plainnat gesetzt.\n"
              "Der Standardwert ist: plainnat.\n"
              "Dieses Tag erfordert, dass das Tag GENERATE_LATEX auf YES gesetzt ist."
          );
  doc->add(
              "LATEX_EMOJI_DIRECTORY",
              "Das LATEX_EMOJI_DIRECTORY-Tag wird verwendet, um den Pfad anzugeben, aus dem\n"
              "die Emoji-Bilder gelesen werden. Wenn leer gelassen, wird das Standard-Emoji-\n"
              "Verzeichnis verwendet.\n"
              "Dieses Tag erfordert, dass das Tag GENERATE_LATEX auf YES gesetzt ist."
          );
  doc->add(
              "GENERATE_RTF",
              "Wenn das GENERATE_RTF-Tag auf YES gesetzt ist, generiert Doxygen RTF-Ausgabe.\n"
              "Die RTF-Ausgabe ist für Word 97 optimiert und kann mit anderen RTF-\n"
              "Lesern/Editoren nicht sehr schön aussehen.\n"
              "Der Standardwert ist: NO."
          );
  doc->add(
              "RTF_OUTPUT",
              "Das RTF_OUTPUT-Tag wird verwendet, um anzugeben, wo die RTF-Dokumente\n"
              "platziert werden. Wenn ein relativer Pfad eingegeben wird, wird der Wert von\n"
              "OUTPUT_DIRECTORY davor gesetzt.\n"
              "Das Standardverzeichnis ist: rtf.\n"
              "Dieses Tag erfordert, dass das Tag GENERATE_RTF auf YES gesetzt ist."
          );
  doc->add(
              "COMPACT_RTF",
              "Wenn das COMPACT_RTF-Tag auf YES gesetzt ist, generiert Doxygen kompaktere\n"
              "RTF-Dokumente. Dies kann für kleine Projekte nützlich sein und kann dazu\n"
              "beitragen, im Allgemeinen einige Bäume zu sparen.\n"
              "Der Standardwert ist: NO.\n"
              "Dieses Tag erfordert, dass das Tag GENERATE_RTF auf YES gesetzt ist."
          );
  doc->add(
              "RTF_HYPERLINKS",
              "Wenn das RTF_HYPERLINKS-Tag auf YES gesetzt ist, kann die generierte RTF-\n"
              "Ausgabe Links enthalten. Dies erfordert, dass die Ausgabedatei von Anwendungen\n"
              "wie Word oder WordPad gelesen wird, die RTF-Links unterstützen. Für andere\n"
              "Anwendungen erscheinen die Links als normaler Text.\n"
              "Der Standardwert ist: NO.\n"
              "Dieses Tag erfordert, dass das Tag GENERATE_RTF auf YES gesetzt ist."
          );
  doc->add(
              "RTF_STYLESHEET_FILE",
              "Laden Sie Stylesheet-Definitionen aus einer Datei. Die Syntax ist ähnlich wie\n"
              "die Konfigurationsdatei von Doxygen, d.h. eine Reihe von Zuweisungen. Sie\n"
              "müssen nur Ersetzungen angeben, fehlende Definitionen werden auf ihren\n"
              "Standardwert gesetzt.\n"
              "\n"
              "Siehe auch Abschnitt \"Doxygen usage\" für Informationen zum Generieren des\n"
              "Standard-Stylesheets, das Doxygen normalerweise verwendet.\n"
              "Dieses Tag erfordert, dass das Tag GENERATE_RTF auf YES gesetzt ist."
          );
  doc->add(
              "RTF_EXTENSIONS_FILE",
              "Setzen Sie optionale Variablen, die bei der Generierung eines RTF-Dokuments\n"
              "verwendet werden. Die Syntax ist ähnlich wie die Konfigurationsdatei von\n"
              "Doxygen. Eine Vorlage für Erweiterungsdateien kann mit doxygen -e rtf\n"
              "extensionFile generiert werden.\n"
              "Dieses Tag erfordert, dass das Tag GENERATE_RTF auf YES gesetzt ist."
          );
  doc->add(
              "RTF_EXTRA_FILES",
              "Das RTF_EXTRA_FILES-Tag kann verwendet werden, um ein oder mehrere zusätzliche\n"
              "Bilder oder andere Quelldateien anzugeben, die in das RTF-Ausgabeverzeichnis\n"
              "kopiert werden sollen. Beachten Sie, dass die Dateien wie sie sind kopiert\n"
              "werden; es sind keine Befehle oder Marker verfügbar.\n"
              "Dieses Tag erfordert, dass das Tag GENERATE_RTF auf YES gesetzt ist."
          );
  doc->add(
              "GENERATE_MAN",
              "Wenn das GENERATE_MAN-Tag auf YES gesetzt ist, generiert Doxygen Man-Pages für\n"
              "Klassen und Dateien.\n"
              "Der Standardwert ist: NO."
          );
  doc->add(
              "MAN_OUTPUT",
              "Das MAN_OUTPUT-Tag wird verwendet, um anzugeben, wo die Man-Pages platziert\n"
              "werden. Wenn ein relativer Pfad eingegeben wird, wird der Wert von\n"
              "OUTPUT_DIRECTORY davor gesetzt. Ein Verzeichnis man3 wird innerhalb des von\n"
              "MAN_OUTPUT angegebenen Verzeichnisses erstellt.\n"
              "Das Standardverzeichnis ist: man.\n"
              "Dieses Tag erfordert, dass das Tag GENERATE_MAN auf YES gesetzt ist."
          );
  doc->add(
              "MAN_EXTENSION",
              "Das MAN_EXTENSION-Tag bestimmt die Erweiterung, die den generierten Man-Pages\n"
              "hinzugefügt wird. Falls der Handbuchabschnitt nicht mit einer Zahl beginnt,\n"
              "wird die Zahl 3 vorangestellt. Der Punkt (.) am Anfang des MAN_EXTENSION-Tags\n"
              "ist optional.\n"
              "Der Standardwert ist: .3.\n"
              "Dieses Tag erfordert, dass das Tag GENERATE_MAN auf YES gesetzt ist."
          );
  doc->add(
              "MAN_SUBDIR",
              "Das MAN_SUBDIR-Tag bestimmt den Namen des Verzeichnisses, das innerhalb von\n"
              "MAN_OUTPUT erstellt wird, in dem die Man-Pages platziert werden. Standardmäßig\n"
              "ist dies man gefolgt von MAN_EXTENSION ohne den anfänglichen ..\n"
              "Dieses Tag erfordert, dass das Tag GENERATE_MAN auf YES gesetzt ist."
          );
  doc->add(
              "MAN_LINKS",
              "Wenn das MAN_LINKS-Tag auf YES gesetzt ist und Doxygen Man-Ausgabe generiert,\n"
              "wird es eine zusätzliche Man-Datei für jede Entität generieren, die in den\n"
              "echten Man-Pages dokumentiert ist. Diese zusätzlichen Dateien verweisen nur\n"
              "auf die echte Man-Page, aber ohne sie wäre der man-Befehl nicht in der Lage,\n"
              "die richtige Seite zu finden.\n"
              "Der Standardwert ist: NO.\n"
              "Dieses Tag erfordert, dass das Tag GENERATE_MAN auf YES gesetzt ist."
          );
  doc->add(
              "GENERATE_XML",
              "Wenn das GENERATE_XML-Tag auf YES gesetzt ist, generiert Doxygen eine XML-\n"
              "Datei, die den Code und die Dokumentation erfasst.\n"
              "Der Standardwert ist: NO."
          );
  doc->add(
              "XML_OUTPUT",
              "Das XML_OUTPUT-Tag wird verwendet, um anzugeben, wo die XML-Seiten platziert\n"
              "werden. Wenn ein relativer Pfad eingegeben wird, wird der Wert von\n"
              "OUTPUT_DIRECTORY davor gesetzt.\n"
              "Das Standardverzeichnis ist: xml.\n"
              "Dieses Tag erfordert, dass das Tag GENERATE_XML auf YES gesetzt ist."
          );
  doc->add(
              "XML_PROGRAMLISTING",
              "Wenn das XML_PROGRAMLISTING-Tag auf YES gesetzt ist, gibt Doxygen die\n"
              "Programmauflistungen (einschließlich Syntaxhervorhebung und\n"
              "Querverweisinformationen) in die XML-Ausgabe. Beachten Sie, dass die\n"
              "Aktivierung dieser Option die Größe der XML-Ausgabe erheblich vergrößert.\n"
              "Der Standardwert ist: YES.\n"
              "Dieses Tag erfordert, dass das Tag GENERATE_XML auf YES gesetzt ist."
          );
  doc->add(
              "XML_NS_MEMB_FILE_SCOPE",
              "Wenn das XML_NS_MEMB_FILE_SCOPE-Tag auf YES gesetzt ist, wird Doxygen\n"
              "Namensbereich-Mitglieder auch im Dateibereich aufnehmen, passend zur HTML-\n"
              "Ausgabe.\n"
              "Der Standardwert ist: NO.\n"
              "Dieses Tag erfordert, dass das Tag GENERATE_XML auf YES gesetzt ist."
          );
  doc->add(
              "GENERATE_DOCBOOK",
              "Wenn das GENERATE_DOCBOOK-Tag auf YES gesetzt ist, generiert Doxygen Docbook-\n"
              "Dateien, die zur Erstellung von PDF verwendet werden können.\n"
              "Der Standardwert ist: NO."
          );
  doc->add(
              "DOCBOOK_OUTPUT",
              "Das DOCBOOK_OUTPUT-Tag wird verwendet, um anzugeben, wo die Docbook-Seiten\n"
              "platziert werden. Wenn ein relativer Pfad eingegeben wird, wird der Wert von\n"
              "OUTPUT_DIRECTORY davor gesetzt.\n"
              "Das Standardverzeichnis ist: docbook.\n"
              "Dieses Tag erfordert, dass das Tag GENERATE_DOCBOOK auf YES gesetzt ist."
          );
  doc->add(
              "GENERATE_AUTOGEN_DEF",
              "Wenn das GENERATE_AUTOGEN_DEF-Tag auf YES gesetzt ist, generiert Doxygen eine\n"
              "AutoGen Definitions-Datei (siehe https://autogen.sourceforge.net/), die die\n"
              "Struktur des Codes einschließlich aller Dokumentation erfasst. Beachten Sie,\n"
              "dass diese Funktion derzeit noch experimentell und unvollständig ist.\n"
              "Der Standardwert ist: NO."
          );
  doc->add(
              "GENERATE_SQLITE3",
              "Wenn das GENERATE_SQLITE3-Tag auf YES gesetzt ist, generiert Doxygen eine\n"
              "Sqlite3-Datenbank mit Symbolen, die von der Suchmaschine verwendet werden\n"
              "kann.\n"
              "Der Standardwert ist: NO."
          );
  doc->add(
              "SQLITE3_OUTPUT",
              "Das SQLITE3_OUTPUT-Tag wird verwendet, um anzugeben, wo die Sqlite3-Datenbank\n"
              "platziert wird. Wenn ein relativer Pfad eingegeben wird, wird der Wert von\n"
              "OUTPUT_DIRECTORY davor gesetzt.\n"
              "Das Standardverzeichnis ist: sqlite3.\n"
              "Dieses Tag erfordert, dass das Tag GENERATE_SQLITE3 auf YES gesetzt ist."
          );
  doc->add(
              "SQLITE3_RECREATE_DB",
              "Wenn das SQLITE3_RECREATE_DB-Tag auf YES gesetzt ist, wird die vorhandene\n"
              "doxygen_sqlite3.db-Datenbankdatei bei jedem Doxygen-Lauf neu erstellt. Wenn\n"
              "auf NO gesetzt, warnt Doxygen, wenn eine Datenbankdatei bereits gefunden wird,\n"
              "und ändert sie nicht.\n"
              "Der Standardwert ist: YES.\n"
              "Dieses Tag erfordert, dass das Tag GENERATE_SQLITE3 auf YES gesetzt ist."
          );
  doc->add(
              "GENERATE_PERLMOD",
              "Wenn das GENERATE_PERLMOD-Tag auf YES gesetzt ist, generiert Doxygen eine\n"
              "Perl-Modul-Datei, die bestimmte Informationen über den Code in einer für Perl-\n"
              "Module geeigneten Form erfasst.\n"
              "Der Standardwert ist: NO."
          );
  doc->add(
              "PERLMOD_LATEX",
              "Wenn das PERLMOD_LATEX-Tag auf YES gesetzt ist, generiert Doxygen die\n"
              "notwendigen Makefile-Regeln, Perl-Skripte und LaTeX-Code, um PDF- und DVI-\n"
              "Ausgabe aus der Perl-Modul-Ausgabe generieren zu können.\n"
              "Der Standardwert ist: NO.\n"
              "Dieses Tag erfordert, dass das Tag GENERATE_PERLMOD auf YES gesetzt ist."
          );
  doc->add(
              "PERLMOD_PRETTY",
              "Wenn das PERLMOD_PRETTY-Tag auf YES gesetzt ist, wird die Perl-Modul-Ausgabe\n"
              "schön formatiert, sodass sie von einem menschlichen Leser geparst werden kann.\n"
              "Dies ist nützlich, wenn Sie verstehen möchten, was passiert. Auf der anderen\n"
              "Seite, wenn dieses Tag auf NO gesetzt ist, wird die Größe der Perl-Modul-\n"
              "Ausgabe viel kleiner sein und Perl wird sie genauso parsen.\n"
              "Der Standardwert ist: YES.\n"
              "Dieses Tag erfordert, dass das Tag GENERATE_PERLMOD auf YES gesetzt ist."
          );
  doc->add(
              "PERLMOD_MAKEVAR_PREFIX",
              "Die Namen der Make-Variablen in der generierten doxyrules.make-Datei werden\n"
              "mit der Zeichenfolge vorangestellt, die in PERLMOD_MAKEVAR_PREFIX enthalten\n"
              "ist. Dies ist nützlich, damit verschiedene doxyrules.make-Dateien, die von\n"
              "derselben Makefile eingebunden werden, die Variablen der anderen nicht\n"
              "überschreiben.\n"
              "Dieses Tag erfordert, dass das Tag GENERATE_PERLMOD auf YES gesetzt ist."
          );
  doc->add(
              "ENABLE_PREPROCESSING",
              "Wenn das ENABLE_PREPROCESSING-Tag auf YES gesetzt ist, wertet Doxygen alle\n"
              "C-Präprozessor-Direktiven aus.\n"
              "Der Standardwert ist: YES."
          );
  doc->add(
              "MACRO_EXPANSION",
              "Wenn das MACRO_EXPANSION-Tag auf YES gesetzt ist, expandiert Doxygen alle\n"
              "Makronamen im Quellcode. Wenn auf NO gesetzt, wird nur bedingte Kompilierung\n"
              "durchgeführt. Makro-Expansion kann kontrolliert werden, indem\n"
              "EXPAND_ONLY_PREDEF auf YES gesetzt wird.\n"
              "Der Standardwert ist: NO.\n"
              "Dieses Tag erfordert, dass das Tag ENABLE_PREPROCESSING auf YES gesetzt ist."
          );
  doc->add(
              "EXPAND_ONLY_PREDEF",
              "Wenn die Tags EXPAND_ONLY_PREDEF und MACRO_EXPANSION beide auf YES gesetzt\n"
              "sind, ist die Makroexpansion beschränkt auf die mit EXPAND_AS_DEFINED\n"
              "angegebenen Makros.\n"
              "Der Standardwert ist: NO.\n"
              "Dieses Tag erfordert, dass das Tag ENABLE_PREPROCESSING auf YES gesetzt ist."
          );
  doc->add(
              "SEARCH_INCLUDES",
              "Wenn das SEARCH_INCLUDES-Tag auf YES gesetzt ist, sind die Include-\n"
              "Abhängigkeiten in der Liste der Dateien, die durchsucht werden, enthalten.\n"
              "Der Standardwert ist: YES.\n"
              "Dieses Tag erfordert, dass das Tag ENABLE_PREPROCESSING auf YES gesetzt ist."
          );
  doc->add(
              "INCLUDE_PATH",
              "Das INCLUDE_PATH-Tag kann verwendet werden, um ein oder mehrere Verzeichnisse\n"
              "anzugeben, die Include-Dateien enthalten, die keine Eingabedateien sind, aber\n"
              "vom Präprozessor verarbeitet werden sollen. Beachten Sie, dass der\n"
              "INCLUDE_PATH nicht rekursiv ist, sodass die Einstellung von RECURSIVE hier\n"
              "keine Auswirkung hat.\n"
              "Dieses Tag erfordert, dass das Tag SEARCH_INCLUDES auf YES gesetzt ist."
          );
  doc->add(
              "INCLUDE_FILE_PATTERNS",
              "Sie können das INCLUDE_FILE_PATTERNS-Tag verwenden, um ein oder mehrere\n"
              "Platzhaltermuster (wie *.h und *.hpp) anzugeben, um die Header-Dateien in den\n"
              "Verzeichnissen zu filtern. Wenn leer gelassen, werden die mit FILE_PATTERNS\n"
              "angegebenen Muster verwendet.\n"
              "Dieses Tag erfordert, dass das Tag ENABLE_PREPROCESSING auf YES gesetzt ist."
          );
  doc->add(
              "PREDEFINED",
              "Das PREDEFINED-Tag kann verwendet werden, um einen oder mehrere Makronamen\n"
              "anzugeben, die definiert sind, bevor der Präprozessor gestartet wird (ähnlich\n"
              "der -D-Option von z.B. gcc). Das Argument des Tags ist eine Liste von Makros\n"
              "der Form: name oder name=definition (keine Leerzeichen). Wenn die Definition\n"
              "und das \"=\" weggelassen werden, wird \"=1\" angenommen. Um zu verhindern, dass\n"
              "eine Makrodefinition über #undef aufgehoben oder rekursiv expandiert wird,\n"
              "verwenden Sie den :=-Operator anstelle des =-Operators.\n"
              "Dieses Tag erfordert, dass das Tag ENABLE_PREPROCESSING auf YES gesetzt ist."
          );
  doc->add(
              "EXPAND_AS_DEFINED",
              "Wenn die Tags MACRO_EXPANSION und EXPAND_ONLY_PREDEF auf YES gesetzt sind,\n"
              "kann dieses Tag verwendet werden, um eine Liste von Makronamen anzugeben, die\n"
              "expandiert werden sollen.\n"
              "Dieses Tag erfordert, dass das Tag ENABLE_PREPROCESSING auf YES gesetzt ist."
          );
  doc->add(
              "SKIP_FUNCTION_MACROS",
              "Dieses Tag kann verwendet werden, um die Liste der Funktionsmakros zu\n"
              "spezifizieren, die in der Dokumentation übersprungen werden sollen.\n"
              "Funktionsmakros sind Makros, die wie Funktionen aussehen und Parameter haben.\n"
              "Der Standardwert ist: YES.\n"
              "Dieses Tag erfordert, dass das Tag ENABLE_PREPROCESSING auf YES gesetzt ist."
          );
  doc->add(
              "TAGFILES",
              "Das TAGFILES-Tag kann verwendet werden, um eine oder mehrere Tag-Dateien\n"
              "anzugeben. Für jede Tag-Datei sollte der Speicherort der externen\n"
              "Dokumentation hinzugefügt werden. Das Format einer Tag-Datei ohne diesen\n"
              "Speicherort ist wie folgt:\n"
              "TAGFILES = file1 file2 ...\n"
              "Das Hinzufügen des Speicherorts für die Tag-Dateien erfolgt wie folgt:\n"
              "TAGFILES = file1=loc1 \"file2 = loc2\" ...\n"
              "wobei loc1 und loc2 relative oder absolute Pfade oder URLs sein können. Siehe\n"
              "den Abschnitt \"Linking to external documentation\" für weitere Informationen\n"
              "zur Verwendung von Tag-Dateien.\n"
              "Hinweis: Jede Tag-Datei muss einen eindeutigen Namen haben (wobei der Name den\n"
              "Pfad NICHT enthält). Wenn eine Tag-Datei nicht in dem Verzeichnis liegt, in\n"
              "dem Doxygen ausgeführt wird, müssen Sie auch den Pfad zur Tag-Datei hier\n"
              "angeben."
          );
  doc->add(
              "GENERATE_TAGFILE",
              "Wenn ein Dateiname nach GENERATE_TAGFILE angegeben wird, erstellt Doxygen eine\n"
              "Tag-Datei, die von einem anderen Projekt verwendet werden kann, um Verweise\n"
              "auf dieses Projekt zu erstellen."
          );
  doc->add(
              "ALLEXTERNALS",
              "Wenn das ALLEXTERNALS-Tag auf YES gesetzt ist, werden alle externen Klassen\n"
              "und Namensbereiche im Klassen- und Namensbereichindex aufgelistet. Wenn auf NO\n"
              "gesetzt, werden nur die geerbten externen Klassen aufgelistet.\n"
              "Der Standardwert ist: NO."
          );
  doc->add(
              "EXTERNAL_GROUPS",
              "Wenn das EXTERNAL_GROUPS-Tag auf YES gesetzt ist, werden alle externen Gruppen\n"
              "im Themenindex aufgeführt. Wenn auf NO gesetzt, werden nur die Gruppen des\n"
              "aktuellen Projekts aufgeführt.\n"
              "Der Standardwert ist: YES."
          );
  doc->add(
              "EXTERNAL_PAGES",
              "Wenn das EXTERNAL_PAGES-Tag auf YES gesetzt ist, werden alle externen Seiten\n"
              "im Related-Pages-Index aufgeführt. Wenn auf NO gesetzt, werden nur die Seiten\n"
              "des aktuellen Projekts aufgeführt.\n"
              "Der Standardwert ist: YES."
          );
  doc->add(
              "HIDE_UNDOC_RELATIONS",
              "Wenn auf YES gesetzt, blenden die Vererbungs- und Kollaborationsdiagramme\n"
              "Vererbungs- und Verwendungsbeziehungen aus, wenn das Ziel undokumentiert ist\n"
              "oder keine Klasse ist.\n"
              "Der Standardwert ist: YES."
          );
  doc->add(
              "HAVE_DOT",
              "Wenn Sie das HAVE_DOT-Tag auf YES setzen, geht Doxygen davon aus, dass das\n"
              "dot-Tool im path verfügbar ist. Dieses Tool ist Teil von Graphviz (see:\n"
              "https://www.graphviz.org/), einem Graphvisualisierungstoolkit von AT&T und\n"
              "Lucent Bell Labs. Die anderen Optionen in diesem Abschnitt haben keine\n"
              "Auswirkung, wenn diese Option auf NO gesetzt ist.\n"
              "Der Standardwert ist: NO."
          );
  doc->add(
              "DOT_NUM_THREADS",
              "Das DOT_NUM_THREADS gibt die Anzahl der dot-Aufrufe an, die Doxygen parallel\n"
              "ausführen darf. Wenn auf 0 gesetzt, wird Doxygen dies auf der Anzahl der im\n"
              "System verfügbaren Prozessoren basieren. Sie können es explizit auf einen Wert\n"
              "größer als 0 setzen, um die Kontrolle über das Gleichgewicht zwischen CPU-Last\n"
              "und Verarbeitungsgeschwindigkeit zu erhalten.\n"
              "Mindestwert: 0, Höchstwert: 512, Standardwert: 0.\n"
              "Dieses Tag erfordert, dass das Tag HAVE_DOT auf YES gesetzt ist."
          );
  doc->add(
              "DOT_BATCH_SIZE",
              "Das DOT_BATCH_SIZE gibt die Anzahl der dot-Graphen an, die Doxygen in einem\n"
              "einzigen dot-Aufruf kompilieren darf. Wenn auf 1 gesetzt, wird Doxygen dot für\n"
              "jeden Graphen separat aufrufen, was zu erheblichem Prozess-Erstellungsaufwand\n"
              "führen kann, insbesondere auf Systemen mit vielen CPU-Kernen. Zusammen mit\n"
              "DOT_NUM_THREADS kann diese Einstellung verwendet werden, um die dot-\n"
              "Verarbeitungsgeschwindigkeit für ein bestimmtes System zu optimieren. Doxygen\n"
              "wird versuchen, jedem Thread eine ausgewogene Arbeitsmenge zuzuweisen. Wenn\n"
              "die Gesamtzahl der zu verarbeitenden Graphen DOT_NUM_THREADS * DOT_BATCH_SIZE\n"
              "überschreitet, werden zusätzliche Batches für dot erstellt.\n"
              "Mindestwert: 1, Höchstwert: 1000, Standardwert: 50.\n"
              "Dieses Tag erfordert, dass das Tag HAVE_DOT auf YES gesetzt ist."
          );
  doc->add(
              "DOT_COMMON_ATTR",
              "DOT_COMMON_ATTR sind gemeinsame Attribute für Knoten, Kanten und Labels von\n"
              "Untergraphen. Wenn Sie eine anders aussehende Schrift in den von Doxygen\n"
              "generierten dot-Dateien möchten, können Sie die Attribute fontname, fontcolor\n"
              "und fontsize angeben. Für Details siehe <a\n"
              "href=https://graphviz.org/doc/info/attrs.html>Node, Edge and Graph Attributes\n"
              "specification</a>. Sie müssen sicherstellen, dass dot die Schrift finden kann,\n"
              "was erreicht werden kann, indem Sie sie an einem Standardort platzieren oder\n"
              "die Umgebungsvariable DOTFONTPATH setzen oder DOT_FONTPATH auf das Verzeichnis\n"
              "setzen, das die Schrift enthält. Die Standard-Schriftgröße von graphviz ist\n"
              "14.\n"
              "Der Standardwert ist: fontname=Helvetica,fontsize=10.\n"
              "Dieses Tag erfordert, dass das Tag HAVE_DOT auf YES gesetzt ist."
          );
  doc->add(
              "DOT_EDGE_ATTR",
              "DOT_EDGE_ATTR wird mit DOT_COMMON_ATTR verkettet. Für einen eleganten Stil\n"
              "können Sie 'arrowhead=open, arrowtail=open, arrowsize=0.5' hinzufügen. <a\n"
              "href=https://graphviz.org/doc/info/arrows.html>Vollständige Dokumentation über\n"
              "Pfeilformen.</a>\n"
              "Der Standardwert ist: labelfontname=Helvetica,labelfontsize=10.\n"
              "Dieses Tag erfordert, dass das Tag HAVE_DOT auf YES gesetzt ist."
          );
  doc->add(
              "DOT_NODE_ATTR",
              "DOT_NODE_ATTR wird mit DOT_COMMON_ATTR verkettet. Für eine Ansicht ohne\n"
              "Kasten um Knoten setzen Sie 'shape=plain' oder 'shape=plaintext'. <a\n"
              "href=https://www.graphviz.org/doc/info/shapes.html>Shapes specification</a>\n"
              "Der Standardwert ist: shape=box,height=0.2,width=0.4.\n"
              "Dieses Tag erfordert, dass das Tag HAVE_DOT auf YES gesetzt ist."
          );
  doc->add(
              "DOT_FONTPATH",
              "Sie können den Pfad festlegen, in dem dot die mit fontname in DOT_COMMON_ATTR\n"
              "und anderen dot-Attributen angegebene Schrift finden kann.\n"
              "Dieses Tag erfordert, dass das Tag HAVE_DOT auf YES gesetzt ist."
          );
  doc->add(
              "CLASS_GRAPH",
              "Wenn das CLASS_GRAPH-Tag auf YES oder GRAPH oder BUILTIN gesetzt ist,\n"
              "generiert Doxygen einen Graphen für jede dokumentierte Klasse, der die\n"
              "direkten und indirekten Vererbungsbeziehungen zeigt. Falls das CLASS_GRAPH-Tag\n"
              "auf YES oder GRAPH gesetzt ist und HAVE_DOT ebenfalls aktiviert ist, wird dot\n"
              "verwendet, um den Graphen zu zeichnen. Falls das CLASS_GRAPH-Tag auf YES\n"
              "gesetzt ist und HAVE_DOT deaktiviert ist oder wenn das CLASS_GRAPH-Tag auf\n"
              "BUILTIN gesetzt ist, wird der integrierte Generator verwendet. Wenn das\n"
              "CLASS_GRAPH-Tag auf TEXT gesetzt ist, werden die direkten und indirekten\n"
              "Vererbungsbeziehungen als Texte / Links angezeigt. Das explizite Aktivieren\n"
              "eines Vererbungsgraphen oder die Wahl einer anderen Darstellung für einen\n"
              "Vererbungsgraphen einer bestimmten Klasse kann mit dem Befehl\n"
              "\\inheritancegraph erreicht werden. Das Deaktivieren eines Vererbungsgraphen\n"
              "kann mit dem Befehl \\hideinheritancegraph erreicht werden.\n"
              "Mögliche Werte sind: NO, YES, TEXT, GRAPH und BUILTIN.\n"
              "Der Standardwert ist: YES."
          );
  doc->add(
              "COLLABORATION_GRAPH",
              "Wenn das COLLABORATION_GRAPH-Tag auf YES gesetzt ist, generiert Doxygen einen\n"
              "Graphen für jede dokumentierte Klasse, der die direkten und indirekten\n"
              "Implementierungsabhängigkeiten (Vererbung, Enthaltensein und\n"
              "Klassenreferenzvariablen) der Klasse mit anderen dokumentierten Klassen zeigt.\n"
              "Das explizite Aktivieren eines Kollaborationsdiagramms, wenn\n"
              "COLLABORATION_GRAPH auf NO gesetzt ist, kann mit dem Befehl\n"
              "\\collaborationgraph erreicht werden. Das Deaktivieren eines\n"
              "Kollaborationsdiagramms kann mit dem Befehl \\hidecollaborationgraph erreicht\n"
              "werden.\n"
              "Der Standardwert ist: YES.\n"
              "Dieses Tag erfordert, dass das Tag HAVE_DOT auf YES gesetzt ist."
          );
  doc->add(
              "GROUP_GRAPHS",
              "Wenn das GROUP_GRAPHS-Tag auf YES gesetzt ist, generiert Doxygen einen Graphen\n"
              "für Gruppen, der die direkten Gruppenabhängigkeiten zeigt. Das explizite\n"
              "Aktivieren eines Gruppenabhängigkeitsgraphen, wenn GROUP_GRAPHS auf NO gesetzt\n"
              "ist, kann mit dem Befehl \\groupgraph erreicht werden. Das Deaktivieren eines\n"
              "Gruppenabhängigkeitsgraphen kann mit dem Befehl \\hidegroupgraph erreicht\n"
              "werden. Siehe auch das Kapitel Grouping im Handbuch.\n"
              "Der Standardwert ist: YES.\n"
              "Dieses Tag erfordert, dass das Tag HAVE_DOT auf YES gesetzt ist."
          );
  doc->add(
              "UML_LOOK",
              "Wenn das UML_LOOK-Tag auf YES gesetzt ist, generiert Doxygen Vererbungs- und\n"
              "Kollaborationsdiagramme in einem Stil, der der Unified Modeling Language der\n"
              "OMG ähnelt.\n"
              "Der Standardwert ist: NO.\n"
              "Dieses Tag erfordert, dass das Tag HAVE_DOT auf YES gesetzt ist."
          );
  doc->add(
              "UML_LIMIT_NUM_FIELDS",
              "Wenn das UML_LOOK-Tag aktiviert ist, werden die Felder und Methoden innerhalb\n"
              "des Klassenknotens angezeigt. Wenn es viele Felder oder Methoden und viele\n"
              "Knoten gibt, kann der Graph zu groß werden, um nützlich zu sein. Der\n"
              "UML_LIMIT_NUM_FIELDS-Schwellenwert begrenzt die Anzahl der Elemente für jeden\n"
              "Typ, um die Größe handhabbarer zu machen. Setzen Sie dies auf 0 für kein\n"
              "Limit. Beachten Sie, dass der Schwellenwert um 50% überschritten werden kann,\n"
              "bevor das Limit durchgesetzt wird. Wenn Sie also den Schwellenwert auf 10\n"
              "setzen, können bis zu 15 Felder erscheinen, aber wenn die Anzahl 15\n"
              "überschreitet, wird die Gesamtanzahl der angezeigten Felder auf 10 begrenzt.\n"
              "Mindestwert: 0, Höchstwert: 100, Standardwert: 10.\n"
              "Dieses Tag erfordert, dass das Tag UML_LOOK auf YES gesetzt ist."
          );
  doc->add(
              "UML_MAX_EDGE_LABELS",
              "Wenn das UML_LOOK-Tag aktiviert ist, werden Feldbeschriftungen entlang der\n"
              "Kante zwischen zwei Klassenknoten angezeigt. Wenn es viele Felder und viele\n"
              "Knoten gibt, kann der Graph zu überfüllt werden. Der UML_MAX_EDGE_LABELS-\n"
              "Schwellenwert begrenzt die Anzahl der Elemente, um die Größe handhabbarer zu\n"
              "machen. Setzen Sie dies auf 0 für kein Limit.\n"
              "Mindestwert: 0, Höchstwert: 100, Standardwert: 10.\n"
              "Dieses Tag erfordert, dass das Tag UML_LOOK auf YES gesetzt ist."
          );
  doc->add(
              "DOT_UML_DETAILS",
              "Wenn das DOT_UML_DETAILS-Tag auf NO gesetzt ist, zeigt Doxygen Attribute und\n"
              "Methoden ohne Typen und Argumente in den UML-Graphen. Wenn das\n"
              "DOT_UML_DETAILS-Tag auf YES gesetzt ist, fügt Doxygen Typen und Argumente für\n"
              "Attribute und Methoden in den UML-Graphen hinzu. Wenn das DOT_UML_DETAILS-Tag\n"
              "auf NONE gesetzt ist, generiert Doxygen keine Felder mit\n"
              "Klassenmitgliedsinformationen in den UML-Graphen. Die Klassendiagramme ähneln\n"
              "den Standard-Klassendiagrammen, verwenden aber UML-Notation für die\n"
              "Beziehungen.\n"
              "Mögliche Werte sind: NO, YES und NONE.\n"
              "Der Standardwert ist: NO.\n"
              "Dieses Tag erfordert, dass das Tag UML_LOOK auf YES gesetzt ist."
          );
  doc->add(
              "DOT_WRAP_THRESHOLD",
              "Das DOT_WRAP_THRESHOLD-Tag kann verwendet werden, um die maximale Anzahl von\n"
              "Zeichen festzulegen, die in einer einzelnen Zeile angezeigt werden. Wenn die\n"
              "Zeilenlange diesen Wert überschreitet, wird die Zeile umgebrochen.\n"
              "Mindestwert: 0, Höchstwert: 1000, Standardwert: 17.\n"
              "Dieses Tag erfordert, dass das Tag HAVE_DOT auf YES gesetzt ist."
          );
  doc->add(
              "TEMPLATE_RELATIONS",
              "Wenn das TEMPLATE_RELATIONS-Tag auf YES gesetzt ist, zeigen die Vererbungs-\n"
              "und Kollaborationsdiagramme die Beziehungen zwischen Templates und ihren\n"
              "Instanzen.\n"
              "Der Standardwert ist: NO.\n"
              "Dieses Tag erfordert, dass das Tag HAVE_DOT auf YES gesetzt ist."
          );
  doc->add(
              "INCLUDE_GRAPH",
              "Wenn das INCLUDE_GRAPH-Tag auf YES gesetzt ist, generiert Doxygen für jede\n"
              "dokumentierte Datei einen Graphen, der die direkten und indirekten Include-\n"
              "Abhängigkeiten der Datei mit anderen dokumentierten Dateien zeigt. Das\n"
              "explizite Aktivieren eines Include-Graphen, wenn INCLUDE_GRAPH auf NO gesetzt\n"
              "ist, kann mit dem Befehl \\includegraph erreicht werden. Das Deaktivieren eines\n"
              "Include-Graphen kann mit dem Befehl \\hideincludegraph erreicht werden.\n"
              "Der Standardwert ist: YES.\n"
              "Dieses Tag erfordert, dass das Tag HAVE_DOT auf YES gesetzt ist."
          );
  doc->add(
              "INCLUDED_BY_GRAPH",
              "Wenn das INCLUDED_BY_GRAPH, ENABLE_PREPROCESSING und SEARCH_INCLUDES-Tag auf\n"
              "YES gesetzt sind, generiert Doxygen für jede dokumentierte Datei einen\n"
              "Graphen, der die direkten und indirekten Include-Abhängigkeiten der Datei mit\n"
              "anderen dokumentierten Dateien zeigt. Das explizite Aktivieren eines Included-\n"
              "by-Graphen, wenn INCLUDED_BY_GRAPH auf NO gesetzt ist, kann mit dem Befehl\n"
              "\\includedbygraph erreicht werden. Das Deaktivieren eines Included-by-Graphen\n"
              "kann mit dem Befehl \\hideincludedbygraph erreicht werden.\n"
              "Der Standardwert ist: YES.\n"
              "Dieses Tag erfordert, dass das Tag HAVE_DOT auf YES gesetzt ist."
          );
  doc->add(
              "CALL_GRAPH",
              "Wenn das CALL_GRAPH-Tag auf YES gesetzt ist, generiert Doxygen einen\n"
              "Aufrufabhängigkeitsgraphen für jede globale Funktion oder Klassenmethode.\n"
              "Beachten Sie, dass die Aktivierung dieses Tags die Einstellung HAVE_DOT auf\n"
              "YES voraussetzt. Das explizite Aktivieren eines Aufrufgraphen, wenn CALL_GRAPH\n"
              "auf NO gesetzt ist, kann mit dem Befehl \\callgraph erreicht werden. Das\n"
              "Deaktivieren eines Aufrufgraphen kann mit dem Befehl \\hidecallgraph erreicht\n"
              "werden.\n"
              "Der Standardwert ist: NO.\n"
              "Dieses Tag erfordert, dass das Tag HAVE_DOT auf YES gesetzt ist."
          );
  doc->add(
              "CALLER_GRAPH",
              "Wenn das CALLER_GRAPH-Tag auf YES gesetzt ist, generiert Doxygen einen\n"
              "Aufruferabhängigkeitsgraphen für jede globale Funktion oder Klassenmethode.\n"
              "Beachten Sie, dass die Aktivierung dieses Tags die Einstellung HAVE_DOT auf\n"
              "YES voraussetzt. Das explizite Aktivieren eines Aufrufergraphen, wenn\n"
              "CALLER_GRAPH auf NO gesetzt ist, kann mit dem Befehl \\callergraph erreicht\n"
              "werden. Das Deaktivieren eines Aufrufergraphen kann mit dem Befehl\n"
              "\\hidecallergraph erreicht werden.\n"
              "Der Standardwert ist: NO.\n"
              "Dieses Tag erfordert, dass das Tag HAVE_DOT auf YES gesetzt ist."
          );
  doc->add(
              "GRAPHICAL_HIERARCHY",
              "Wenn das GRAPHICAL_HIERARCHY-Tag auf YES gesetzt ist, zeigt Doxygen eine\n"
              "grafische Hierarchie aller Klassen an. Beachten Sie, dass die Aktivierung\n"
              "dieses Tags die Einstellung HAVE_DOT auf YES voraussetzt.\n"
              "Der Standardwert ist: YES.\n"
              "Dieses Tag erfordert, dass das Tag HAVE_DOT auf YES gesetzt ist."
          );
  doc->add(
              "DIRECTORY_GRAPH",
              "Wenn das DIRECTORY_GRAPH-Tag auf YES gesetzt ist, zeigt Doxygen die\n"
              "Abhängigkeiten eines Verzeichnisses von anderen Verzeichnissen in grafischer\n"
              "Weise an. Die Abhängigkeitsbeziehungen werden durch die \\#include-Beziehungen\n"
              "zwischen den Dateien in den Verzeichnissen bestimmt. Das explizite Aktivieren\n"
              "eines Verzeichnisgraphen, wenn DIRECTORY_GRAPH auf NO gesetzt ist, kann mit\n"
              "dem Befehl \\directorygraph erreicht werden. Das Deaktivieren eines\n"
              "Verzeichnisgraphen kann mit dem Befehl \\hidedirectorygraph erreicht werden.\n"
              "Der Standardwert ist: YES.\n"
              "Dieses Tag erfordert, dass das Tag HAVE_DOT auf YES gesetzt ist."
          );
  doc->add(
              "DIR_GRAPH_MAX_DEPTH",
              "Das DIR_GRAPH_MAX_DEPTH-Tag kann verwendet werden, um die maximale Anzahl von\n"
              "Ebenen untergeordneter Verzeichnisse zu begrenzen, die in\n"
              "Verzeichnisabhängigkeitsgraphen von dot generiert werden.\n"
              "Mindestwert: 1, Höchstwert: 25, Standardwert: 1.\n"
              "Dieses Tag erfordert, dass das Tag DIRECTORY_GRAPH auf YES gesetzt ist."
          );
  doc->add(
              "DOT_IMAGE_FORMAT",
              "Das DOT_IMAGE_FORMAT-Tag kann verwendet werden, um das Bildformat der von dot\n"
              "generierten Bilder festzulegen. Für eine Erklärung der Bildformate siehe den\n"
              "Abschnitt Ausgabeformate in der Dokumentation des dot-Tools (Graphviz (see:\n"
              "https://www.graphviz.org/)).\n"
              "\n"
              "Beachten Sie, dass die Formate svg:cairo und svg:cairo:cairo nicht in\n"
              "Kombination mit INTERACTIVE_SVG verwendet werden können (INTERACTIVE_SVG wird\n"
              "auf NO gesetzt).\n"
              "Mögliche Werte sind: png, jpg, gif, svg, png:gd, png:gd:gd, png:cairo,\n"
              "png:cairo:gd, png:cairo:cairo, png:cairo:gdiplus, png:gdiplus,\n"
              "png:gdiplus:gdiplus, svg:cairo, svg:cairo:cairo, svg:svg, svg:svg:core,\n"
              "gif:cairo, gif:cairo:gd, gif:cairo:gdiplus, gif:gdiplus, gif:gdiplus:gdiplus,\n"
              "gif:gd, gif:gd:gd, jpg:cairo, jpg:cairo:gd, jpg:cairo:gdiplus, jpg:gd,\n"
              "jpg:gd:gd, jpg:gdiplus und jpg:gdiplus:gdiplus.\n"
              "Der Standardwert ist: png.\n"
              "Dieses Tag erfordert, dass das Tag HAVE_DOT auf YES gesetzt ist."
          );
  doc->add(
              "INTERACTIVE_SVG",
              "Wenn DOT_IMAGE_FORMAT auf svg oder svg:svg oder svg:svg:core gesetzt ist, kann\n"
              "diese Option auf YES gesetzt werden, um die Generierung interaktiver SVG-\n"
              "Bilder zu aktivieren, die Zoomen und Schwenken ermöglichen.\n"
              "\n"
              "Beachten Sie, dass dies einen modernen Browser außer Internet Explorer\n"
              "erfordert. Getestet und funktionierend sind Firefox, Chrome, Safari und Opera.\n"
              "\n"
              "Beachten Sie, dass diese Option automatisch deaktiviert wird, wenn\n"
              "DOT_IMAGE_FORMAT auf svg:cairo oder svg:cairo:cairo gesetzt ist.\n"
              "Der Standardwert ist: NO.\n"
              "Dieses Tag erfordert, dass das Tag HAVE_DOT auf YES gesetzt ist."
          );
  doc->add(
              "DOT_PATH",
              "Das DOT_PATH-Tag kann verwendet werden, um den Pfad anzugeben, in dem das dot-\n"
              "Tool gefunden werden kann. Wenn leer gelassen, wird angenommen, dass dot im\n"
              "Standard-Suchpfad gefunden wird.\n"
              "Dieses Tag erfordert, dass das Tag HAVE_DOT auf YES gesetzt ist."
          );
  doc->add(
              "DOTFILE_DIRS",
              "Das DOTFILE_DIRS-Tag kann verwendet werden, um ein oder mehrere Verzeichnisse\n"
              "anzugeben, die dot-Dateien enthalten, die in die Dokumentation eingebunden\n"
              "werden (siehe den Befehl \\dotfile).\n"
              "Dieses Tag erfordert, dass das Tag HAVE_DOT auf YES gesetzt ist."
          );
  doc->add(
              "DIA_PATH",
              "Sie können mit dia erstellte Diagramme in die Doxygen-Dokumentation einbinden.\n"
              "Doxygen wird dann dia ausführen, um das Diagramm zu erstellen und in die\n"
              "Dokumentation einzufügen. Das DIA_PATH-Tag ermöglicht es Ihnen, das\n"
              "Verzeichnis anzugeben, in dem sich die dia-Binardatei befindet. Wenn leer\n"
              "gelassen, wird angenommen, dass dia im Standard-Suchpfad gefunden wird."
          );
  doc->add(
              "DIAFILE_DIRS",
              "Das DIAFILE_DIRS-Tag kann verwendet werden, um ein oder mehrere Verzeichnisse\n"
              "anzugeben, die dia-Dateien enthalten, die in die Dokumentation eingebunden\n"
              "werden (siehe den Befehl \\diafile)."
          );
  doc->add(
              "PLANTUML_JAR_PATH",
              "Bei Verwendung von PlantUML sollte das PLANTUML_JAR_PATH-Tag verwendet werden,\n"
              "um den Pfad anzugeben, in dem Java die plantuml.jar-Datei finden kann, oder\n"
              "den Dateinamen der zu verwendenden jar-Datei. Wenn leer gelassen, wird\n"
              "angenommen, dass PlantUML nicht verwendet oder während eines\n"
              "Vorverarbeitungsschritts aufgerufen wird. Doxygen generiert eine Warnung, wenn\n"
              "es in diesem Fall auf einen \\startuml-Befehl stößt, und generiert keine\n"
              "Ausgabe für das Diagramm."
          );
  doc->add(
              "PLANTUML_CFG_FILE",
              "Bei Verwendung von PlantUML kann das PLANTUML_CFG_FILE-Tag verwendet werden,\n"
              "um eine Konfigurationsdatei für PlantUML anzugeben."
          );
  doc->add(
              "PLANTUML_INCLUDE_PATH",
              "Bei Verwendung von PlantUML werden die angegebenen Pfade nach Dateien\n"
              "durchsucht, die durch die !include-Anweisung in einem PlantUML-Block angegeben\n"
              "werden."
          );
  doc->add(
              "PLANTUMLFILE_DIRS",
              "Das PLANTUMLFILE_DIRS-Tag kann verwendet werden, um ein oder mehrere\n"
              "Verzeichnisse anzugeben, die PlantUml-Dateien enthalten, die in die\n"
              "Dokumentation eingebunden werden (siehe den Befehl \\plantumlfile)."
          );
  doc->add(
              "MERMAID_PATH",
              "Bei Verwendung von Mermaid-Diagrammen mit CLI-Rendering sollte das\n"
              "MERMAID_PATH-Tag verwendet werden, um das Verzeichnis anzugeben, in dem die\n"
              "ausführbare Datei mmdc (Mermaid CLI) gefunden werden kann. Wenn leer gelassen,\n"
              "ist CLI-basiertes Rendering deaktiviert. Für HTML-Ausgabe wird standardmäßig\n"
              "clientseitiges Rendering über JavaScript verwendet und erfordert kein mmdc.\n"
              "Für LaTeX/PDF-Ausgabe ist mmdc erforderlich, um Bilder vorab zu generieren.\n"
              "Doxygen generiert eine Warnung, wenn CLI-Rendering benötigt wird, aber mmdc\n"
              "nicht verfügbar ist."
          );
  doc->add(
              "MERMAID_CONFIG_FILE",
              "Bei Verwendung von Mermaid-Diagrammen kann das MERMAID_CONFIG_FILE-Tag\n"
              "verwendet werden, um eine JSON-Konfigurationsdatei für das Mermaid-CLI-Tool\n"
              "(mmdc) anzugeben. Diese Datei kann Themeneinstellungen und andere Mermaid-\n"
              "Konfigurationsoptionen enthalten."
          );
  doc->add(
              "MERMAID_RENDER_MODE",
              "Das MERMAID_RENDER_MODE-Tag steuert, wie Mermaid-Diagramme gerendert werden.\n"
              "Mögliche Werte sind: CLI (verwendet das mmdc-Tool von der Befehlszeile),\n"
              "CLIENT (verwendet mermaid.js im Browser) oder SERVER (verwendet mermaid.ink\n"
              "als externen Dienst). Standardmäßig ist dies auf CLIENT gesetzt.\n"
              "Mögliche Werte sind: AUTO (verwendet Client-Side-Rendering für HTML und mmdc\n"
              "für LaTeX/PDF und andere Formate. Wenn MERMAID_PATH nicht gesetzt ist,\n"
              "erzeugen Nicht-HTML-Diagramme eine Warnung), CLI (verwendet das mmdc-Tool zum\n"
              "Vorgenerieren von Bildern (erfordert Node.js und mermaid-js/mermaid-cli).\n"
              "Funktioniert für alle Ausgabeformate) und CLIENT_SIDE (bettet mermaid.js in\n"
              "die HTML-Ausgabe für Client-Side-Rendering ein. Erfordert kein mmdc,\n"
              "funktioniert aber nur für HTML-Ausgabe).\n"
              "Der Standardwert ist: AUTO."
          );
  doc->add(
              "MERMAID_JS_URL",
              "Das MERMAID_JS_URL-Tag gibt die URL an, von der mermaid.js geladen werden\n"
              "soll, wenn clientseitiges Rendering verwendet wird (MERMAID_RENDER_MODE ist\n"
              "CLIENT_SIDE oder AUTO). Der Standardwert verweist auf die neueste Mermaid\n"
              "v11-Version auf dem jsDelivr CDN.\n"
              "\n"
              "Die Standard-CDN-URL erfordert Internetzugang beim Anzeigen der generierten\n"
              "Dokumentation. Für die Offline-Verwendung laden Sie mermaid.esm.min.mjs\n"
              "herunter und setzen Sie dies auf einen relativen Pfad, oder verwenden Sie\n"
              "MERMAID_RENDER_MODE=CLI, um stattdessen Bilder vorab zu generieren.\n"
              "Beispiele:\n"
              "- Neueste v11 (Standard):\n"
              "https://cdn.jsdelivr.net/npm/mermaid@11/dist/mermaid.esm.min.mjs\n"
              "- Angeheftete Version:\n"
              "https://cdn.jsdelivr.net/npm/mermaid@11.3.0/dist/mermaid.esm.min.mjs\n"
              "- Lokale Kopie: ./mermaid.esm.min.mjs (Benutzer muss Datei im HTML-\n"
              "Ausgabeverzeichnis platzieren)\n"
              "Der Standardwert ist:\n"
              "https://cdn.jsdelivr.net/npm/mermaid@11/dist/mermaid.esm.min.mjs."
          );
  doc->add(
              "MERMAIDFILE_DIRS",
              "Das MERMAIDFILE_DIRS-Tag kann verwendet werden, um ein oder mehrere\n"
              "Verzeichnisse anzugeben, die Mermaid-Dateien enthalten, die in die\n"
              "Dokumentation eingebunden werden (siehe den Befehl \\mermaidfile)."
          );
  doc->add(
              "DOT_GRAPH_MAX_NODES",
              "Das DOT_GRAPH_MAX_NODES-Tag kann verwendet werden, um die maximale Anzahl von\n"
              "Knoten festzulegen, die im Graphen angezeigt werden. Wenn die Anzahl der\n"
              "Knoten in einem Graphen größer wird als dieser Wert, wird Doxygen den Graphen\n"
              "abschneiden, was visualisiert wird, indem ein Knoten als rotes Feld\n"
              "dargestellt wird. Beachten Sie, dass der Graph überhaupt nicht angezeigt wird,\n"
              "wenn die Anzahl der direkten Kinder des Wurzelknotens in einem Graphen bereits\n"
              "größer als DOT_GRAPH_MAX_NODES ist. Beachten Sie auch, dass die Große eines\n"
              "Graphen durch MAX_DOT_GRAPH_DEPTH weiter eingeschränkt werden kann.\n"
              "Mindestwert: 0, Höchstwert: 10000, Standardwert: 50.\n"
              "Dieses Tag erfordert, dass das Tag HAVE_DOT auf YES gesetzt ist."
          );
  doc->add(
              "MAX_DOT_GRAPH_DEPTH",
              "Das MAX_DOT_GRAPH_DEPTH-Tag kann verwendet werden, um die maximale Tiefe der\n"
              "von dot generierten Graphen festzulegen. Ein Tiefenwert von 3 bedeutet, dass\n"
              "nur Knoten angezeigt werden, die vom Wurzelknoten aus durch einen Pfad über\n"
              "höchstens 3 Kanten erreichbar sind. Knoten, die weiter vom Wurzelknoten\n"
              "entfernt liegen, werden weggelassen. Beachten Sie, dass das Setzen dieser\n"
              "Option auf 1 oder 2 die für große Codebasen benötigte Rechenzeit erheblich\n"
              "reduzieren kann. Beachten Sie auch, dass die Große eines Graphen durch\n"
              "DOT_GRAPH_MAX_NODES weiter eingeschränkt werden kann. Die Verwendung einer\n"
              "Tiefe von 0 bedeutet keine Tiefenbeschränkung.\n"
              "Mindestwert: 0, Höchstwert: 1000, Standardwert: 0.\n"
              "Dieses Tag erfordert, dass das Tag HAVE_DOT auf YES gesetzt ist."
          );
  doc->add(
              "GENERATE_LEGEND",
              "Wenn das GENERATE_LEGEND-Tag auf YES gesetzt ist, generiert Doxygen eine\n"
              "Legenden-Seite, die die Bedeutung der verschiedenen Boxen in den von dot\n"
              "erzeugten Graphen erklärt.\n"
              "Der Standardwert ist: YES.\n"
              "Dieses Tag erfordert, dass das Tag HAVE_DOT auf YES gesetzt ist."
          );
  doc->add(
              "DOT_CLEANUP",
              "Wenn das DOT_CLEANUP-Tag auf YES gesetzt ist, löscht Doxygen die\n"
              "Zwischendateien, die zum Generieren der verschiedenen Diagramme verwendet\n"
              "wurden.\n"
              "\n"
              "Hinweis: Diese Einstellung wird nicht nur für dot-Dateien verwendet, sondern\n"
              "auch für msc-Temporärdateien.\n"
              "Der Standardwert ist: YES."
          );
  doc->add(
              "MSCGEN_TOOL",
              "Sie können Nachrichtensequenzdiagramme in Doxygen-Kommentaren mit dem Befehl\n"
              "\\msc definieren. Wenn das MSCGEN_TOOL-Tag leer gelassen wird (der Standard),\n"
              "verwendet Doxygen eine eingebaute Version des mscgen-Tools, um die Diagramme\n"
              "zu erstellen. Alternativ kann das MSCGEN_TOOL-Tag auch den Namen eines\n"
              "externen Tools angeben. Wenn Sie beispielsweise prog als Wert angeben, ruft\n"
              "Doxygen das Tool als prog -T <ausgabedateiformat> -o <ausgabedatei>\n"
              "<eingabedatei> auf. Das externe Tool sollte die Ausgabedateiformate \"png\",\n"
              "\"eps\", \"svg\" und \"ismap\" unterstützen."
          );
  doc->add(
              "MSCFILE_DIRS",
              "Das MSCFILE_DIRS-Tag kann verwendet werden, um ein oder mehrere Verzeichnisse\n"
              "anzugeben, die MSC-Dateien enthalten, die in die Dokumentation eingebunden\n"
              "werden (siehe den Befehl \\mscfile)."
          );
}
